@@ -17,7 +17,7 @@ void mexfunction12(nlhs, plhs, nrhs, prhs)
   array_ptr = mxCreateFull(m,n,it);
   B = mxGetPr(array_ptr);  
   for (i=0 ; i < m*n ;i++ ) B[i]= (double) i;
-  mexPutFull("C",&m,&n,B,NULL);
+  mexPutFull("C",m,n,B,NULL);
   mxFree(array_ptr);
 }
 
