@@ -2,40 +2,40 @@
  * Copyright Jean-Philippe Chancelier 
  * ENPC 
  **************************************/
+#include <setjmp.h>
+#include <stdio.h>
+#include <ctype.h>
+#include <signal.h>
 
 #include "../machine.h"
 #include "../sun/addinter.h" /* for DynInterfStart */
-#include <setjmp.h>
+#include "../sun/Sun.h" /* for DynInterfStart */
+
 static  jmp_buf jmp_env; 
-extern int  C2F(matdsc) __PARAMS((void));
-extern int  C2F(matdsr) __PARAMS((void));
-extern int  C2F(userlk) __PARAMS((int *));
+
 extern int  C2F(error) __PARAMS((int *));
 extern void sciprint __PARAMS((char* ,...));
+extern int  Scierror __PARAMS((int iv,char *fmt,...));
+
+extern void  errjump(int n);
+extern void  sci_sig_tstp(int n);
+extern void  controlC_handler(int n);
+static void  sci_sigint_addinter(int n);
+
 /***********************************************************
  * interface function 
  ***********************************************************/
 
-static int Iflag=0; /* special flag for matdsr matdsc */
-
-void C2F(MatdsRC)()
-{
-  if (Iflag == 1) 
-    C2F(matdsc)();
-  else
-    C2F(matdsr)();
-}
-
 static int c_local = 9999;
 
-void C2F(NoTksci)()
+void C2F(NoTksci)(void)
 {
   sciprint("tksci interface not loaded \n");
   C2F(error)(&c_local);
   return;
 }
 
-void C2F(NoPvm)()
+void C2F(NoPvm)(void)
 {
   sciprint("pvm interface not loaded \n");
   C2F(error)(&c_local);
@@ -49,26 +49,28 @@ void C2F(NoPvm)()
 typedef  struct  {
   void  (*fonc)();} OpTab ;
 
-
 #include "callinterf.h"
 
 
 /***********************************************************
  * call the apropriate interface according to the value of k 
- * iflagint is only used inside MatdsRC to switch between 
- * matdsc or matdsr 
+ * iflagint is no more used here ....
  ***********************************************************/
 
-int C2F(callinterf)(k,iflagint)
-      int *k,*iflagint;
+
+static int sig_ok = 0;
+
+int C2F(callinterf) ( int *k, int * iflagint)
 {
   int returned_from_longjump ;
-  static count = 0;
-  Iflag=*iflagint;
+  static int count = 0;
   if ( count == 0) 
     {
+      if (sig_ok) signal(SIGINT,sci_sigint_addinter);
       if (( returned_from_longjump = setjmp(jmp_env)) != 0 )
 	{
+	  if (sig_ok) signal(SIGINT, controlC_handler);
+	  Scierror(999,"SIGSTP: aborting current computation\r\n");
 	  count = 0;
 	  return 0;
 	}
@@ -79,9 +81,22 @@ int C2F(callinterf)(k,iflagint)
   else
     (*(Interfaces[*k-1].fonc))();
   count--;
+  if (count == 0) { 
+    if (sig_ok) signal(SIGINT, controlC_handler);
+  }
   return 0;
 }
 
+static void sci_sigint_addinter(int n)
+{
+  int c;
+  sciprint("Trying to stop scilab in the middle of an interface\n");
+  sciprint("Do you really want to abort computation (y n  ?) ");
+  c = getchar();
+  if ( c == 'y' ) errjump(n);
+}
+
+
 /***********************************************************
  * Unused function just here to force linker to load some 
  * functions 
@@ -95,7 +110,7 @@ extern int   System2_contents __PARAMS((int));
 extern int   System_contents __PARAMS((int));
 extern int  Intersci_contents __PARAMS((int));
 
-int ForceLink()
+int ForceLink(void)
 {
   Blas_contents(0);
   Lapack_contents(0);
@@ -107,7 +122,11 @@ int ForceLink()
   return 0;
 }
 
-extern int errjump()
+/*-------------------------------------
+ * long jump to stop interface computation 
+ *-------------------------------------*/
+
+void errjump(int n)
 {
-longjmp(jmp_env,-1); 
+  longjmp(jmp_env,-1); 
 }
