@@ -1,17 +1,18 @@
 /*------------------------------------------------------------------------
  *    Graphic library
- *    Copyright (C) 1998-2000 Enpc/Jean-Philippe Chancelier
- *    jpc@cereve.enpc.fr 
+ *    Copyright (C) 1998-2001 Enpc/Jean-Philippe Chancelier
+ *    jpc@cermics.enpc.fr 
  --------------------------------------------------------------------------*/
 
 #include "Math.h"
+#include "Entities.h"
 
 /********************************************************
  * the functions in this file are called from 
  * callback ( see jpc_SGraph.c ) for the XWindow version 
  * Nov 1998 : we must be sure that during the evaluation of 
  *            scig_xxx an other function scig_yyy won't be 
- *            run. Thi sis possible since during the execution of 
+ *            run. This is possible since during the execution of 
  *            one scig_xxx function a sciprint can be performed 
  *            and it will lead to an event check which can 
  *            produce a call to an other scig_yyy function 
@@ -26,31 +27,27 @@ static int scig_buzy = 0;
  * action of scig_xxx functions 
  ********************************************************/
 
-
-int scig_handler_none(win_num)int win_num; {return win_num;};
+int scig_handler_none(int win_num) {return win_num;};
 
 Scig_handler scig_handler = scig_handler_none;
 
-Scig_handler set_scig_handler(f) 
-     Scig_handler f;
+Scig_handler set_scig_handler(Scig_handler f)
 {
   Scig_handler old = scig_handler;
   scig_handler = f;
   return old;
 }
 
-void reset_scig_handler() 
+void reset_scig_handler(void)
 {
   scig_handler = scig_handler_none;
 }
 
-
 /********************************************************
  * Basic Replay : redraw recorded graphics 
  ********************************************************/
 
-void scig_replay(win_num)
-     integer win_num;
+void scig_replay(integer win_num)
 {
   integer verb=0,cur,na;
   char name[4];
@@ -76,8 +73,7 @@ void scig_replay(win_num)
  * else we perform a sgig_replay 
  ********************************************************/
 
-void scig_expose(win_num)
-     integer win_num;
+void scig_expose(integer win_num)
 {
   integer verb=0,cur,pix,na;
   char name[4];
@@ -91,9 +87,12 @@ void scig_expose(win_num)
 	C2F(SetDriver)("Rec",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
       C2F(dr)("xget","window",&verb,&cur,&na,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);  
       C2F(dr)("xset","window",&win_num,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-      C2F(dr)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);    
+      C2F(dr)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);  
+      if (version_flag() == 0) /* NG */
+       sciRedrawF(&win_num); /* NG */
+      else /* NG */  
       /* XXXX scig_handler(win_num); */
-      C2F(dr)("xreplay","v",&win_num,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+	C2F(dr)("xreplay","v",&win_num,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
 
       C2F(dr)("xset","window",&cur,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
       C2F(dr)("xsetdr",name, PI0, PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
@@ -113,8 +112,7 @@ void scig_expose(win_num)
  * Redraw graphic window win_num  after resizing 
  ********************************************************/
 
-void scig_resize(win_num)
-     integer win_num;
+void scig_resize(integer win_num)
 {
   integer verb=0,cur,na;
   char name[4];
@@ -138,8 +136,7 @@ void scig_resize(win_num)
  * Just resize a pixmap (win95 only)
  ********************************************************/
 
-void scig_resize_pixmap(win_num)
-     integer win_num;
+void scig_resize_pixmap(integer win_num)
 {
   integer verb=0,cur,na;
   char name[4];
@@ -160,8 +157,7 @@ void scig_resize_pixmap(win_num)
  * clear window 
  ********************************************************/
 
-void  scig_erase(win_num)
-     integer win_num;
+void  scig_erase(integer win_num)
 {
   integer verb=0,cur,na;
   char name[4];
@@ -172,6 +168,7 @@ void  scig_erase(win_num)
     C2F(SetDriver)("Rec",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
   C2F(dr)("xget","window",&verb,&cur,&na,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);  
   C2F(dr)("xset","window",&win_num,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+  if (version_flag() == 0) sciXbasc(); /*NG */
   C2F(dr)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   C2F(dr)("xstart","v",&win_num,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   C2F(dr)("xset","window",&cur,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
@@ -187,37 +184,46 @@ void  scig_erase(win_num)
  * driver : driver for code generation 
  ********************************************************/
 
-void scig_tops(win_num,colored,bufname,driver)
-     integer win_num,colored;
-     char *bufname,*driver;
+void scig_tops(integer win_num, integer colored, char *bufname, char *driver)
 {
   char name[4];
   integer zero=0,un=1;
   integer verb=0,cur,na,screenc;
+
   if ( scig_buzy  == 1 ) return ;
   scig_buzy =1;
   GetDriver1(name,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
-  C2F(dr)("xget","window",&verb,&cur,&na,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);  
-  C2F(dr)("xset","window",&win_num,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-  C2F(dr)("xsetdr",driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-  C2F(dr)("xinit",bufname,&win_num,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-  if (colored==1) 
-    C2F(dr)("xset","use color",&un,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-  else
-    C2F(dr)("xset","use color",&zero,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-  getcolordef(&screenc);
-  /** we set the default screen color to the value of colored 
-    because we don't want that recorded events such as xset("default") could 
-    change the color status .
-    and we set the UseColorFlag to 1 not to replay xset("use color",..) events 
+  C2F(dr)("xget","window",&verb,&cur,&na,PI0,PI0,PI0,PD0,PD0,PD0,PD0,5L,7L);  
+  C2F(dr)("xset","window",&win_num,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,5L,7L);
+  if (version_flag() == 0) {
+    sciPointObj *curFig=sciGetCurrentFigure ();
+    integer bg;
+    C2F(dr)("xget","background",&verb,&bg,&na,PI0,PI0,PI0,PD0,PD0,PD0,PD0,5L,11L);
+    C2F(dr)("xsetdr",driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+    C2F(dr)("xinit",bufname,&win_num,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+    C2F(dr)("xset","background",&bg,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,5L,7L);
+    sciDrawObj(curFig);
+  }
+  else {
+    C2F(dr)("xsetdr",driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+    C2F(dr)("xinit",bufname,&win_num,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+    if (colored==1) 
+      C2F(dr)("xset","use color",&un,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+    else
+      C2F(dr)("xset","use color",&zero,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+    getcolordef(&screenc);
+    /** we set the default screen color to the value of colored 
+	because we don't want that recorded events such as xset("default") could 
+	change the color status .
+	and we set the UseColorFlag to 1 not to replay xset("use color",..) events 
     **/
-  setcolordef(colored);
-  UseColorFlag(1);
-  /* XXXX scig_handler(win_num); */
-  C2F(dr)("xreplay","v",&win_num,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-  /** back to default values **/
-  UseColorFlag(0);
-  setcolordef(screenc);
+    setcolordef(colored);
+    UseColorFlag(1);
+    C2F(dr)("xreplay","v",&win_num,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+    /** back to default values **/
+    UseColorFlag(0);
+    setcolordef(screenc);
+  }
   C2F(dr)("xend","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   C2F(dr)("xsetdr",name, PI0, PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   C2F(dr)("xset","window",&cur,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
@@ -226,10 +232,7 @@ void scig_tops(win_num,colored,bufname,driver)
   scig_buzy = 0;
 }
 
-int C2F(xg2psofig)(fname,len,iwin,color,driver,l1,l2)
-     char *fname,*driver;
-     integer *len,*iwin,*color;
-     long int l1,l2;
+int C2F(xg2psofig)(char *fname, integer *len, integer *iwin, integer *color, char *driver, long int l1, long int l2)
 {
   int sc;
   if ( *color == -1 ) 
@@ -244,14 +247,13 @@ int C2F(xg2psofig)(fname,len,iwin,color,driver,l1,l2)
  * 2D Zoom 
  ******************************************************/
 
-void scig_2dzoom(win_num)
-     integer win_num;
+void scig_2dzoom(integer win_num)
 {
   char name[4];
   if ( scig_buzy  == 1 ) return ;
   scig_buzy =1;
   GetDriver1(name,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
-  if ( (GetDriver()) !='R') 
+  if ( (GetDriver()) !='R'&&version_flag !=0) 
     {
       wininfo("Zoom works only with the Rec driver");
     }
@@ -272,15 +274,14 @@ void scig_2dzoom(win_num)
  * Unzoom function 
  ******************************************************/
 
-void   scig_unzoom(win_num)
-     integer win_num;
+void   scig_unzoom(integer win_num)
 {
   integer verb=0,cur,na;
   char name[4];
   if ( scig_buzy  == 1 ) return ;
   scig_buzy =1;
   GetDriver1(name,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
-  if ( (GetDriver()) !='R') 
+  if ( (GetDriver()) !='R'&&version_flag !=0) 
     {
       wininfo("UnZoom works only with the Rec driver ");
     }
@@ -299,15 +300,14 @@ void   scig_unzoom(win_num)
  * 3d rotation function 
  ******************************************************/
 
-void scig_3drot(win_num)
-     integer win_num;
+void scig_3drot(integer win_num)
 {
   integer verb=0,cur,na;
   char name[4];
   if ( scig_buzy  == 1 ) return ;
   scig_buzy =1;
   GetDriver1(name,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
-  if ( (GetDriver()) !='R') 
+  if ( (GetDriver()) !='R'&&version_flag !=0) 
     {
       wininfo("Rot3D works only with the Rec driver");
     }
@@ -321,24 +321,33 @@ void scig_3drot(win_num)
     }
   scig_buzy = 0;
 }
+
 /********************************************************
  * graphic Window selection 
  ********************************************************/
 
-void scig_sel(win_num)
-     integer win_num;
+void scig_sel(integer win_num)
 {
   C2F(dr)("xset","window",&win_num,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
 }
 
+/********************************************************
+ * graphic Window raise 
+ ********************************************************/
+
+void scig_raise(integer win_num)
+{
+  C2F(dr)("xset","window",&win_num,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+  C2F(dr)("xselect","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+}
+
+
 
 /********************************************************
  * Reload a saved graphic
  ********************************************************/
 
-void scig_loadsg(win_num,filename)
-     int win_num;
-     char *filename;
+void scig_loadsg(int win_num, char *filename)
 {
   integer verb=0,cur,na;
   if ( scig_buzy  == 1 ) return ;
