@@ -1,7 +1,7 @@
 /*------------------------------------------------------------------------
  *    Graphic library
- *    Copyright (C) 1998-2000 Enpc/Jean-Philippe Chancelier
- *    jpc@cereve.enpc.fr 
+ *    Copyright (C) 1998-2001 Enpc/Jean-Philippe Chancelier
+ *    jpc@cermics.enpc.fr 
  --------------------------------------------------------------------------*/
 
 #include <math.h>
@@ -9,9 +9,13 @@
 #include <string.h>
 #include "Math.h"
 #include "PloEch.h"
+#include "Entities.h" /* NG */
 
 static double MiniD __PARAMS((double *x,integer n));
-
+extern void Champ2DRealToPixel __PARAMS((integer *xm,integer *ym,integer *zm,integer *na,
+					 integer *arsize,integer *colored,double *x,double *y,
+                                         double  *fx,double *fy,integer *n1,integer *n2,double *arfact));
+extern void initsubwin();
 /*-----------------------------------------------------------------
  *  int C2F(champ)(x,y,fx,fy,n1,n2,strflag,brect,arfact,lstr)
  *  int C2F(champ1)(x,y,fx,fy,n1,n2,strflag,brect,arfact,lstr)
@@ -29,22 +33,18 @@ static double MiniD __PARAMS((double *x,integer n));
  * - lstr : (used when called from Fortran code)
  -------------------------------------------------------------------*/
 
-void champg(name, colored, x, y, fx, fy, n1, n2, strflag, brect, arfact, lstr)
-     char *name;
-     integer colored;
-     double x[],y[],fx[],fy[];
-     integer *n1,*n2;
-     char *strflag;
-     double *brect;
-     double *arfact;
-     integer lstr;
+void champg(char *name, integer colored, double *x, double *y, double *fx, double *fy, integer *n1, integer *n2, 
+char *strflag, double *brect, double *arfact, integer lstr)
 {
   static integer aaint[]={2,10,2,10};
-  integer *xm,*ym,*zm,i,j,n,na;
-  double  xx[2],yy[2], maxx;
-  double  nx,ny,sc,sfx,sfy,sfx2,sfy2;
-  double  arsize1=0.5,arsize2=0.5;
-  integer arsize,nn1=1,nn2=2,iflag=0;
+  integer *xm,*ym,*zm,na,n;
+  double  xx[2],yy[2];
+  integer arsize,nn1=1,nn2=2,iflag=0;  
+  /* NG */
+  sciPointObj  *psubwin;
+  integer flag,type =1;
+  double arsize1;
+  integer *style;
   /* get default dash fo rarrows **/
   integer verbose=0,narg,xz[10],uc;
 
@@ -54,18 +54,48 @@ void champg(name, colored, x, y, fx, fy, n1, n2, strflag, brect, arfact, lstr)
   else
     C2F(dr)("xget","line style",&verbose,xz,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   /** The arrowsize acording to the windowsize **/
-  n=2*(*n1)*(*n2);
+  n=2*(*n1)*(*n2); 
   xx[0]=x[0];xx[1]=x[*n1-1];
   yy[0]=y[0];yy[1]=y[*n2-1];
-  /** Boundaries of the frame **/
+  /** Boundaries of the frame **/ 
+  
+  if (version_flag() == 0)
+  {
+      if (!(sciGetGraphicMode (sciGetSelectedSubWin (sciGetCurrentFigure ())))->addplot) 
+        { 
+          sciXbasc();  
+          initsubwin();
+          sciRedrawFigure();
+        }  
+  /** Boundaries of the frame **/ 
+      if ((sciGetGraphicMode (sciGetSelectedSubWin (sciGetCurrentFigure ())))->autoscaling)
+            update_frame_bounds(0,"gnn",xx,yy,&nn1,&nn2,aaint,strflag,brect);
+  }
+ else
+      update_frame_bounds(0,"gnn",xx,yy,&nn1,&nn2,aaint,strflag,brect);
 
-  update_frame_bounds(0,"gnn",xx,yy,&nn1,&nn2,aaint,strflag,brect);
   /* Storing values if using the Record driver */
-  if (GetDriver()=='R') 
-    StoreChamp(name,x,y,fx,fy,n1,n2,strflag,brect,arfact);
+  if ((GetDriver()=='R') && (version_flag() != 0))
+     StoreChamp(name,x,y,fx,fy,n1,n2,strflag,brect,arfact); 
+ 
+  /*---- Drawing the axes ----*/
+  if (version_flag() == 0)
+  {
+  psubwin = sciGetSelectedSubWin (sciGetCurrentFigure ()); 
+  sciSetIsClipping (psubwin,0); 
 
-  /** Allocation **/
-  xm = graphic_alloc(0,n,sizeof(int));
+  strncpy(pSUBWIN_FEATURE (psubwin)->strflag, strflag, strlen(strflag));
+  pSUBWIN_FEATURE (psubwin)->isaxes  = TRUE;
+
+  sciDrawObj(sciGetSelectedSubWin (sciGetCurrentFigure ())); 
+
+  sciSetCurrentObj(ConstructSegs((sciPointObj *) sciGetSelectedSubWin (sciGetCurrentFigure ()),
+                       type,x,y,*n1,*n2,fx,fy,flag,style,arsize1,colored,*arfact)); 
+
+  }
+  else 
+    axis_draw(strflag);
+  /** Allocation **/  xm = graphic_alloc(0,n,sizeof(int));
   ym = graphic_alloc(1,n,sizeof(int));
   if ( xm == 0 || ym == 0) 
     {
@@ -80,6 +110,68 @@ void champg(name, colored, x, y, fx, fy, n1, n2, strflag, brect, arfact, lstr)
 	return ;
       }      
   }
+
+  Champ2DRealToPixel(xm,ym,zm,&na,&arsize,&colored,x,y,fx,fy,n1,n2,arfact);
+  
+  /** Drawing the curves **/
+  frame_clip_on();
+  if ( colored ==0) 
+    C2F(dr)("xarrow","v",xm,ym,&na,&arsize,xz,&iflag,PD0,PD0,PD0,PD0,0L,0L);
+  else
+    C2F(dr)("xarrow","v",xm,ym,&na,&arsize,zm,(iflag=1,&iflag),PD0,PD0,PD0,PD0,0L,0L);
+  frame_clip_off();
+}
+
+int C2F(champ)(double *x, double *y, double *fx, double *fy, integer *n1, integer *n2, char *strflag, double *brect, double *arfact, integer lstr)
+{
+  champg("champ",0,x,y,fx,fy,n1,n2,strflag,brect,arfact,lstr);
+  return(0); 
+}
+
+int C2F(champ1)(double *x, double *y, double *fx, double *fy, integer *n1, integer *n2, char *strflag, double *brect, double *arfact, integer lstr)
+{
+  champg("champ1",1,x,y,fx,fy,n1,n2,strflag,brect,arfact,lstr);
+  return(0);
+}
+
+
+/*----------------------------------
+ * Returns min( abs(x)) excluding null x(i)  values 
+ * if x==0 then 1 is returned 
+ *----------------------------------*/
+
+static double MiniD(double *x, integer n)
+{
+  int i;
+  double dx=1,mindx=1;
+  if ( n < 2 ) return(mindx);
+  mindx= Abs(x[1]-x[0]);
+  mindx = ( mindx != 0 ) ? mindx : 1;
+  for ( i = 2 ; i < n ; i++) 
+    {
+      dx = Abs(x[i]-x[i-1]);
+      if ( dx < mindx && dx != 0 ) mindx=dx;
+    }
+  return(mindx);
+}
+
+
+extern void Champ2DRealToPixel(xm,ym,zm,na,arsize,colored,x,y,fx,fy,n1,n2,arfact)
+
+  integer *xm,*ym,*zm;
+  integer *na,*arsize,*colored;
+  integer *n1,*n2;
+  double *x, *y, *fx, *fy;
+  double*arfact;
+{  
+ 
+  integer i,j;
+  double  maxx;
+  double  nx,ny,sc,sfx,sfy,sfx2,sfy2;
+  double  arsize1=0.5,arsize2=0.5;
+  /* get default dash fo rarrows **/
+  integer verbose=0,narg;
+
   /* From double to pixels */
   for ( i = 0 ; i < *n1 ; i++)
     for ( j =0 ; j < *n2 ; j++)
@@ -109,13 +201,13 @@ void champg(name, colored, x, y, fx, fy, n1, n2, strflag, brect, arfact, lstr)
   /** size of arrow **/
   arsize1= ((double) Cscale.WIRect1[2])/(5*(*n1));
   arsize2= ((double) Cscale.WIRect1[3])/(5*(*n2));
-  arsize=  (arsize1 < arsize2) ? inint(arsize1*10.0) : inint(arsize2*10.0) ;
-  arsize = (int)(arsize*(*arfact));
+  *arsize=  (arsize1 < arsize2) ? inint(arsize1*10.0) : inint(arsize2*10.0) ;
+  *arsize = (int)((*arsize)*(*arfact));
 
   set_clip_box(Cscale.WIRect1[0],Cscale.WIRect1[0]+Cscale.WIRect1[2],Cscale.WIRect1[1],
 	       Cscale.WIRect1[1]+Cscale.WIRect1[3]);
 
-  if ( colored == 0 ) 
+  if ( *colored == 0 ) 
     {
       int j=0;
       for ( i = 0 ; i < (*n1)*(*n2) ; i++)
@@ -134,7 +226,7 @@ void champg(name, colored, x, y, fx, fy, n1, n2, strflag, brect, arfact, lstr)
 	      j++;
 	    }
 	}
-      na=2*j;
+      *na=2*j;
     }
   else 
     {
@@ -159,65 +251,9 @@ void champg(name, colored, x, y, fx, fy, n1, n2, strflag, brect, arfact, lstr)
 	      j++;
 	    }
        }
-      na=2*j;
+      *na=2*j;
     }
-  /** Drawing axes **/
-  axis_draw(strflag);
-  /** Drawing the curves **/
-  frame_clip_on();
-  if ( colored ==0) 
-    C2F(dr)("xarrow","v",xm,ym,&na,&arsize,xz,&iflag,PD0,PD0,PD0,PD0,0L,0L);
-  else
-    C2F(dr)("xarrow","v",xm,ym,&na,&arsize,zm,(iflag=1,&iflag),PD0,PD0,PD0,PD0,0L,0L);
-  frame_clip_off();
-}
-
-int C2F(champ)(x,y,fx,fy,n1,n2,strflag,brect,arfact,lstr)
-     double x[],y[],fx[],fy[],brect[],*arfact;
-     integer *n1,*n2;
-     char strflag[];
-     integer lstr;
-{
-  champg("champ",0,x,y,fx,fy,n1,n2,strflag,brect,arfact,lstr);
-  return(0); 
-}
-
-int C2F(champ1)(x,y,fx,fy,n1,n2,strflag,brect,arfact,lstr)
-     double x[],y[],fx[],fy[],brect[],*arfact;
-     integer *n1,*n2;
-     char strflag[];
-     integer lstr;
-{
-  champg("champ1",1,x,y,fx,fy,n1,n2,strflag,brect,arfact,lstr);
-  return(0);
-}
-
-
-/*----------------------------------
- * Returns min( abs(x)) excluding null x(i)  values 
- * if x==0 then 1 is returned 
- *----------------------------------*/
-
-static double MiniD(x, n)
-     double *x;
-     integer n;
-{
-  int i;
-  double dx=1,mindx=1;
-  if ( n < 2 ) return(mindx);
-  mindx= Abs(x[1]-x[0]);
-  mindx = ( mindx != 0 ) ? mindx : 1;
-  for ( i = 2 ; i < n ; i++) 
-    {
-      dx = Abs(x[i]-x[i-1]);
-      if ( dx < mindx && dx != 0 ) mindx=dx;
-    }
-  return(mindx);
 }
 
 
 
-
-
-
-
