@@ -12,6 +12,7 @@
 /* Other functions */
 
 extern void sciprint __PARAMS((char *fmt,...));
+extern void sciprint_nd __PARAMS((char *fmt,...));
 extern void Scistring __PARAMS((char *str));
 
 /*Actions.c */
@@ -27,6 +28,7 @@ extern void scig_replay __PARAMS((integer ));
 extern void scig_expose __PARAMS((integer )); 
 extern void scig_3drot __PARAMS((integer )); 
 extern void scig_sel __PARAMS((integer )); 
+extern void scig_raise __PARAMS((integer )); 
 extern void scig_loadsg __PARAMS((int ,char *)); 
 extern void scig_resize __PARAMS((integer )); 
 extern void scig_resize_pixmap __PARAMS((integer )); 
@@ -647,9 +649,6 @@ extern void ReleaseWinHdc  __PARAMS((void));
 /**  extern struct BCG *AddNewWindow  __PARAMS((WindowList **listptr));  **/
   extern void DeleteSGWin  __PARAMS((integer intnum));  
   extern void DeleteWindowToList  __PARAMS((integer num));  
-/**  extern HWND GetWindowNumber  __PARAMS((int wincount));  **/
-/**  extern struct BCG *GetWindowXgcNumber  __PARAMS((integer i));  **/
-/**  extern struct BCG *GetWinXgc  __PARAMS((WindowList *listptr,integer i));  **/
   extern void C2F(getwins) __PARAMS((integer *,integer *,integer *));  
   extern void set_c  __PARAMS((integer i));  
   extern void C2F(initgraphic) __PARAMS((char *,integer *,integer *,integer *,integer *,integer *,integer *,double *,double *,double *,double *));  
