@@ -1,7 +1,7 @@
 /*------------------------------------------------------------------------
  *    Graphic library
- *    Copyright (C) 1998-2000 Enpc/Jean-Philippe Chancelier
- *    jpc@cereve.enpc.fr 
+ *    Copyright (C) 1998-2001 Enpc/Jean-Philippe Chancelier
+ *    jpc@cermics.enpc.fr 
  --------------------------------------------------------------------------*/
 
 #include <string.h>
@@ -10,16 +10,12 @@
 #include "Math.h"
 #include "PloEch.h"
 
-static void Plo2d4RealToPixel __PARAMS((integer *n1, integer *n2, double *x, double *y, integer *xm, integer *ym, char *xf));
+extern void Plo2d4RealToPixel __PARAMS((integer *n1, integer *n2, double *x, double *y, integer *xm, integer *ym, char *xf));
 /*--------------------------------------------------------------------
   C2F(plot2d4)(xf,x,y,n1,n2,style,strflag,legend,brect,aaint)
 --------------------------------------------------------------------------*/
   
-int C2F(plot2d4)(xf,x,y,n1,n2,style,strflag,legend,brect,aaint,l1,l2,l3)
-     double x[],y[],brect[];
-     integer   *n1,*n2,style[],aaint[];
-     char legend[],strflag[],xf[];
-     integer l1,l2,l3;
+int C2F(plot2d4)(char *xf, double *x, double *y, integer *n1, integer *n2, integer *style, char *strflag, char *legend, double *brect, integer *aaint, integer l1, integer l2, integer l3)
 {
   int n;
   integer *xm,*ym;
@@ -81,14 +77,7 @@ int C2F(plot2d4)(xf,x,y,n1,n2,style,strflag,legend,brect,aaint,l1,l2,l3)
 
 
 
-static void Plo2d4RealToPixel(n1, n2, x, y, xm, ym, xf)
-     integer *n1;
-     integer *n2;
-     double *x;
-     double *y;
-     integer *xm;
-     integer *ym;
-     char *xf;
+extern void Plo2d4RealToPixel(integer *n1, integer *n2, double *x, double *y, integer *xm, integer *ym, char *xf)
 {
   integer i,j;
   /** Computing y-values **/
