@@ -7,8 +7,10 @@
 #include <string.h> /* in case of dbmalloc use */
 #include <stdio.h>
 #include <math.h>
-#include "Math.h"
+#include "Math.h" 
+#include "Graphics.h"
 #include "PloEch.h"
+#include "Entities.h"
 
 /*----------------------------------------------
  * A List for storing Window scaling information 
@@ -23,7 +25,6 @@ static WCScaleList *check_subwin_wcscale __PARAMS((WCScaleList *listptr, double
 static int same_subwin __PARAMS((double lsubwin_rect[4],double subwin_rect[4]));
 static void set_window_scale __PARAMS((integer i,WCScaleList  *scale));
 
-
 /* The scale List : one for each graphic window */
 
 static ScaleList *The_List = NULL;
@@ -48,12 +49,12 @@ WCScaleList  Cscale =
   35.0,45.0,
   1,                 /* added by es */
   (WCScaleList *) 0, /*unused */
-  (WCScaleList *) 0 /*unused */
+  (WCScaleList *) 0  /*unused */  
 };
 
 /** default values **/
 
-static WCScaleList  Defscale = 
+WCScaleList  Defscale = 
 { 
   0,
   {600,400},
@@ -71,7 +72,7 @@ static WCScaleList  Defscale =
   35.0,45.0,
   1,                 /* added by es */
   (WCScaleList *) 0, /*unused */
-  (WCScaleList *) 0 /*unused */
+  (WCScaleList *) 0 /*unused */  
 };
 
 /*----------------------------------------------------------
@@ -79,7 +80,7 @@ static WCScaleList  Defscale =
  * and curwin() scale with default scale.
  *----------------------------------------------------------*/
 
-void Cscale2default()
+extern void Cscale2default()
 {
   scale_copy(&Cscale,&Defscale);  set_window_scale(curwin(),&Cscale);
 }
@@ -447,10 +448,30 @@ int C2F(Nsetscale2d)(WRect,ARect,FRect,logscale,l1)
    * this is only important for StoreNEch which do not work with null arguments 
    */ 
   /* char flag[] = "tfffff";*/ /* flag to specify which arguments have changed*/
+  /* 14/03/2002*/
+  sciPointObj *masousfen;
+	
   char flag[7];
-  strcpy(flag,"tfffff");
+  strcpy(flag,"tfffff");  
+ 
+  /** voir aussi si xsetech (frect) **/ 
   if ( WRect != NULL) 
     {
+      /* Ajout djalel */
+      if (version_flag() == 0)
+        {
+	  if (( masousfen = sciIsExistingSubWin (WRect)) != (sciPointObj *)NULL)
+	    sciSetSelectedSubWin(masousfen);
+	  else if ((masousfen = ConstructSubWin (sciGetCurrentFigure(), 0)) != NULL)
+	    {
+	    sciSetSelectedSubWin(masousfen);
+            pSUBWIN_FEATURE (masousfen)->WRect[0]   = WRect[0];
+	    pSUBWIN_FEATURE (masousfen)->WRect[1]   = WRect[1];
+	    pSUBWIN_FEATURE (masousfen)->WRect[2]   = WRect[2];
+            pSUBWIN_FEATURE (masousfen)->WRect[3]   = WRect[3];
+            }
+	} 
+      /** */
       /* a subwindow is specified */
       flag[1]='t';
       if (! same_subwin( WRect, Cscale.subwin_rect))
@@ -472,7 +493,15 @@ int C2F(Nsetscale2d)(WRect,ARect,FRect,logscale,l1)
 	    }
 	}
     }
-  else WRect = Cscale.subwin_rect;
+  else WRect = Cscale.subwin_rect; 
+  if (version_flag() == 0)
+    if (FRect != NULL)
+	    { masousfen=sciGetSelectedSubWin(sciGetCurrentFigure());
+	      pSUBWIN_FEATURE (masousfen)->FRect[0]   = FRect[0];
+	      pSUBWIN_FEATURE (masousfen)->FRect[1]   = FRect[1];
+	      pSUBWIN_FEATURE (masousfen)->FRect[2]   = FRect[2];
+	      pSUBWIN_FEATURE (masousfen)->FRect[3]   = FRect[3];
+	    }
   if ( FRect != NULL) flag[2]='t'; else FRect = Cscale.frect;
   if ( ARect != NULL) flag[5]='t'; else ARect = Cscale.axis;
   if ( logscale != NULL) flag[4] ='t'; else logscale = Cscale.logflag;
@@ -499,8 +528,8 @@ int C2F(Nsetscale2d)(WRect,ARect,FRect,logscale,l1)
 	  FRect[3]=log10(FRect[3]);
 	}
     }
-  if (GetDriver()=='R') StoreNEch("nscale",flag,WRect,ARect,FRect,logscale);
-  set_scale(flag,WRect,FRect,NULL,logscale,ARect);
+  if ((GetDriver()=='R') && (version_flag() != 0)) StoreNEch("nscale",flag,WRect,ARect,FRect,logscale);
+  set_scale(flag,WRect,FRect,NULL,logscale,ARect);  
   return(0);
 }
 
@@ -521,7 +550,7 @@ int getscale2d(WRect,FRect,logscale,ARect)
       ARect[i]=Cscale.axis[i];
     }
   if (logscale[0]=='l') 
-    {
+    { 
       FRect[0]=pow(ten,FRect[0]);
 	FRect[2]=pow(ten,FRect[2]);
     }
@@ -655,13 +684,12 @@ void set_scale(flag,subwin,frame_values,aaint,logflag,axis_values)
       Cscale.xtics[3] = Cscale.Waaint1[1];
       Cscale.ytics[3] = Cscale.Waaint1[3];
     }
-
-
+ 
   /** Cscale changes are copied int current window scale */
   if ( (c=GetDriver()) == 'X' ||  c == 'R' || c == 'I' || c == 'G' || c == 'W' )
     {
       set_window_scale(curwin(),&Cscale);
-    }
+    }  
 }
 
 /*--------------------------------------------------------------------
@@ -723,6 +751,7 @@ int C2F(xechelle2d)(x,x1,n1,dir,lstr)
   integer i;
   if (strcmp("f2i",dir)==0) 
     {
+      
       if (Cscale.logflag[0] == 'n') 
 	for ( i=0 ; i < (*n1) ; i++) x1[i]= XScale(x[i]);
       else 
@@ -736,7 +765,8 @@ int C2F(xechelle2d)(x,x1,n1,dir,lstr)
 	for ( i=0 ; i < (*n1) ; i++) x[i]= exp10(XPi2R( x1[i]));
     }
   else 
-    sciprint(" Wrong dir %s argument in echelle2d\r\n",dir);
+   sciprint(" Wrong dir %s argument in echelle2d\r\n",dir);
+  
   return(0);
 }
 
@@ -764,7 +794,8 @@ int C2F(yechelle2d)(y,yy1,n2,dir,lstr)
 	for ( i=0 ; i < (*n2) ; i++)  y[i]= exp10(YPi2R( yy1[i]));
     }
   else 
-    sciprint(" Wrong dir %s argument in echelle2d\r\n",dir);
+    sciprint(" Wrong dir %s argument in echelle2d\r\n",dir); 
+  
   return(0);
 }
 
@@ -957,8 +988,12 @@ void zoom_get_rectangle(bbox)
   /* Using the mouse to get the new rectangle to fix boundaries */
   integer th,th1=1;
   integer pixmode,alumode,color,style[10],fg,verbose=0,narg;
-  integer ibutton,in,iwait=0,istr=0;
+  integer ibutton,in,iwait=0,istr=0, noir=33;
+  integer modes[2];
   double x0,yy0,x,y,xl,yl;
+
+  modes[0]=1;modes[1]=0; /* for xgemouse only get mouse mouvement*/ 
+
   C2F(dr)("xget","pixmap",&verbose,&pixmode,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   C2F(dr)("xget","alufunction",&verbose,&alumode,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   C2F(dr)("xget","thickness",&verbose,&th,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
@@ -983,14 +1018,15 @@ void zoom_get_rectangle(bbox)
   while ( ibutton == -1 ) 
     {
       /* dessin d'un rectangle */
+      C2F (dr) ("xset", "color",&noir,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0, PD0,0L,0L);
       zoom_rect(x0,yy0,x,y);
       if ( pixmode == 1) C2F(dr1)("xset","wshow",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-      C2F(dr1)("xgetmouse","one",&ibutton,&iwait,PI0,PI0,PI0,PI0,&xl, &yl,PD0,PD0,0L,0L);
+      C2F(dr1)("xgetmouse","one",&ibutton,&iwait,PI0,PI0,modes,PI0,&xl, &yl,PD0,PD0,0L,0L);
       /* effacement du rectangle */
       zoom_rect(x0,yy0,x,y);
       if ( pixmode == 1) C2F(dr1)("xset","wshow",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
       x=xl;y=yl;
-    }
+    }   
 #ifndef WIN32
   /** XXXX */
   C2F(dr1)("xset","alufunction",(in=3,&in),PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
@@ -1014,11 +1050,21 @@ void zoom_get_rectangle(bbox)
 
 }
 
+
+
 void zoom()
 {
   char driver[4];
   integer aaint[4],flag[2]; /* ansi : ={1,0};*/
-  integer verbose=0,narg,ww;
+  integer verbose=0,narg,ww; 
+  /** 01/07/2002 ***/
+  sciPointObj *psousfen,*tmpsousfen;
+  sciSons *psonstmp;  
+
+  double fmin,fmax,lmin,lmax;  
+  integer min,max,puiss,deux=2,dix=10,box1[4],section[4];
+ 
+ 
   flag[0] =1 ; flag[1]=0;
   C2F(dr1)("xget","window",&verbose,&ww,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   GetDriver1(driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
@@ -1030,18 +1076,91 @@ void zoom()
   else 
     {
       double bbox[4];
-      zoom_get_rectangle(bbox);
+ 
+      zoom_get_rectangle(bbox);   
       C2F(SetDriver)(driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
-      C2F(dr)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);    
-      Tape_ReplayNewScale(" ",&ww,flag,PI0,aaint,PI0,PI0,bbox,PD0,PD0,PD0);
+      C2F(dr)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);  
+      if (version_flag() == 0){  
+	/***** 02/10/2002 ****/
+        integer box[4];
+       
+        box[0]= Min(XDouble2Pixel(bbox[0]),XDouble2Pixel(bbox[2])); 
+        box[2]= Max(XDouble2Pixel(bbox[0]),XDouble2Pixel(bbox[2]));
+        box[1]= Min(YDouble2Pixel(bbox[1]),YDouble2Pixel(bbox[3])); 
+        box[3]= Max(YDouble2Pixel(bbox[1]),YDouble2Pixel(bbox[3]));
+       
+        
+        tmpsousfen= (sciPointObj *) sciGetSelectedSubWin (sciGetCurrentFigure());
+        psonstmp = sciGetSons (sciGetCurrentFigure());
+        while (psonstmp != (sciSons *) NULL)	
+          {  
+           if(sciGetEntityType (psonstmp->pointobj) == SCI_SUBWIN)
+             {
+                psousfen= (sciPointObj *)psonstmp->pointobj;
+                 sciSetSelectedSubWin(psousfen);
+                 box1[0]= Cscale.WIRect1[0]; 
+		 box1[2]= Cscale.WIRect1[2]+Cscale.WIRect1[0];
+		 box1[1]= Cscale.WIRect1[1]; 
+		 box1[3]= Cscale.WIRect1[3]+Cscale.WIRect1[1];
+                 
+                 if (sciIsAreaZoom(box,box1,section))
+                   { 
+                 bbox[0]= Min(XPixel2Double(section[0]),XPixel2Double(section[2])); 
+                 bbox[2]= Max(XPixel2Double(section[0]),XPixel2Double(section[2]));
+                 bbox[1]= Min(YPixel2Double(section[1]),YPixel2Double(section[3])); 
+                 bbox[3]= Max(YPixel2Double(section[1]),YPixel2Double(section[3])); 
+                 
+                     if (!(sciGetZooming(psousfen)))
+	               {
+		       sciSetZooming(psousfen, 1);
+		       pSUBWIN_FEATURE (psousfen)->FRect_kp[0]   = pSUBWIN_FEATURE (psousfen)->FRect[0];
+		       pSUBWIN_FEATURE (psousfen)->FRect_kp[1]   = pSUBWIN_FEATURE (psousfen)->FRect[1];
+		       pSUBWIN_FEATURE (psousfen)->FRect_kp[2]   = pSUBWIN_FEATURE (psousfen)->FRect[2];
+		       pSUBWIN_FEATURE (psousfen)->FRect_kp[3]   = pSUBWIN_FEATURE (psousfen)->FRect[3];
+                       }
+		      
+ 
+		     /** regraduation de l'axe des axes ***/
+		     fmin=  bbox[0]; 
+		     fmax=  bbox[2];
+		     C2F(graduate)(&fmin, &fmax,&lmin,&lmax,&deux,&dix,&min,&max,&puiss) ;
+                     pSUBWIN_FEATURE(psousfen)->axes.xlim[2]=puiss; 
+                     pSUBWIN_FEATURE (psousfen)->FRect[0]=lmin;  
+                     pSUBWIN_FEATURE (psousfen)->FRect[2]=lmax; 
+		     
+          
+		     fmin= bbox[1]; fmax= bbox[3];   
+		     C2F(graduate)(&fmin, &fmax,&lmin,&lmax,&deux,&dix,&min,&max,&puiss) ;
+		     pSUBWIN_FEATURE(psousfen)->axes.ylim[2]=puiss;
+                     pSUBWIN_FEATURE (psousfen)->FRect[1]=lmin;  
+                     pSUBWIN_FEATURE (psousfen)->FRect[3]=lmax; 
+		 }
+	     }     
+           psonstmp = psonstmp->pnext;
+          }
+          sciSetSelectedSubWin(tmpsousfen);
+          sciSetReplay(1);
+	  sciDrawObj(sciGetCurrentFigure());
+	  sciSetReplay(0);
+         }
+        else 
+           Tape_ReplayNewScale(" ",&ww,flag,PI0,aaint,PI0,PI0,bbox,PD0,PD0,PD0);
+	  
     }
 }
 
 
-void unzoom()
+extern void unzoom()
 {
   char driver[4];
-  integer ww,verbose=0,narg;
+  integer ww,verbose=0,narg; 
+  /** 17/09/2002 ***/  
+  double fmin,fmax,lmin,lmax;  
+  integer min,max,puiss,deux=2,dix=10;
+  sciPointObj *psousfen;
+  sciSons *psonstmp;  
+
+  
   GetDriver1(driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
   if (strcmp("Rec",driver) != 0) 
     {
@@ -1052,7 +1171,44 @@ void unzoom()
     {
       C2F(dr1)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
       C2F(dr1)("xget","window",&verbose,&ww,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-      Tape_ReplayUndoScale("v",&ww);
+      if (version_flag() == 0){ 
+         /***** 02/10/2002 ****/
+        psonstmp = sciGetSons (sciGetCurrentFigure());
+        while (psonstmp != (sciSons *) NULL)	
+          {  
+           if(sciGetEntityType (psonstmp->pointobj) == SCI_SUBWIN)
+             {
+                psousfen= (sciPointObj *)psonstmp->pointobj;
+        	if (sciGetZooming(psousfen))
+	            {
+		      sciSetZooming(psousfen, 0);
+		      pSUBWIN_FEATURE (psousfen)->FRect[0]   = pSUBWIN_FEATURE (psousfen)->FRect_kp[0];
+		      pSUBWIN_FEATURE (psousfen)->FRect[1]   = pSUBWIN_FEATURE (psousfen)->FRect_kp[1];
+		      pSUBWIN_FEATURE (psousfen)->FRect[2]   = pSUBWIN_FEATURE (psousfen)->FRect_kp[2];
+		      pSUBWIN_FEATURE (psousfen)->FRect[3]   = pSUBWIN_FEATURE (psousfen)->FRect_kp[3];
+		    }
+	  
+		/** regraduation de l'axe des axes ***/
+		fmin= pSUBWIN_FEATURE (psousfen)->FRect[0];
+		fmax= pSUBWIN_FEATURE (psousfen)->FRect[2]; 
+		C2F(graduate)(&fmin, &fmax,&lmin,&lmax,&deux,&dix,&min,&max,&puiss) ;
+		pSUBWIN_FEATURE(psousfen)->axes.xlim[2]=puiss; 
+          
+		fmin= pSUBWIN_FEATURE (psousfen)->FRect[1];
+		fmax= pSUBWIN_FEATURE (psousfen)->FRect[3]; 
+		C2F(graduate)(&fmin, &fmax,&lmin,&lmax,&deux,&dix,&min,&max,&puiss) ;
+		pSUBWIN_FEATURE(psousfen)->axes.ylim[2]=puiss;
+		/*****/  
+               }     
+              psonstmp = psonstmp->pnext;
+            } 
+        
+          sciSetReplay(1);
+	  sciDrawObj(sciGetCurrentFigure());
+	  sciSetReplay(0);
+    }
+   else
+    Tape_ReplayUndoScale("v",&ww);
     }
 }
 
@@ -1102,10 +1258,28 @@ void Gr_Rescale(logf, FRectI, Xdec, Ydec, xnax, ynax)
      integer *ynax;
 {
   double FRectO[4];
+  sciPointObj *psubwin; 
+  int i;
+
+  /** 18/06/2002 **/
+  if (version_flag() == 0){
+      psubwin = sciGetSelectedSubWin (sciGetCurrentFigure ());
+      for (i=0;i<4 ; i++)
+	pSUBWIN_FEATURE (psubwin)->axes.limits[i+1]=FRectI[i];}
+     
+    
   if (logf[0] == 'n') 
-    {
-      C2F(graduate)(FRectI,FRectI+2,FRectO,FRectO+2,xnax,xnax+1,Xdec,Xdec+1,Xdec+2);
-      FRectI[0]=FRectO[0];FRectI[2]=FRectO[2];
+    { 
+      if ((version_flag() != 0) || ( pSUBWIN_FEATURE (psubwin)->axes.limits[0] !=1))
+         {
+          C2F(graduate)(FRectI,FRectI+2,FRectO,FRectO+2,xnax,xnax+1,Xdec,Xdec+1,Xdec+2);
+          FRectI[0]=FRectO[0];FRectI[2]=FRectO[2];
+         }
+        
+      else
+      {
+         C2F(graduate)(FRectI,FRectI+2,FRectO,FRectO+2,xnax,xnax+1,Xdec,Xdec+1,Xdec+2);
+      }
     }
   else
     {
@@ -1115,22 +1289,21 @@ void Gr_Rescale(logf, FRectI, Xdec, Ydec, xnax, ynax)
     }
   if (logf[1] == 'n') 
     {
-      C2F(graduate)(FRectI+1,FRectI+3,FRectO+1,FRectO+3,ynax,ynax+1,Ydec,Ydec+1,Ydec+2);
-      FRectI[1]=FRectO[1];FRectI[3]=FRectO[3];
+     if ((version_flag() != 0) || ( pSUBWIN_FEATURE (psubwin)->axes.limits[0] !=1))
+         {
+            C2F(graduate)(FRectI+1,FRectI+3,FRectO+1,FRectO+3,ynax,ynax+1,Ydec,Ydec+1,Ydec+2);
+            FRectI[1]=FRectO[1];FRectI[3]=FRectO[3];
+         } 
+     else
+      {
+         C2F(graduate)(FRectI+1,FRectI+3,FRectO+1,FRectO+3,ynax,ynax+1,Ydec,Ydec+1,Ydec+2);
+      }
     }
   else
     {
       Ydec[0]=inint(FRectI[1]);Ydec[1]=inint(FRectI[3]);Ydec[2]=0;
     }
+
+
 }
 
-    
-
-
-
-
-
-
-
-
-
