@@ -1,7 +1,7 @@
 /*------------------------------------------------------------------------
  *    Graphic library
- *    Copyright (C) 1998-2000 Enpc/Jean-Philippe Chancelier
- *    jpc@cereve.enpc.fr 
+ *    Copyright (C) 1998-2001 Enpc/Jean-Philippe Chancelier
+ *    jpc@cermics.enpc.fr 
  --------------------------------------------------------------------------*/
 
 #include <string.h> /* in case of dbmalloc use */
@@ -9,10 +9,19 @@
 #include <stdio.h>
 #include "Math.h"
 #include "PloEch.h"
+#include "Entities.h"
+
+#ifdef __STDC__
+void wininfo(char *format,...);
+#else
+/*VARARGS0*/
+void wininfo();
+#endif    
 
 extern double C2F(dsort)();
-extern char GetDriver();
-extern int Check3DPlots();
+extern char GetDriver(void);
+extern int Check3DPlots(char *, integer *);
+extern int version_flag();
 
 /** like GEOX or GEOY in PloEch.h but we keep values in xx1 and yy1 for finite check **/
 
@@ -60,61 +69,31 @@ static void dbox __PARAMS((void));
  *     
  *  <-- The arguments are not modified 
  *-------------------------------------------------------------------------*/
-int C2F(plot3d)(x,y,z,p,q,teta,alpha,legend,flag,bbox,lstr)
-     double x[],y[],z[],bbox[];
-     integer *p,*q;
-     double *teta,*alpha;
-     integer flag[];
-     char legend[];
-     integer lstr;
+int C2F(plot3d)(double *x, double *y, double *z, integer *p, integer *q, double *teta, double *alpha, char *legend, integer *flag, double *bbox, integer lstr)
 {
   C2F(plot3dg)("plot3d",DPoints,x,y,z,p,q,teta,alpha,legend,flag,bbox);
   return(0);
 }
 
-int C2F(plot3d1)(x,y,z,p,q,teta,alpha,legend,flag,bbox,lstr)
-     double x[],y[],z[],bbox[];
-     integer *p,*q;
-     double *teta,*alpha;
-     integer flag[];
-     char legend[];
-     integer lstr;
+int C2F(plot3d1)(double *x, double *y, double *z, integer *p, integer *q, double *teta, double *alpha, char *legend, integer *flag, double *bbox, integer lstr)
 {
   C2F(plot3dg)("plot3d1",DPoints1,x,y,z,p,q,teta,alpha,legend,flag,bbox);
   return(0);
 }
 
-int C2F(fac3d)(x,y,z,cvect,p,q,teta,alpha,legend,flag,bbox,lstr)
-     double x[],y[],z[],bbox[];
-     integer *p,*q;
-     double *teta,*alpha;
-     integer flag[],*cvect;
-     char legend[];
-     integer lstr;
+int C2F(fac3d)(double *x, double *y, double *z, integer *cvect, integer *p, integer *q, double *teta, double *alpha, char *legend, integer *flag, double *bbox, integer lstr)
 {
   C2F(fac3dg)("fac3d",0,x,y,z,cvect,p,q,teta,alpha,legend,flag,bbox);
   return(0);
 }
 
-int C2F(fac3d1)(x,y,z,cvect,p,q,teta,alpha,legend,flag,bbox,lstr)
-     double x[],y[],z[],bbox[];
-     integer *p,*q;
-     double *teta,*alpha;
-     integer flag[],*cvect;
-     char legend[];
-     integer lstr;
+int C2F(fac3d1)(double *x, double *y, double *z, integer *cvect, integer *p, integer *q, double *teta, double *alpha, char *legend, integer *flag, double *bbox, integer lstr)
 {
   C2F(fac3dg)("fac3d1",1,x,y,z,cvect,p,q,teta,alpha,legend,flag,bbox);
   return(0);
 }
 
-int C2F(fac3d2)(x,y,z,cvect,p,q,teta,alpha,legend,flag,bbox,lstr)
-     double x[],y[],z[],bbox[];
-     integer *p,*q;
-     double *teta,*alpha;
-     integer flag[],*cvect;
-     char legend[];
-     integer lstr;
+int C2F(fac3d2)(double *x, double *y, double *z, integer *cvect, integer *p, integer *q, double *teta, double *alpha, char *legend, integer *flag, double *bbox, integer lstr)
 {
   C2F(fac3dg)("fac3d2",2,x,y,z,cvect,p,q,teta,alpha,legend,flag,bbox);
   return(0);
@@ -126,15 +105,7 @@ int C2F(fac3d2)(x,y,z,cvect,p,q,teta,alpha,legend,flag,bbox,lstr)
  *
  */
 
-static void C2F(plot3dg)(name, func, x, y, z, p, q, teta, alpha, legend, flag, bbox)
-     char *name;
-     int (*func)();
-     double *x,*y,*z;
-     integer *p,*q;
-     double *teta, *alpha;
-     char *legend;
-     integer *flag;
-     double *bbox;
+static void C2F(plot3dg)(char *name, int (*func) (/* ??? */), double *x, double *y, double *z, integer *p, integer *q, double *teta, double *alpha, char *legend, integer *flag, double *bbox)
 {
   static integer InsideU[4],InsideD[4],fg,fg1,dc;
   /* solid = color of 3D frame */
@@ -145,7 +116,7 @@ static void C2F(plot3dg)(name, func, x, y, z, p, q, teta, alpha, legend, flag, b
   static double zmin,zmax;
   integer i,j;
   /** If Record is on **/
-  if (GetDriver()=='R') 
+  if (GetDriver()=='R' && version_flag() != 0) 
     StorePlot3D(name,x,y,z,p,q,teta,alpha,legend,flag,bbox);
 
   C2F(dr)("xget","foreground",&verbose,&fg,&narg, PI0, PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
@@ -277,20 +248,7 @@ static void C2F(plot3dg)(name, func, x, y, z, p, q, teta, alpha, legend, flag, b
 }
 
 
-static void C2F(fac3dg)(name, iflag, x, y, z, cvect, p, q, teta, alpha, legend, flag, bbox)
-     char *name;
-     int iflag;
-     double *x;
-     double *y;
-     double *z;
-     integer *cvect;
-     integer *p;
-     integer *q;
-     double *teta;
-     double *alpha;
-     char *legend;
-     integer *flag;
-     double *bbox;
+static void C2F(fac3dg)(char *name, int iflag, double *x, double *y, double *z, integer *cvect, integer *p, integer *q, double *teta, double *alpha, char *legend, integer *flag, double *bbox)
 {
   static integer InsideU[4],InsideD[4],fg1;
   integer polysize,npoly,whiteid,verbose=0,narg;
@@ -300,7 +258,7 @@ static void C2F(fac3dg)(name, iflag, x, y, z, cvect, p, q, teta, alpha, legend,
   static double zmin,zmax;
   integer i;
   /** If Record is on **/
-  if (GetDriver()=='R') 
+  if (GetDriver()=='R' && version_flag() != 0) 
     StoreFac3D(name,x,y,z,cvect,p,q,teta,alpha,legend,flag,bbox);
 
   if (flag[1]!=1 && flag[1] != 0 && flag[1]!=3 && flag[1]!=5)
@@ -480,12 +438,7 @@ static void C2F(fac3dg)(name, iflag, x, y, z, cvect, p, q, teta, alpha, legend,
  *  returns in (polyx, polyy) the polygon for one facet of the surface 
  *--------------------------------------------------------------------*/
 
-int DPoints1(polyx, polyy, fill, whiteid, zmin, zmax, x, y, z, i, j, jj1, p,dc,fg)
-     integer *polyx, *polyy;
-     integer *fill, whiteid;
-     double zmin, zmax;
-     double *x, *y, *z;
-     integer i, j, jj1, *p, dc,fg;
+int DPoints1(integer *polyx, integer *polyy, integer *fill, integer whiteid, double zmin, double zmax, double *x, double *y, double *z, integer i, integer j, integer jj1, integer *p, integer dc, integer fg)
 {
   polyx[  5*jj1] =PGEOX(x[i]  ,y[j]  ,z[i+(*p)*j]);
   if ( finite(xx1)==0 )return(0);
@@ -521,10 +474,7 @@ int DPoints1(polyx, polyy, fill, whiteid, zmin, zmax, x, y, z, i, j, jj1, p,dc,f
   
 }
 
-int DPoints(polyx, polyy, fill, whiteid, zmin, zmax, x, y, z, i, j, jj1, p,dc,fg)
-     integer *polyx, *polyy, *fill, whiteid;
-     double zmin, zmax, *x,*y, *z;
-     integer i,j,jj1,*p,dc,fg;
+int DPoints(integer *polyx, integer *polyy, integer *fill, integer whiteid, double zmin, double zmax, double *x, double *y, double *z, integer i, integer j, integer jj1, integer *p, integer dc, integer fg)
 {
 #ifdef lint
   whiteid,fill[0],zmin,zmax;
@@ -561,13 +511,7 @@ int DPoints(polyx, polyy, fill, whiteid, zmin, zmax, x, y, z, i, j, jj1, p,dc,fg
  * param3d function 
  *-------------------------------------------------------------------*/
 
-int C2F(param3d)(x,y,z,n,teta,alpha,legend,flag,bbox,lstr)
-     double x[],y[],z[],bbox[];
-     integer *n;
-     double *teta,*alpha;
-     integer *flag;
-     char legend[];
-     integer lstr;
+int C2F(param3d)(double *x, double *y, double *z, integer *n, double *teta, double *alpha, char *legend, integer *flag, double *bbox, integer lstr)
 {
   static integer InsideU[4],InsideD[4];
   static double xbox[8],ybox[8],zbox[8];
@@ -576,7 +520,7 @@ int C2F(param3d)(x,y,z,n,teta,alpha,legend,flag,bbox,lstr)
   static integer *xm,*ym;
   integer verbose=0,xz[10],narg,fg1;
   /** If Record is on **/
-  if (GetDriver()=='R') 
+  if (GetDriver()=='R' && version_flag() != 0) 
     StoreParam3D("param3d",x,y,z,n,teta,alpha,legend,flag,bbox);
   C2F(dr)("xget","dashes",&verbose,xz,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   style[0]= xz[0];
@@ -655,13 +599,7 @@ int C2F(param3d)(x,y,z,n,teta,alpha,legend,flag,bbox,lstr)
  * param3d1 function 
  *-------------------------------------------------------------------*/
 
-int C2F(param3d1)(x,y,z,m,n,iflag,colors,teta,alpha,legend,flag,bbox,lstr)
-     double x[],y[],z[],bbox[];
-     integer *m,*n,*colors,*iflag;
-     double *teta,*alpha;
-     integer *flag;
-     char legend[];
-     integer lstr;
+int C2F(param3d1)(double *x, double *y, double *z, integer *m, integer *n, integer *iflag, integer *colors, double *teta, double *alpha, char *legend, integer *flag, double *bbox, integer lstr)
 {
   static integer InsideU[4],InsideD[4];
   static double xbox[8],ybox[8],zbox[8];
@@ -670,7 +608,7 @@ int C2F(param3d1)(x,y,z,m,n,iflag,colors,teta,alpha,legend,flag,bbox,lstr)
   static integer *xm,*ym;
   integer verbose=0,xz[10],narg,fg1,cur;
   /** If Record is on **/
-  if (GetDriver()=='R') 
+  if (GetDriver()=='R' && version_flag() != 0) 
     StoreParam3D1("param3d1",x,y,z,m,n,iflag,colors,teta,alpha,legend,flag,bbox);
   C2F(dr)("xget","dashes",&verbose,xz,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   style[0]= xz[0];
@@ -755,8 +693,7 @@ int C2F(param3d1)(x,y,z,m,n,iflag,colors,teta,alpha,legend,flag,bbox,lstr)
  * box3d 
  *-------------------------------------------------------------------*/
 
-int C2F(box3d)(xbox,ybox,zbox)
-     double xbox[8],ybox[8],zbox[8];
+int C2F(box3d)(double *xbox, double *ybox, double *zbox)
 {
   static integer InsideU[4],InsideD[4],flag[]={1,1,3},verbose=0,fg,narg,fg1;
   /** Calcule l' Enveloppe Convexe de la boite **/
@@ -783,9 +720,7 @@ int C2F(box3d)(xbox,ybox,zbox)
  * 3d geometric transformation 
  *-------------------------------------------------------------------*/
 
-int C2F(geom3d)(x,y,z,n)
-     double x[],y[],z[];
-     integer *n;
+int C2F(geom3d)(double *x, double *y, double *z, integer *n)
 {
   integer j;
   for ( j =0 ; j < (*n) ; j++)	 
@@ -806,13 +741,7 @@ int C2F(geom3d)(x,y,z,n)
  * functions for 3D scales 
  *-------------------------------------------------------------------*/
 
-void SetEch3d(xbox, ybox, zbox, bbox, teta, alpha)
-     double *xbox;
-     double *ybox;
-     double *zbox;
-     double *bbox;
-     double *teta;
-     double *alpha;
+void SetEch3d(double *xbox, double *ybox, double *zbox, double *bbox, double *teta, double *alpha)
 {
   SetEch3d1(xbox,ybox,zbox,bbox,teta,alpha,1L);
 }
@@ -822,14 +751,7 @@ void SetEch3d(xbox, ybox, zbox, bbox, teta, alpha)
  * if flag==0      we only change m without changing scales 
  */
 
-void SetEch3d1(xbox, ybox, zbox, bbox, teta, alpha, flag)
-     double *xbox;
-     double *ybox;
-     double *zbox;
-     double *bbox;
-     double *teta;
-     double *alpha;
-     integer flag;
+void SetEch3d1(double *xbox, double *ybox, double *zbox, double *bbox, double *teta, double *alpha, integer flag)
 {
   double xmmin,ymmax,xmmax,ymmin,FRect[4],WRect[4],ARect[4];
   integer ib;
@@ -956,11 +878,7 @@ void SetEch3d1(xbox, ybox, zbox, bbox, teta, alpha, flag)
  * constituent le triedre dans les tableaux xbox et ybox 
  *-----------------------------------------------------------------*/ 
 
-void DrawAxis(xbox, ybox, Indices, style)
-     double *xbox;
-     double *ybox;
-     integer *Indices;
-     integer style;
+void DrawAxis(double *xbox, double *ybox, integer *Indices, integer style)
 {
   integer ixbox[6],iybox[6],npoly=6,lstyle[6],verbose=0,narg;
   integer i,iflag=0;
@@ -984,14 +902,7 @@ void DrawAxis(xbox, ybox, Indices, style)
  * qui sont sur les 2 tri\`edres a l'interieur de l'enveloppe convexe
  *---------------------------------------------------------------------*/
 
-void Convex_Box(xbox, ybox, InsideU, InsideD, legend, flag, bbox)
-     double *xbox;
-     double *ybox;
-     integer *InsideU;
-     integer *InsideD;
-     char *legend;
-     integer *flag;
-     double *bbox;
+void Convex_Box(double *xbox, double *ybox, integer *InsideU, integer *InsideD, char *legend, integer *flag, double *bbox)
 {
   double xmaxi;
   integer ixbox[8],iybox[8];
@@ -1088,13 +999,7 @@ void Convex_Box(xbox, ybox, InsideU, InsideD, legend, flag, bbox)
 /** (ixbox,iybox) : Coordonnees des points de l'envelloppe cvxe en pixel **/
 /** xind : indices des points de l'enveloppe cvxe ds xbox et ybox **/
 
-void AxesStrings(axflag, ixbox, iybox, xind, legend, bbox)
-     integer axflag;
-     integer *ixbox;
-     integer *iybox;
-     integer *xind;
-     char *legend;
-     double *bbox;
+void AxesStrings(integer axflag, integer *ixbox, integer *iybox, integer *xind, char *legend, double *bbox)
 {
   integer verbose=0,narg,xz[2];
   integer iof;
@@ -1227,11 +1132,7 @@ void AxesStrings(axflag, ixbox, iybox, xind, legend, bbox)
   FREE(loc);
 }
 
-void MaxiInd(vect, n, ind, maxi)
-     double *vect;
-     integer n;
-     integer *ind;
-     double maxi;
+void MaxiInd(double *vect, integer n, integer *ind, double maxi)
 {
   integer i ;
   if ( *ind+1 < n)
@@ -1243,10 +1144,7 @@ void MaxiInd(vect, n, ind, maxi)
 /* renvoit les indices des points voisins de ind1 sur la face haute 
    de la boite  */
 
-void UpNext(ind1, ind2, ind3)
-     integer ind1;
-     integer *ind2;
-     integer *ind3;
+void UpNext(integer ind1, integer *ind2, integer *ind3)
 {
   *ind2 = ind1+1;
   *ind3 = ind1-1;
@@ -1254,10 +1152,7 @@ void UpNext(ind1, ind2, ind3)
   if (*ind3 == 3) *ind3 = 7;
 }
 
-void DownNext(ind1, ind2, ind3)
-     integer ind1;
-     integer *ind2;
-     integer *ind3;
+void DownNext(integer ind1, integer *ind2, integer *ind3)
 {
   *ind2 = ind1+1;
   *ind3 = ind1-1;
@@ -1266,14 +1161,7 @@ void DownNext(ind1, ind2, ind3)
 }
 
 
-void TDAxis(flag, FPval, LPval, nax, FPoint, LPoint, Ticsdir)
-     integer flag;
-     double FPval;
-     double LPval;
-     integer *nax;
-     integer *FPoint;
-     integer *LPoint;
-     integer *Ticsdir;
+void TDAxis(integer flag, double FPval, double LPval, integer *nax, integer *FPoint, integer *LPoint, integer *Ticsdir)
 {
   char fornum[100];
   integer i,barlength;
@@ -1323,14 +1211,7 @@ void TDAxis(flag, FPval, LPval, nax, FPoint, LPoint, Ticsdir)
 }
 
 
-void C2F(TDdrawaxis)(size, FPval, LPval, nax, FPoint, LPoint, Ticsdir)
-     double size;
-     double FPval;
-     double LPval;
-     integer *nax;
-     integer *FPoint;
-     integer *LPoint;
-     integer *Ticsdir;
+void C2F(TDdrawaxis)(double size, double FPval, double LPval, integer *nax, integer *FPoint, integer *LPoint, integer *Ticsdir)
 { 
   integer i;
   double dx,dy,ticsx,ticsy;
@@ -1361,12 +1242,7 @@ void C2F(TDdrawaxis)(size, FPval, LPval, nax, FPoint, LPoint, Ticsdir)
 
 /** Returns the [x,y,z] values of a pointeger given its xbox or ybox indices **/
 
-void BBoxToval(x, y, z, ind, bbox)
-     double *x;
-     double *y;
-     double *z;
-     integer ind;
-     double *bbox;
+void BBoxToval(double *x, double *y, double *z, integer ind, double *bbox)
 {
   switch ( ind)
     {
@@ -1388,25 +1264,41 @@ void BBoxToval(x, y, z, ind, bbox)
 /** Changement interactif de 3d **/
 static double theta,alpha;
 
-void I3dRotation()
+void I3dRotation(void)
 {
   char driver[4];
   integer flag[3],pixmode,alumode,verbose=0,narg,ww;
   static integer iflag[]={0,0,0,0};
   double xx,yy;
   double theta0,alpha0;
+  static integer modes[]={1,0};/* for xgemouse only get mouse mouvement*/ 
+  sciSons *psonstmp;
+  sciPointObj *psubwin, *tmpsubwin, *psurface; 
+  integer xr, yr;
+
+
   C2F(dr1)("xget","window",&verbose,&ww,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-  if ( Check3DPlots("v",&ww) == 0) 
-    {
-      wininfo("No 3d recorded plots in your graphic window");
-      return;
-    }
+  if (version_flag() != 0) {
+    if ( Check3DPlots("v",&ww) == 0) 
+      {
+	wininfo("No 3d recorded plots in your graphic window");
+	return;
+      }
+  }
+  else {
+    if ( !Check3DObjs()) 
+      {
+	wininfo("No 3d entities in your graphic window");
+	return;
+      }
+  }
   xx=1.0/Abs(Cscale.frect[0]-Cscale.frect[2]);
   yy=1.0/Abs(Cscale.frect[1]-Cscale.frect[3]);
   C2F(dr)("xget","pixmap",&verbose,&pixmode,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   C2F(dr)("xget","alufunction",&verbose,&alumode,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+
   GetDriver1(driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
-  if (strcmp("Rec",driver) != 0) 
+  if (strcmp("Rec",driver) != 0 && version_flag() !=0) 
     {
       Scistring("\n Use the Rec driver for 3f Rotation " );
       return;
@@ -1419,13 +1311,16 @@ void I3dRotation()
 #ifdef WIN32
       SetWinhdc();
       SciMouseCapture();
-      C2F(SetDriver)("Int",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
+      if (version_flag() != 0)
+	C2F(SetDriver)("Int",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
 #else
-      C2F(SetDriver)("X11",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
+      if (version_flag() != 0)
+	C2F(SetDriver)("X11",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
 #endif
       if ( pixmode == 0 ) C2F(dr1)("xset","alufunction",(in=6,&in),PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
       C2F(dr1)("xclick","one",&ibutton,&iwait,&istr,PI0,PI0,PI0,&x0,&yy0,PD0,PD0,0L,0L);
-      C2F(dr1)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+      if (version_flag() != 0)
+	C2F(dr1)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
       theta=Cscale.theta ;
       alpha=Cscale.alpha ;
 
@@ -1435,15 +1330,57 @@ void I3dRotation()
       theta0=theta;
       alpha0=alpha;
       ibutton=-1;
+      if (version_flag() == 0)
+	{
+	  tmpsubwin = (sciPointObj *) sciGetSelectedSubWin (sciGetCurrentFigure ());          
+	  xr=inint( ((double) Cscale.wdim[0]*pSUBWIN_FEATURE(tmpsubwin)->WRect[2]*
+		     (1-(Cscale.axis[0]+Cscale.axis[1])))*(x0) + 
+		    (((double) Cscale.wdim[0]*pSUBWIN_FEATURE(tmpsubwin)->WRect[2])*(Cscale.axis[0])
+		     +pSUBWIN_FEATURE(tmpsubwin)->WRect[0]*((double)Cscale.wdim[0])));
+	  yr=inint(((double) Cscale.wdim[1]*pSUBWIN_FEATURE(tmpsubwin)->WRect[3]*
+		    (1-(Cscale.axis[2]+Cscale.axis[3])))*(-(yy0)+1) + 
+		   (((double) Cscale.wdim[1]*pSUBWIN_FEATURE(tmpsubwin)->WRect[3])*(Cscale.axis[2])
+		    + pSUBWIN_FEATURE(tmpsubwin)->WRect[1]*((double)Cscale.wdim[1])));
+          if (pFIGURE_FEATURE((sciPointObj *)sciGetCurrentFigure())->rotstyle == 0)    
+	    {
+	      psubwin = (sciPointObj *)CheckClickedSubwin(xr,yr);
+	      psurface = (sciPointObj *) sciGetSurface(psubwin); 
+	      if (psurface != (sciPointObj *)NULL)
+		{
+		  sciSetSelectedSubWin (psubwin);
+		  theta0 =  pSURFACE_FEATURE (psurface)-> theta; 
+		  alpha0 =  pSURFACE_FEATURE (psurface)-> alpha;
+		}
+	      else 
+		{
+		  wininfo("Is not a 3d Entity");
+		  if ( pixmode == 0) 
+		    C2F(dr1)("xset","alufunction",(in=3,&in),PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+		  return;
+		}
+	    }
+          else
+	    {                  
+	      psonstmp = sciGetLastSons (sciGetCurrentFigure());  
+	      while (psonstmp != (sciSons *) NULL)
+		{  
+		  if(sciGetEntityType (psonstmp->pointobj) == SCI_SUBWIN) 
+		    break;   
+		  psonstmp = psonstmp->pnext;
+		} 
+	      sciSetSelectedSubWin (psonstmp->pointobj);
+	    } 
+	}
       while ( ibutton == -1 ) 
 	{
 	  /* dessin d'un rectangle */
-	  theta= theta0 - 180.0*(x-x0);alpha=alpha0 + 180.0*(y-yy0);
+	  theta= ((int)(theta0 - 180.0*(x-x0)) % 360);
+	  alpha= ((int)(alpha0 + 180.0*(y-yy0)) % 360);
 	  wininfo("alpha=%.1f,theta=%.1f",alpha,theta); 
 	  if ( pixmode == 1) C2F(dr1)("xset","wwpc",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
 	  dbox();
 	  if ( pixmode == 1) C2F(dr1)("xset","wshow",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-	    C2F(dr1)("xgetmouse","one",&ibutton,&iwait,PI0,PI0,PI0,PI0,&xl, &yl,PD0,PD0,0L,0L);
+	    C2F(dr1)("xgetmouse","one",&ibutton,&iwait,PI0,PI0,modes,PI0,&xl, &yl,PD0,PD0,0L,0L);
 	    /* effacement du rectangle */
 	    dbox();
 	    xx=1.0/Abs(Cscale.frect[0]-Cscale.frect[2]);
@@ -1453,14 +1390,33 @@ void I3dRotation()
 	}
       if ( pixmode == 0) C2F(dr1)("xset","alufunction",(in=3,&in),PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
       C2F(SetDriver)(driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
-      C2F(dr1)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+      if (version_flag() != 0)
+	C2F(dr1)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
       C2F(dr1)("xget","window",&verbose,&ww,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
       C2F(dr1)("xset","alufunction",&alumode,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
 #ifdef WIN32
       ReleaseWinHdc();
       SciMouseRelease();
 #endif
-      Tape_ReplayNewAngle("v",&ww,PI0,PI0,iflag,flag,PI0,&theta,&alpha,bbox,PD0);
+      if (version_flag() != 0)
+	Tape_ReplayNewAngle("v",&ww,PI0,PI0,iflag,flag,PI0,&theta,&alpha,bbox,PD0);
+      else
+	{  
+          if (pFIGURE_FEATURE((sciPointObj *)sciGetCurrentFigure())->rotstyle == 0)         
+	    Obj_RedrawNewAngle(psubwin,theta,alpha);
+	  else
+            { 
+	      psonstmp = sciGetSons (sciGetCurrentFigure());  
+	      while (psonstmp != (sciSons *) NULL)	
+		{  
+		  if(sciGetEntityType (psonstmp->pointobj) == SCI_SUBWIN) 
+		    Obj_RedrawNewAngle(psonstmp->pointobj,theta,alpha);
+		  psonstmp = psonstmp->pnext;
+		} 
+            }
+	  sciRedrawFigure(); 
+	  sciSetSelectedSubWin (tmpsubwin);
+	}
     }
 }
 
@@ -1471,7 +1427,7 @@ void I3dRotation()
  * inside dbox
  */
 
-static void dbox()
+static void dbox(void)
 {
   double xbox[8],ybox[8],zbox[8];
 #ifdef WIN32
@@ -1492,13 +1448,7 @@ static void dbox()
  *
  *******************************************************************************/
 
-int C2F(fac3d3)(x,y,z,cvect,p,q,teta,alpha,legend,flag,bbox,lstr)
-     double x[],y[],z[],bbox[];
-     integer *p,*q;
-     double *teta,*alpha;
-     integer flag[],*cvect;
-     char legend[];
-     integer lstr;
+int C2F(fac3d3)(double *x, double *y, double *z, integer *cvect, integer *p, integer *q, double *teta, double *alpha, char *legend, integer *flag, double *bbox, integer lstr)
 {
   C2F(fac3dg)("fac3d3",3,x,y,z,cvect,p,q,teta,alpha,legend,flag,bbox);
   return(0);
@@ -1508,13 +1458,7 @@ int C2F(fac3d3)(x,y,z,cvect,p,q,teta,alpha,legend,flag,bbox,lstr)
  *This function sorts the vertices such that the color value is in decreasing order
  *---------------------------------------------------------------------------------*/
 
-int  triangleSort(polyxin,polyyin,fillin,polyx,polyy,fill)
-     integer *polyxin;
-     integer *polyyin;
-     integer *fillin;
-     integer *polyx;
-     integer *polyy;
-     integer *fill;
+int  triangleSort(integer *polyxin, integer *polyyin, integer *fillin, integer *polyx, integer *polyy, integer *fill)
 { 
   integer tmp,k;
   for (k=0;k<3;k++) {polyx[k]=polyxin[k]; polyy[k]=polyyin[k]; fill[k]=fillin[k];}
@@ -1546,13 +1490,7 @@ int  triangleSort(polyxin,polyyin,fillin,polyx,polyy,fill)
  *       routines 
  *-----------------------------------------------------------------------*/
 
-int shade(polyx,polyy,fill,polysize,flag)
-    
-     integer *polyx;
-     integer *polyy;
-     integer *fill;
-     integer polysize;
-     integer flag;
+int shade(integer *polyx, integer *polyy, integer *fill, integer polysize, integer flag)
 {
    integer px[5],py[5],fil[4],is[3],ie[3],n[3];
    integer npoly=1,k,col,cols,psize,i,s,e;
