@@ -1,7 +1,7 @@
 /*------------------------------------------------------------------------
  *    Graphic library
- *    Copyright (C) 1998-2000 Enpc/Jean-Philippe Chancelier
- *    jpc@cereve.enpc.fr 
+ *    Copyright (C) 1998-2001 Enpc/Jean-Philippe Chancelier
+ *    jpc@cermics.enpc.fr 
  --------------------------------------------------------------------------*/
 /*------------------------------------------------------------------------
  * exported function : int C2F(xloadplots) (fname1,lvx)
@@ -22,7 +22,7 @@
 #	ifndef __ABSC__
 #   	include <sys/types.h>	/* for <netinet/in.h> on some systems */
 #       endif
-#   	if !(defined __MSC__) && !(defined __ABSC__)
+#   	if !(defined __MSC__) && !(defined __ABSC__) && !(defined __MINGW32__)
 #          include <netinet/in.h>	/* for htonl() */
 #   	endif
 #	endif
