@@ -1,11 +1,10 @@
 /* C code produced by gperf version 2.7.1 (19981006 egcs) */
 /* Command-line: gperf -C -t -k 2,3,4,$ Xcall.gperf  */
-
 /*------------------------------------------------------------------------
-    Graphic library for 2D and 3D plotting 
-    Copyright (C) 1998 Chancelier Jean-Philippe
-    jpc@cergrene.enpc.fr 
- --------------------------------------------------------------------------*/
+   *  Graphic library for 2D and 3D plotting 
+   *  Copyright (C) 1998-2001 Chancelier Jean-Philippe
+   * jpc@cermics.enpc.fr 
+   --------------------------------------------------------------------------*/
 #include <string.h>
 #include <stdio.h>
 
@@ -26,7 +25,12 @@
 #include "periFig.h"
 #include "periGif.h"
 
+/* should be removed when scilab will be full ansi C */
+
+#ifndef __STDC__ 
 #define const 
+#endif 
+
 
 /*---------------------------------------------------------------
  * The basic graphic driver is X11 
@@ -40,19 +44,9 @@
 
 static void C2F(all)();
 
-static void C2F(vide)(v1, v2, v3, v4, v5, v6, v7, dv1, dv2, dv3, dv4)
-     char *v1;
-     integer *v2;
-     integer *v3;
-     integer *v4;
-     integer *v5;
-     integer *v6;
-     integer *v7;
-     double *dv1;
-     double *dv2;
-     double *dv3;
-     double *dv4;
-{}
+static void C2F(vide)(char *v1,integer * v2,integer * v3,integer * v4,integer * v5,integer * v6,
+		      integer *v7,double * dv1,double * dv2,double * dv3,double * dv4) {}
+
 typedef void (*func)();
 typedef void (function)() ;
 struct funreplace { char *name; func action[4]; };
@@ -69,8 +63,8 @@ __inline
 #endif
 static unsigned int
 hash (str, len)
-     char *str;
-     unsigned int len;
+     register const char *str;
+     register unsigned int len;
 {
   static const unsigned char asso_values[] =
     {
@@ -201,10 +195,8 @@ xcall_in_word_set (str, len)
 static char DriverName[]= "Rec";
 static int  DriverId = 0;
 
-void C2F(SetDriver)(x0, v2, v3, v4, v5, v6, v7, dv1, dv2, dv3, dv4)
-     char *x0;
-     integer *v2,*v3,*v4,*v5,*v6,*v7;
-     double *dv1,*dv2,*dv3,*dv4;
+void C2F(SetDriver)(char *x0, integer *v2,integer * v3,integer * v4, integer *v5,integer * v6,
+		    integer * v7,double * dv1,double * dv2,double * dv3,double * dv4)
 {
   switch (x0[0])
     {
@@ -225,8 +217,15 @@ void C2F(SetDriver)(x0, v2, v3, v4, v5, v6, v7, dv1, dv2, dv3, dv4)
       DriverId = 0;
       break;
     case 'P'  :
-      strcpy(DriverName,"Pos");
-      DriverId = 1;
+      if (x0[1] == 'P') {
+	strcpy(DriverName,"PPM");
+	DriverId = 3;
+	break;
+      }
+      else {
+ 	strcpy(DriverName,"Pos");
+ 	DriverId = 1;
+      }
       break;
     case 'F'  :
       strcpy(DriverName,"Fig");
@@ -244,10 +243,8 @@ void C2F(SetDriver)(x0, v2, v3, v4, v5, v6, v7, dv1, dv2, dv3, dv4)
     }
 }
 
-void GetDriver1(str, v2, v3, v4, v5, v6, v7, dv1, dv2, dv3, dv4)
-     char *str;
-     integer *v2,*v3,*v4,*v5,*v6,*v7;
-     double *dv1,*dv2,*dv3,*dv4;
+void GetDriver1(char *str, integer *v2,integer * v3,integer * v4, integer *v5,integer * v6,
+		    integer * v7,double * dv1,double * dv2,double * dv3,double * dv4)
 {
   strcpy(str,DriverName);
 }
@@ -261,12 +258,9 @@ int GetDriverId() { return DriverId;}
    dr has 2 last extra parametres to deal with the size of
    x0 and x1 */
 
-
-int C2F(dr)(x0,x1,x2,x3,x4,x5,x6,x7,dx1,dx2,dx3,dx4,lx0,lx1)
-     char x0[],x1[];
-     integer *x2,*x3,*x4,*x5,*x6,*x7;
-     integer lx0,lx1;
-     double *dx1,*dx2,*dx3,*dx4;
+int C2F(dr)(char x0[],char x1[],integer *x2,integer *x3,integer *x4,integer *x5,integer *x6,
+	    integer *x7,double *dx1,double *dx2,double *dx3,double *dx4,
+	    integer lx0, integer lx1)
 { 
 #ifdef WIN32
   if ( DriverId == 0 && DriverName[0] != 'I' ) 
@@ -282,13 +276,12 @@ int C2F(dr)(x0,x1,x2,x3,x4,x5,x6,x7,dx1,dx2,dx3,dx4,lx0,lx1)
 #else
       C2F(all)(x0,x1,x2,x3,x4,x5,x6,x7,dx1,dx2,dx3,dx4);
 #endif
-	return 0;
+  return 0;
 }
 
-static void C2F(all)(x0,x1,x2,x3,x4,x5,x6,x7,dx1,dx2,dx3,dx4)
-     char x0[],x1[];
-     integer *x2,*x3,*x4,*x5,*x6,*x7;
-     double *dx1,*dx2,*dx3,*dx4;
+static void C2F(all)(char x0[],char x1[],integer *x2,integer *x3,integer *x4,integer *x5,
+		     integer *x6,
+		     integer *x7,double *dx1,double *dx2,double *dx3,double *dx4)
 { 
   const struct funreplace *fr;
   fr=xcall_in_word_set(x0,strlen(x0));
@@ -302,8 +295,7 @@ static void C2F(all)(x0,x1,x2,x3,x4,x5,x6,x7,dx1,dx2,dx3,dx4)
     }
 }
 
-int C2F(foo_inttest)(x1)
-     int *x1;
+int C2F(foo_inttest)(int *x1)
 {
   sciprint("Value  of x1 = <%d>\r\n",*x1);
   return(0);
