@@ -1,7 +1,7 @@
 /*------------------------------------------------------------------------
  *    Graphic library
- *    Copyright (C) 1998-2000 Enpc/Jean-Philippe Chancelier
- *    jpc@cereve.enpc.fr 
+ *    Copyright (C) 1998-2001 Enpc/Jean-Philippe Chancelier
+ *    jpc@cermics.enpc.fr 
  --------------------------------------------------------------------------*/
 
 #include <stdio.h>
@@ -35,11 +35,7 @@ extern void sciqsort();
  * iord : 'i' or 'd' : increasind or decreasing sort 
  ******************************************************/
 
-int C2F(gsort)(xI,xD,ind,iflag,m,n,type,iord)
-     int *xI,*ind;
-     double *xD;
-     int *m,*n,*iflag;
-     char *type,*iord;
+int C2F(gsort)(int *xI, double *xD, int *ind, int *iflag, int *m, int *n, char *type, char *iord)
 {
   switch ( type[0])
     {
@@ -68,11 +64,7 @@ int C2F(gsort)(xI,xD,ind,iflag,m,n,type,iord)
 
 #ifndef TEST 
 
-void C2F(gsorts_old)(value,ptrv,m,n,res,ptrres,ierr,ind,iflag,type,iord)
-     int *value,*ptrv,*m,*n,*res,*ptrres,*ierr;
-     int *ind;
-     int *iflag;
-     char *type,*iord;     
+void C2F(gsorts_old)(int *value, int *ptrv, int *m, int *n, int *res, int *ptrres, int *ierr, int *ind, int *iflag, char *type, char *iord)
 {
   char **data;
   int i,nv;
@@ -88,7 +80,7 @@ void C2F(gsorts_old)(value,ptrv,m,n,res,ptrres,ierr,ind,iflag,type,iord)
     case 'c' :  CNAME(RowSort,char)(data,ind,*iflag,*m,*n,iord[0]);break;
     case 'l' :  
       if ( type[1] == 'r' ) 
-	CNAME(LexiRow,char)(data,ind,*iflag,*m,*n,iord[0]);
+	CNAME(LexiRow,char)((int **)data,ind,*iflag,*m,*n,iord[0]);
       else
 	CNAME(LexiCol,char)(data,ind,*iflag,*m,*n,iord[0]);
       break;
@@ -110,10 +102,7 @@ void C2F(gsorts_old)(value,ptrv,m,n,res,ptrres,ierr,ind,iflag,type,iord)
 
 #ifndef TEST 
 
-void C2F(gsorts)(data,ind,iflag,m,n,type,iord)
-     char **data;
-     int *m,*n,*ind,*iflag;
-     char *type,*iord;     
+void C2F(gsorts)(char **data, int *ind, int *iflag, int *m, int *n, char *type, char *iord)
 {
   switch ( type[0])
     {
@@ -121,7 +110,7 @@ void C2F(gsorts)(data,ind,iflag,m,n,type,iord)
     case 'c' :  CNAME(RowSort,char)(data,ind,*iflag,*m,*n,iord[0]);break;
     case 'l' :  
       if ( type[1] == 'r' ) 
-	CNAME(LexiRow,char)(data,ind,*iflag,*m,*n,iord[0]);
+	CNAME(LexiRow,char)((int **)data,ind,*iflag,*m,*n,iord[0]);
       else
 	CNAME(LexiCol,char)(data,ind,*iflag,*m,*n,iord[0]);
       break;
@@ -135,20 +124,27 @@ void C2F(gsorts)(data,ind,iflag,m,n,type,iord)
 /******************************************************
  * TEST 
  ******************************************************/
+#ifndef TEST 
 
-#ifdef TEST 
-
-
-main()
+void gsort_test_function()
 {
-  printf("Test for char \n");
-  CNAME(sorttest,char)() ;
   printf("Test for int \n");
   CNAME(sorttest,int)() ;
   printf("Test for double \n");
   CNAME(sorttest,double)() ;
+}
+
+#endif 
+
+
+#ifdef TEST 
+
+int main()
+{
+  gsort_test_function();
   return(0);
 }
+
 #endif
 
 
