@@ -4,8 +4,11 @@
  *    jpc@cereve.enpc.fr 
  --------------------------------------------------------------------------*/
 
+#ifndef PERIWIN_BCG 
+#define PERIWIN_BCG 
 #include <winuser.h>
 #define Window HWND
+/* typedef int (*EVTHANDLER) __PARAMS((int win,int x,int y,int ibut));*/
 
 struct BCG 
 { 
@@ -27,7 +30,7 @@ struct BCG
   int CurPattern;
   int CurColor;
   int CurPixmapStatus;
-  integer CurResizeStatus;
+  int CurResizeStatus;
   int CurVectorStyle;
   int CurDrawFunction;
   int ClipRegionSet;
@@ -48,6 +51,13 @@ struct BCG
   int NumBackground;  /* number of Background */
   int NumForeground; /* number of Foreground in the color table */
   int NumHidden3d;  /* color for hidden 3d facets **/
+  char EventHandler[25]; /* name of window event handler */
+  /* NG beg */
+  int CWindowWidthView;	 /** graphic window width **/
+  int CWindowHeightView;  /** graphic window height **/
+  sciPointObj *mafigure;  /* Entities root */
+  int graphicsversion;
+  /* NG end */
   /** win95 specific objects **/
   HPEN hPen ;  /** the current pen for graphic window **/
   HBRUSH hBrush; /** the current brush **/
@@ -56,6 +66,10 @@ struct BCG
 		     initgraphic **/
   SCROLLINFO vertsi;
   SCROLLINFO horzsi;
-  int CWindowWidthView ; /** graphic window width **/
-  int CWindowHeightView ; /** graphic window height **/
 }  ;
+
+
+extern struct BCG *GetWindowXgcNumber  (int i);
+
+#endif /* PERIWIN_BCG  */
+
