@@ -238,6 +238,11 @@ c     .  vector+eye
          go to 41
       elseif (mn2.eq.1) then
 c     .   vector+const
+         err=l1+mn1*(itr+1)-lstk(bot)
+         if(err.gt.0) then
+            call error(17)
+            return
+         endif
          call dadd(mn1,stk(l2),0,stk(l1),1)
          if(it2+2*it1.eq.1) call unsfdcopy(mn1,stk(l2+mn2),0,
      $        stk(l1+mn1),1)
@@ -246,6 +251,11 @@ c     .   vector+const
          istk(il1+3)=itr
       elseif (mn1.eq.1) then
 c     .  cst+vector
+         err=l1+mn2*(itr+1)-lstk(bot)
+         if(err.gt.0) then
+            call error(17)
+            return
+         endif
          cstr=stk(l1)
          csti=stk(l1+1)
          call unsfdcopy((it2+1)*mn2,stk(l2),1,stk(l1),1)
@@ -262,6 +272,11 @@ c     .  vector+vector
             call error(8)
             return
          endif
+         err=l1+mn1*(itr+1)-lstk(bot)
+         if(err.gt.0) then
+            call error(17)
+            return
+         endif
          call dadd(mn1,stk(l2),1,stk(l1),1)
          if(it2+2*it1.eq.1) then
             call unsfdcopy(mn1,stk(l2+mn1),1,stk(l1+mn1),1)
@@ -610,11 +625,13 @@ c     .  matrix*matrix
             return
          endif
          if(it1*it2.ne.1) then
-            call dmmul(stk(l1),m1,stk(l2),m2,stk(lr),m1,m1,n1,n2)
-            if(it1.eq.1) call dmmul(stk(l1+mn1),m1,stk(l2),m2
-     $           ,stk(lr+m1*n2),m1,m1,n1,n2)
-            if(it2.eq.1) call dmmul(stk(l1),m1,stk(l2+mn2),m2
-     $           ,stk(lr+m1*n2),m1,m1,n1,n2)
+*           remplacement de dmmul par dgemm (Bruno le 31/10/2001)
+            call dgemm('n','n',m1,n2,n1,1.d0,stk(l1),m1,stk(l2),m2,
+     $           0.d0,stk(lr),m1)
+            if(it1.eq.1) call dgemm('n','n',m1,n2,n1,1.d0,stk(l1+mn1),
+     $           m1,stk(l2),m2,0.d0,stk(lr+m1*n2),m1)
+            if(it2.eq.1) call dgemm('n','n',m1,n2,n1,1.d0,stk(l1),m1,
+     $           stk(l2+mn2),m2,0.d0,stk(lr+m1*n2),m1)      
          else
 c     .     a et a2 sont complexes
             call wmmul(stk(l1),stk(l1+mn1),m1,stk(l2),stk(l2
@@ -675,11 +692,13 @@ c     .  a/[] or []/a
             call error(14)
             return
          endif
-         if (m2 .eq. n2) fun = 1
-         if (m2 .ne. n2) fun = 4
-         fin = -1
          top = top+1
-         rhs = 2
+         rhs = 2        
+         call intslash('slash')
+         if (fin.ge.0) call putlhsvar()
+c         if (m2 .eq. n2) fun = 1
+c         if (m2 .ne. n2) fun = 4
+c         fin = -1
       else
 c     .  vector / cst
          if(m2.lt.0.and.mn1.ne.1) then 
@@ -773,11 +792,13 @@ c     .  a\[] or []\a
             call error(14)
             return
          endif
-         if (m1 .eq. n1) fun = 1
-         if (m1 .ne. n1) fun = 4
          top = top+1
-         fin = -2
-         rhs = 2
+         rhs = 2 
+         call intbackslash('backslash')
+         if (fin.ge.0) call putlhsvar()
+c         if (m1 .eq. n1) fun = 1
+c         if (m1 .ne. n1) fun = 4
+c         fin = -2
       else
 c     .  cst \ vector
          if(m1.lt.0.and.mn2.ne.1) then 
@@ -900,25 +921,25 @@ c
       if(it2.eq.0) then
          if(it1.eq.0) then
             call ddpow1(mn,stk(l1),inc1,stk(l2),inc2,
-     $           stk(lw),stk(lw+mn),1,err,itr)
+     $           stk(lw),stk(lw+mn),1,ierr,itr)
          else
             call wdpow1(mn,stk(l1),stk(l1+mn1),inc1,stk(l2),inc2,
-     $           stk(lw),stk(lw+mn),1,err)
+     $           stk(lw),stk(lw+mn),1,ierr)
          endif
       else
          if(it1.eq.0) then
             call dwpow1(mn,stk(l1),inc1,stk(l2),stk(l2+mn2),inc2,
-     &           stk(lw),stk(lw+mn),1,err)
+     &           stk(lw),stk(lw+mn),1,ierr)
          else
             call wwpow1(mn,stk(l1),stk(l1+mn1),inc1,stk(l2),stk(l2+mn2),
-     &           inc2,stk(lw),stk(lw+mn),1,err)
+     &           inc2,stk(lw),stk(lw+mn),1,ierr)
          endif
       endif
-      if(err.eq.1) then
+      if(ierr.eq.1) then
          call error(30)
          return
       endif
-      if(err.eq.2) then
+      if(ierr.eq.2) then
          if(ieee.eq.0) then
             call error(27)
             return
@@ -1100,13 +1121,12 @@ c     .     vect^scalar treated as  vect.^scalar (see matxpow)
       endif
 c     
       if (nexp.le.0) then
-         fun=10
-         fin=1
          rhs=1
-         call matlu
-         if(err.gt.0) return
+         call intinv('pow')
+         call putlhsvar()
+c         call matlu
+         if(err.gt.0.or.err1.gt.0) return
          nexp=-nexp
-         fun=0
       endif
       l2=l1+mn1*(it1+1)
 c     
@@ -2086,8 +2106,9 @@ c     .  arg2(:), just reshape to column vector
          istk(il1+1)=mn2
          istk(il1+2)=1
          istk(il1+3)=istk(il2+3)
+         l1=sadr(il1+4)
          call unsfdcopy(mn2*(it2+1),stk(l2),1,stk(l1),1)
-         lstk(top+1)=sadr(il1+4)+mn2*(it2+1)
+         lstk(top+1)=l1+mn2*(it2+1)
          return
       endif
 c     check and convert indices variable
@@ -2296,6 +2317,7 @@ c
 c     
       il2=iadr(lstk(top))
       if(istk(il2).lt.0) il2=iadr(istk(il2+1))
+  
       m2=istk(il2+1)
       n2=istk(il2+2)
       it2=istk(il2+3)
@@ -2306,6 +2328,11 @@ c
       il1=iadr(lstk(top))
       ilrs=il1
       if(istk(il1).lt.0) il1=iadr(istk(il1+1))
+      if (istk(il1).eq.10.or.istk(il1).eq.15) then
+         top=top0
+         fin=-fin
+         return
+      endif
       m1=istk(il1+1)
       n1=istk(il1+2)
       it1=istk(il1+3)
@@ -3072,6 +3099,10 @@ c     .  eye op b
             endif
             return
          endif
+         if (.true.) then 
+c           add explicit nan tests when requested 
+            call idcmp(stk(l1),stk(l2),mn1,istk(il1+3),op)
+         else
          do 132 i=0,mn1-1
             e1=stk(l1+i)
             e2=stk(l2+i)
@@ -3093,6 +3124,7 @@ c     for vc++ we add an explicit test for nan
                istk(il1+3+i)=0
             endif
  132     continue
+         endif
          lstk(top+1)=sadr(il1+3+mn1)
       endif
       return
