@@ -52,9 +52,9 @@ c     newfun clearfun  funptr  macr2lst setbpt delbpt dispbpt
 c     19      20       21       22       23     24      25
 c     funcprot whereis where   timer         havewindow stacksize
 c     26         27    28      29       30       31       32
-c     mtlb_mode  link     ulink  c_link addinter  fhelp  fapropos
+c     mtlb_mode  link     ulink  c_link addinter <free>   <free>
 c     33         34        35     36    37       38        39
-c     fclear    what    sciargs  chdir getcwd ieee typename
+c     fclear    what    sciargs  chdir getwd ieee typename
 c     40         41       42     43     44     45    46
 c     global   clearglobal isglobal gstacksize getdate intppty
 c     47         48          49        50        51       52
@@ -215,9 +215,9 @@ c     mtlb_mode
       goto 999
  630  call scidint("addinter")
       goto 999
- 640  call scifhelp("fhelp")
+ 640  return
       goto 999
- 650  call scifapr("fapropos")
+ 650  return
       goto 999
  660  call intclear("clear")
       goto 999
@@ -275,8 +275,6 @@ c     in scilab executable
  999  return
       end
 
-
-
       subroutine scilink(fname) 
 C     ================================================================
 C    link function  
@@ -370,9 +368,8 @@ C     ================================================================
       character*(*) fname
 cc    implicit undefined (a-z)
       include '../stack.h'
-      integer topk,iadr
-      logical getwsmat,checkrhs,getsmat,lib_cpp
-
+      integer topk,iadr,gettype
+      logical getwsmat,checkrhs,getsmat,lib_cpp,getscalar
       character strf*25, c_cpp*10
 
       iadr(l)=l+l-1
@@ -434,9 +431,19 @@ c
       strf(nlr2+1:nlr2+1)=char(0)
       top=top-1
 C     first argument 
-      if (.not.getwsmat(fname,topk,top,m1,n1,il1,ild1)) return
-      call addinter(istk(il1),istk(ild1),m1*n1,strf,
-     $     istk(il3),istk(ild3),m3*n3,c_cpp,lib_cpp,ierr)
+C     jpc on accepte un entier 
+      itop = gettype(top)
+      if ( itop .eq. 1 ) then 
+         if (.not.getscalar(fname,topk,top,il1)) return
+         ilib=int(stk(il1))
+         call addinter(ilib,iv,iv,iv,strf,
+     $        istk(il3),istk(ild3),m3*n3,c_cpp,lib_cpp,ierr)
+      else
+         if (.not.getwsmat(fname,topk,top,m1,n1,il1,ild1)) return
+         ilib=-1
+         call addinter(ilib,istk(il1),istk(ild1),m1*n1,strf,
+     $        istk(il3),istk(ild3),m3*n3,c_cpp,lib_cpp,ierr)
+      endif
       if(ierr.ne.0) then
          if (ierr.eq.-1) then
             call error(236)
@@ -494,10 +501,10 @@ cc    implicit undefined (a-z)
       integer topk,iadr
 c      integer m3,n3,lr3,nlr3,m2,n2,il2,ild2,m1,n1,il1,ild1
       integer ilib,iv ,l1
-      logical checkrhs,crebmat,getscalar,getsmat,cremat
+      logical checkrhs,checklhs,crebmat,getscalar,getsmat,cremat
       iadr(l)=l+l-1
       if (.not.checkrhs(fname,1,2)) return
-      if (.not.checkrhs(fname,1,2)) return
+      if (.not.checklhs(fname,1,2)) return
       topk=top
       if (rhs.eq.2) then 
          if(.not.getscalar(fname,topk,top,lr))return
@@ -509,7 +516,7 @@ c      integer m3,n3,lr3,nlr3,m2,n2,il2,ild2,m1,n1,il1,ild1
       if(.not.getsmat(fname,topk,top,m3,n3,1,1,lr3,nlr3))return
       call cvstr(nlr3,istk(lr3),buf,1)
       buf(nlr3+1:nlr3+1)=char(0)
-      call iislink(buf,ilib,irep)
+      call iislink(buf,ilib)
       if (.not.crebmat(fname,top,1,1,lr)) return
       if (ilib.eq.-1)  then 
          istk(lr) = 0
@@ -525,63 +532,6 @@ c      integer m3,n3,lr3,nlr3,m2,n2,il2,ild2,m1,n1,il1,ild1
       end
 
 
-      subroutine scifhelp(fname)
-c     =============================
-c     fhelp(name)
-      character*(*) fname
-      character*80 h
-      logical checkrhs,checklhs,getsmat,checkval,cresmat2,bufstore
-      include '../stack.h'
-      integer a, blank,percent
-      data a/10/,blank/40/,percen/56/
-c
-      rhs = max(0,rhs)
-      lbuf = 1
-      if(.not.checkrhs(fname,0,1)) return
-      if(rhs.eq.0) then
-         h='help'
-         h(5:5)= char(0)
-         call iscihelp(buf,h,ierr)
-      else
-         if(.not.getsmat(fname,top,top-rhs+1,m1,n1,1,1,lr1,nlr1)) return
-         if(.not.checkval(fname,m1*n1,1)) return
-         if(nlr1.gt.0) then
-            ic=abs(istk(lr1))
-            if(.not.((ic.ge.a.and.ic.lt.blank) .or. ic.eq.percen)) then
-               h='symbols'
-               h(8:8)= char(0)
-               call iscihelp(buf,h,ierr)
-            else
-               if(.not.bufstore(fname,lbuf,lbufi1,lbuff1,lr1,nlr1))
-     $              return
-               call iscihelp(buf,buf(lbufi1:lbuff1),ierr)
-            endif
-         endif
-      endif
-      call objvide(fname,top)
-      return
-      end
-c
-      subroutine scifapr(fname)
-c     =============================
-c     fapropos(name)
-      character*(*) fname
-      logical checkrhs,checklhs,getsmat,checkval,cresmat2,bufstore
-      include '../stack.h'
-      rhs = max(0,rhs)
-      lbuf = 1
-      if(.not.checkrhs(fname,1,1)) return
-      if(.not.getsmat(fname,top,top-rhs+1,m1,n1,1,1,lr1,nlr1)) return
-      if(.not.checkval(fname,m1*n1,1)) return
-c     conversion to lower case
-      do 10 i=0,nlr1-1
-         istk(lr1+i)=abs(istk(lr1+i))
- 10   continue
-      if(.not.bufstore(fname,lbuf,lbufi1,lbuff1,lr1,nlr1)) return
-      call isciap(buf,buf(lbufi1:lbuff1),ierr)
-      call objvide(fname,top)
-      return
-      end
 
       subroutine intfort(fname)
 c     =====================================
@@ -895,7 +845,7 @@ c     overlapping object is necessary
 c     sciargs()
       character*(*) fname
       logical checkrhs,checklhs
-      integer iadr,sadr,ciargc
+      integer iadr,sadr,sciiargc
       include '../stack.h'
 c
       iadr(l)=l+l-1
@@ -907,8 +857,7 @@ c
       if(.not.checkrhs(fname,0,0)) return
       if(.not.checklhs(fname,1,1)) return
 
-      nargs = iargc()
-
+      nargs = sciiargc()
       top=top+1
       il=iadr(lstk(top))
       l=il+5+nargs+1
@@ -924,7 +873,7 @@ c
       istk(il+4)=1
 
       do 20 k=0,nargs
-         call fgetarg(k,buf)
+         call scigetarg(k,buf)
          l1=len(buf)+1
  10      l1=l1-1
          if(buf(l1:l1).eq.' ') goto 10
@@ -945,17 +894,14 @@ c
       subroutine intschdir(fname)
       character*(*) fname
       logical createvar,  putlhsvar
-      logical checkrhs,checklhs,getsmat
+      logical checkrhs,checklhs,getrhsvar
       include '../stack.h'
       nbvars=0
       if(.not.checkrhs(fname,1,1)) return
       if(.not.checklhs(fname,1,1)) return
-
-      if(.not.getsmat(fname,top,top,m1,n1,1,1,lr,m)) return
-      call cvstr(m,istk(lr),buf,1)
+      if(.not.getrhsvar(1,'c',m1,n1,lr)) return 
       if(.not.createvar(2,'i',1,1,l2)) return
-      buf(m+1:m+1)=char(0)
-      call scichdir(buf(1:m+1),istk(l2))
+      call scichdir(cstk(lr:lr+m1*n1),istk(l2))
       if(istk(l2) .gt. 0) then 
          buf = fname // ': Internal Error' 
          call error(998)
@@ -1233,6 +1179,19 @@ c     .     clear within a macro, an exec or a pause
 c     .  clear all variable
 
 c     .  preserve %help and scicos_pal variables
+         i1=bbot
+         fin=-1
+         call stackg(helps)
+         if(err.gt.0) return
+         if (fin.gt.0) i1=min(fin,i1)
+
+         fin=-1
+         call stackg(scspal)
+         if(err.gt.0) return
+         if (fin.gt.0) i1=min(fin,i1)
+         bot = i1
+         if(bot.eq.bbot) goto 02
+         
          fin=0
          call stackg(helps)
          if(err.gt.0) return
@@ -1327,9 +1286,13 @@ c
       if(.not.checklhs(fname,1,1)) return
 
       if(rhs.le.0) then
-c     clear all variable
-         call iset(gtop-(isiz+1)*nsiz,0,idstk(1,isiz+2),1)
-         gtop=isiz+1
+c     clear all variable but those created by the startup
+         nprotect=6
+         nv=gtop-(isiz+1)-nprotect
+         if(nv.gt.0) then 
+            call iset(nv*nsiz,0,idstk(1,isiz+2+nprotect),1)
+            gtop=isiz+1+nprotect
+         endif
          goto 100
       endif
      
@@ -1405,7 +1368,7 @@ c     return a null matrix
       subroutine intcomp
 c     Copyright INRIA
       include '../stack.h'
-      integer cmode,topk
+      integer cmode,topk,p
       logical checkrhs,checklhs,getscalar,cremat
       integer iadr,sadr
 c    
@@ -1413,7 +1376,7 @@ c
       sadr(l)=(l/2)+1
 c
       call ref2val
-      if(rstk(pt).eq.901) goto 71
+      if(rstk(pt).eq.901) goto 61
 c
       rhs=max(0,rhs)
       if(.not.checklhs('comp',1,1)) return
@@ -1467,12 +1430,16 @@ c
       icall=5
 c     *call* parse  macro
       return
- 71   l=ids(1,pt)
+ 61   l=ids(1,pt)
       pt=pt-1
       if(err1.ne.0) then
          comp(3)=0
          comp(2)=0
          comp(1)=0
+         if (rstk(pt).eq.904) then
+            top=toperr
+            return
+         endif
          il=iadr(lstk(top))
          istk(il)=0
          lhs=0
@@ -2396,7 +2363,7 @@ c     .  get number of protected variables
 c     .     mark n oldest current variables as protected
             if(.not.getscalar('predef',top,top,l)) return
             is=isiz
-            bbot=max(bot,isiz-max( nint(stk(l)),(isiz-bot0) ) )
+            bbot=max(bot,min(isiz-nint(stk(l)),bot0))
          elseif(ityp.eq.10) then
             if(.not.getsmat('predef',top,top,m,n,1,1,l,n1)) return
             if(.not.checkval('predef',m*n,1) ) return
@@ -2405,7 +2372,7 @@ c     .        mark all current variables as protected
                bbot=bot
             elseif(abs(istk(l)).eq.12) then
 c     .        unmark all 
-               bbot=max(bot,isiz-max(0,(isiz-bot0) ) )
+               bbot=bot0
             else
                buf='Unknown option'
                call error(901)
@@ -2441,8 +2408,9 @@ c
       count=0
       pt0=pt+1
  151  pt0=pt0-1
-      if(pt0.le.0) goto 156
-       if(rstk(pt0).eq.802.or.rstk(pt0).eq.612 .or.
+      if(pt0.le.0) return
+         
+      if(rstk(pt0).eq.802.or.rstk(pt0).eq.612 .or.
      &     (rstk(pt0).eq.805.and.eqid(ids(1,pt0),sel)).or.
      &     (rstk(pt0).eq.616.and.pstk(pt0).eq.10)) count=count+1
       if(int(rstk(pt0)/100).ne.5) goto 151
@@ -2454,17 +2422,37 @@ c     resume in a compiled macro
          pstk(pt0+2)=count
       elseif(rstk(pt0).eq.502) then
 c     resume in an uncompiled macro or an exec or an execstr
-         if(rstk(pt0-1).eq.903) then
+         if(rstk(pt0-1).eq.903.or.rstk(pt0-1).eq.706) then
 c     .  in an execstr, check execstr calling context
-
+            ip0=pt0+1
             pt0=pt0-2
  153        pt0=pt0-1
-            if(pt0.le.0) goto 156
+            if(pt0.le.0) return
             if(rstk(pt0).eq.802.or.rstk(pt0).eq.612 .or.
      &           (rstk(pt0).eq.805.and.eqid(ids(1,pt0),sel)).or.
      &           (rstk(pt0).eq.616.and.pstk(pt0).eq.10)) count=count+1
-            if(rstk(pt0).ne.501.and.rstk(pt0).ne.502) goto 153
-            if(paus.ne.0.and.rstk(pt0).eq.201) then
+            if(rstk(pt0).lt.501.or.rstk(pt0).gt.503) goto 153
+            if(rstk(pt0).eq.503.and.rio.eq.rte.and.pause.ne.0) then
+c     .       resume appele dans par un execstr sous pause
+               k=lpt(1)-(13+nsiz)
+               lpt(1)=lin(k+1)
+               macr=macr-1
+
+               k=lpt(1)-(13+nsiz)
+               bot=lin(k+5)
+               mrhs=rhs
+               rhs=0
+               paus=paus-1
+               do 154 i=1,mrhs
+                  call stackp(ids(1,ip0),0)
+                  ip0=ip0-1
+ 154           continue
+               paus=paus+1
+               lin(k+5)=bot
+               top=top-count
+               pt=pt0
+               goto 999
+            elseif(paus.ne.0.and.rstk(pt0).eq.201) then
 c     .        ???
                r=rstk(pt0-4)
                if (r.eq.701.or.r.eq.604) goto 156
@@ -2577,7 +2565,7 @@ c      if(rhs.eq.1) lnb=1
       subroutine intstacksize
 c     Copyright INRIA
       include '../stack.h'
-      integer offset
+      integer offset,p
       logical checkrhs,checklhs,cremat,getscalar
       integer iadr,sadr
 c
@@ -2599,16 +2587,14 @@ c
 
       if(.not.getscalar('stacksize',top,top,l)) return
       top=top-1
-      if (top.ne.0) then
-         buf='stacksize cannot be used in this context'
-         call error(1502)
-         return
-      endif
+c
       mem=stk(l)
       memold=lstk(isiz)-lstk(1)
-      if (mem.eq.memold) goto 502
-      l=lstk(isiz)-lstk(bot)
-      if (mem.lt.l) then
+      if (mem.eq.memold) goto 50
+      lbot=lstk(isiz)-lstk(bot)
+      ltop=0
+      if (top.gt.0) ltop=lstk(top+1)-lstk(1)
+      if (mem.lt.lbot+ltop) then
          buf='Required memory too small for defined data'
          call error(1503)
          return
@@ -2619,20 +2605,79 @@ c
          return
       endif
       offset=offset+1
-      call unsfdcopy(l,stk(lstk(bot)),1,stk(offset+mem-l),1)
-      kd=offset-lstk(1)+mem-memold
-      do 501 k=bot,isiz
-         lstk(k)=lstk(k)+kd
- 501  continue 
+      l1=lstk(1)
+      l2=lstk(bot)
+c     copy the top of the stack
+      if (top.gt.0) call unsfdcopy(ltop,stk(l1),1,stk(offset),1)
+      kd1=offset-l1
+      do 30 k=1,top+1
+         lstk(k)=lstk(k)+kd1
+ 30   continue
+
+c     copy the bottom of the stack
+      call unsfdcopy(lbot,stk(l2),1,stk(offset+mem-lbot),1)
+      kd2=offset+mem-lbot-l2
+      do 40 k=bot,isiz
+         lstk(k)=lstk(k)+kd2
+ 40   continue
+
       call freemem()
-      lstk(1)=offset
+c     update reference variables
+      do 41 i=1,top
+         if(infstk(i).ne.2) then
+            il=iadr(lstk(i))
+            if(istk(il).lt.0) istk(il+1)=istk(il+1)+kd1
+         endif
+ 41   continue
+      do 42 i=bot,isiz-1
+         if(infstk(i).ne.2) then
+            il=iadr(lstk(i))
+            if(istk(il).lt.0) istk(il+1)=istk(il+1)+kd2
+         endif
+ 42   continue
+
+c     rebuild asolute pointers if necessary see macro.f  and run.f
+      if(macr.gt.0) then
+         lpt1=lpt(1)
+c     Check if a compiled macro is running
+         p=pt+1
+ 45      p=p-1
+         if((rstk(p).ge.601.and.rstk(p).le.603).or.rstk(p).eq.605) then
+            call adjuststkptr(pstk(p),kd1,kd2,l2)
+         elseif(rstk(p).eq.604.or.rstk(p).eq.606) then
+            call adjuststkptr(ids(1,p),kd1,kd2,l2)
+            if(rstk(p).le.606) call adjuststkptr(ids(2,p),kd1,kd2,l2)
+         elseif(rstk(p).ge.611.and.rstk(p).le.616) then
+             call adjuststkptr(ids(1,p),kd1,kd2,l2)
+             if(rstk(p).ge.614) call adjuststkptr(pstk(p),kd1,kd2,l2)
+         elseif(rstk(p).eq.501.or.rstk(p).eq.502.or.rstk(p).eq.503) then
+            k = lpt1 - (13+nsiz)
+            lpt1 = lin(k+1)
+            if(rstk(p).eq.501.or.rstk(p).eq.502) then
+               call adjuststkptr(lin(k+6),kd1,kd2,l2)
+               call adjuststkptr(lin(k+7),kd1,kd2,l2)
+               call adjuststkptr(ids(3,p),kd1,kd2,l2)
+            endif
+         endif
+         if(p.gt.0) goto 45
+      endif
+
       leps=sadr(iadr(lstk(isiz-5)) +4)
 
- 502  continue
-      top=top+1
+ 50   top=top+1
       call objvide('stacksize',top)
       return
       end
+      subroutine adjuststkptr(p,topoffset,botoffset,lbot)
+c     routine for intstacksize
+      integer p,topoffset,botoffset,lbot
+      if(p.ge.2*lbot) then
+         p=p+2*botoffset
+      else
+         p=p+2*topoffset
+      endif
+      end
+
       subroutine inttimer
 c     Copyright INRIA
       include '../stack.h'
@@ -2899,7 +2944,7 @@ c
             job=0
             top=top-1
             n=1
-         else
+         else 
             if(.not.getscalar('getdate', top,top, lr)) return
             dt=stk(lr)
             call convertdate(dt,w)
