@@ -178,10 +178,16 @@ c     formal variable
          return
       endif
       n=istk(il+5)-1
+      if(n.gt.4) call msgs(109,0)
       do 12 i=1,4
          id(i)=blank
          if(i.le.n) id(i)=istk(il+5+i)
  12   continue
+      if(abs(id(1)).lt.10.or.abs(id(1)).ge.blank) then
+         err=2
+         call error(116)
+         return
+      endif
 c
 c     first argument
       top=top-1
@@ -208,13 +214,9 @@ c     necessary while matdsr and matdsc cannot be called by reference
          call unsfdcopy(mn1*(it1+1),stk(l1),1,stk(lr),1)
          lstk(top+1)=lr+mn1*(it1+1)
       endif
-      fin=3
       rhs=1
-      if(it1.eq.0) then
-         call matdsr
-      else
-         call matdsc
-      endif
+      call inteig('spec')
+      call putlhsvar
       if(err.gt.0) return
       il1=iadr(lstk(top))
       l1=sadr(il1+4)
@@ -274,15 +276,14 @@ c     polynome defini par ses coefficients
          call error(53)
          return
       endif
+      if(mn1.eq.0) return
+
       if(n1.ne.1.and.m1.ne.1) then
          err=1
          call error(89)
          return
       endif
-      if(mn1.le.0) then
-         call error(42)
-         return
-      endif
+
       lr=sadr(ilr+10)
       err=lr+mn1*(it1+1)-lstk(bot)
       if(err.gt.0) then
@@ -337,6 +338,8 @@ c
 c
       m1=istk(il1+1)
       n1=istk(il1+2)
+      if(m1*n1.eq.0) return
+
       it1=istk(il1+3)
       mn1=m1*n1
       if(mn1.ne.1) then
@@ -1711,8 +1714,13 @@ c     determine max of the degrees
          nb=max(nb,istk(idb+i)-istk(idb-1+i))
  76   continue
 c     preserve adress of the beginning of a and b coefficients
+
       lar=la
       lbr=lb
+c     allocate memory for intermediate results 
+      law=lw
+      lbw=law+na+1
+      lw=lbw+nb+1
 
 c     simplify
       la1=la
@@ -1721,14 +1729,18 @@ c     simplify
          na=istk(ida+i)-istk(ida-1+i)-1
          nb=istk(idb+i)-istk(idb-1+i)-1
          ierr=lstk(bot)-lw
-         call  dpsimp(stk(la),na,stk(lb),nb,stk(la1),nnum,
-     $        stk(lb1),nden,stk(lw),ierr)
+         call  dpsimp(stk(la),na,stk(lb),nb,stk(law),nnum,
+     $        stk(lbw),nden,stk(lw),ierr)
          if(ierr.eq.1) then
             call error(27)
             return
          elseif(ierr.eq.2) then
             call msgs(43,i)
          endif
+c     .  copy overwrite initial polynomials with simplified ones
+         call dcopy(nnum,stk(law),1,stk(la1),1)
+         call dcopy(nden,stk(lbw),1,stk(lb1),1)
+
          la=la+na+1
          lb=lb+nb+1
          la1=la1+nnum
@@ -1888,6 +1900,11 @@ c     set adress where to put the results
       lb1=lb
       ida1=ida
       idb1=idb
+c
+c     allocate memory for intermediate results 
+      law=lw
+      lbw=law+na+1
+      lw=lbw+nb+1
 
 c     beginning of numerator in resulting structure
       l0=ll+istk(ilr+4)-1
@@ -1902,14 +1919,19 @@ c     simplify
          na=istk(ida+i)-istk(ida-1+i)-1
          nb=istk(idb+i)-istk(idb-1+i)-1
          ierr=lstk(bot)-lw
-         call  dpsimp(stk(la),na,stk(lb),nb,stk(la1),nnum,
-     $        stk(lb1),nden,stk(lw),ierr)
+         call  dpsimp(stk(la),na,stk(lb),nb,stk(law),nnum,
+     $        stk(lbw),nden,stk(lw),ierr)
          if(ierr.eq.1) then
             call error(27)
             return
          elseif(ierr.eq.2) then
             call msgs(43,i)
          endif
+
+c     .  copy overwrite initial polynomials with simplified ones
+         call dcopy(nnum,stk(law),1,stk(la1),1)
+         call dcopy(nden,stk(lbw),1,stk(lb1),1)
+
          la=la+na+1
          lb=lb+nb+1
          la1=la1+nnum
