@@ -9,6 +9,7 @@ extern  int C2F(cvname) __PARAMS((integer *,char *,integer *, unsigned long int)
 extern  int C2F(cvstr)  __PARAMS((integer *,integer *,char *,integer *,unsigned long int));
 extern int C2F(icopy)  __PARAMS((integer *,integer *,integer *,integer *,integer *));
 extern int C2F(dcopy)  __PARAMS((integer *,double *,integer *,double *,integer *));
+extern int C2F(unsfdcopy)  __PARAMS((integer *,double *,integer *,double *,integer *));
 extern int C2F(rcopy)  __PARAMS((integer *,float *,integer *,float *,integer *));
 extern void C2F(cstringf) __PARAMS((char ***,integer *,integer *,integer *,integer *,integer *));
 extern int s_copy __PARAMS((char *,char *, integer, unsigned long int));
@@ -36,7 +37,7 @@ extern int C2F(cvstr)  __PARAMS((integer *n, integer *line, char *str, integer *
 extern int C2F(cvstr1)  __PARAMS((integer *n, integer *line, char *str, integer *job, unsigned long str_len));
 extern int C2F(codetoascii)  __PARAMS((integer *n, integer *line, char *str, unsigned long str_len));
 extern int C2F(asciitocode)  __PARAMS((integer *n, integer *line, char *str, integer *flag__, unsigned long str_len));
-extern integer C2F(getcode)  __PARAMS((char *mc, unsigned long mc_len));
+extern integer C2F(getcode)  __PARAMS((unsigned char *mc, unsigned long mc_len));
 
 /* stack1.c */
 
@@ -162,6 +163,7 @@ int cre_listsparse_from_ptr  __PARAMS((char *fname,integer * lw,integer * numi,i
 				      SciSparse *M, unsigned long fname_len ));
 
 
+
 /**********************************************************************
  * INT MATRICES 
  **********************************************************************/
@@ -177,5 +179,15 @@ int C2F(creimat) __PARAMS((char *fname, integer *lw, integer *it, integer *m, in
 
 int C2F(creimati) __PARAMS((char *fname, integer *stlw, integer *it, integer *m, integer *n, integer *lr, int *flagx, long unsigned int fname_len));
 
+/**********************************************************************
+ * HANDLE MATRICES 
+ **********************************************************************/
+extern int C2F(getlisthmat)  __PARAMS((char *fname, integer *topk, integer *spos, integer *lnum, integer *m, integer *n, integer *lr, unsigned long fname_len));
+extern int C2F(gethmat)  __PARAMS((char *fname, integer *topk, integer *lw, integer *m, integer *n, integer *lr, unsigned long fname_len));
+extern int C2F(gethmati)  __PARAMS((char *fname, integer *topk, integer *spos, integer *lw, integer *m, integer *n, integer *lr, int *inlist__, integer *nel, unsigned long fname_len));
 
+
+extern  int C2F(listcrehmat)  __PARAMS((char *fname, integer *lw, integer *numi, integer *stlw, integer *m, integer *n, integer *lrs, unsigned long fname_len));
+extern int C2F(crehmat)  __PARAMS((char *fname, integer *lw, integer *m, integer *n, integer *lr, unsigned long fname_len));
+extern int C2F(crehmati)  __PARAMS((char *fname, integer *stlw, integer *m, integer *n, integer *lr, int *flag__, unsigned long fname_len));
 #endif 
