@@ -12,7 +12,6 @@
 #include "../stack-c.h"
 #include "../sun/men_Sutils.h" 
 
- 
 /* Table of constant values */
 
 static integer cx1 = 1;
@@ -23,6 +22,8 @@ static int C2F(mvfromto) __PARAMS((integer *itopl,integer *));
 
 static int rhs_opt_find __PARAMS((char *name,rhs_opts opts[]));
 static void rhs_opt_print_names __PARAMS((rhs_opts opts[]));
+static void intersci_pop();
+static int intersci_push();
 
 /*------------------------------------------------
  * checkrhs: checks right hand side arguments 
@@ -202,15 +203,15 @@ integer C2F(overloadtype)(lw,fname,typ)
   case 'S' : /* string Matrix */
     ityp=10;
     break;
-  case 'd' :
-  case 'i' :
-  case 'r' :
-  case 'z' :
+  case 'd' :  case 'i' :  case 'r' :  case 'z' :   /* numeric */
     ityp=1;
     break ;
   case 'b' : /* boolean */
     ityp=4;
     break;
+  case 'h' : /* handle */
+    ityp=9;
+    break;
   case 'l' : /* list */
     ityp=15;
     break;
@@ -380,24 +381,23 @@ void rhs_opt_print_names(opts)
  *   or is just a reference to a variable on the stack 
  *---------------------------------------------------------------------*/
 
-int C2F(isref)(lw)
-     integer *lw;
+int IsRef(int number) { 
+  return C2F(isref)(&number);
+}
+
+int C2F(isref)(integer *number) 
 {
-  int retval;
-  integer  lw1;
-  retval = FALSE_;
-  if (*lw > intersiz) {
-    Scierror(999,"isref: too many arguments in the stack edit stack.h and enlarge intersiz\r\n");
-    return retval;
+  integer il,lw;
+  lw = *number + Top - Rhs;
+  if ( *number > Rhs) {
+    Scierror(999,"isref: bad call to isref! (1rst argument)\r\n");
+    return FALSE_;
   }
-  Nbvars = Max(*lw,Nbvars);
-  lw1 = *lw + Top - Rhs;
-  if (*lw < 0) {
-    Scierror(999,"isref: bad call! (1rst argument)\r\n");
-    return retval;
-  }
-  if ( *istk(iadr(lw1)) < 0)   retval = TRUE_;
-  return retval;
+  il = iadr(*lstk(lw));
+  if ( *istk(il) < 0) 
+    return TRUE_ ; 
+  else 
+    return FALSE_ ; 
 }
 
 /*---------------------------------------------------------------------
@@ -421,8 +421,8 @@ int C2F(createvar)(lw, typex, m, n, lr, type_len)
      integer *m, *n, *lr;
      unsigned long type_len;
 {
-  integer ix1, ix, it=0, lw1, lcs, M,N,IT,LR;
-  unsigned char Type = *typex , Type1;
+  integer ix1, ix, it=0, lw1, lcs, IT;
+  unsigned char Type = *typex;
   char *fname = Get_Iname();
   if (*lw > intersiz) {
     Scierror(999,"%s: (createvar) too many arguments in the stack edit stack.h and enlarge intersiz\r\n",
@@ -444,60 +444,83 @@ int C2F(createvar)(lw, typex, m, n, lr, type_len)
       *lr = cadr(*lr);
       for (ix = 0; ix < (*m)*(*n) ; ++ix) *cstk(*lr+ix)= ' ';
       *cstk(*lr+ (*m)*(*n) )= '\0';
-      Type1 = Type ; M =  *m * *n; N = 1; LR = *lr ;
+      C2F(intersci).ntypes[*lw - 1] = Type;
+      C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
+      C2F(intersci).lad[*lw - 1] = *lr;
       break;
     case 'd' : 
       if (! C2F(cremat)(fname, &lw1, &it, m, n, lr, &lcs, nlgh))    return FALSE_;
-      Type1 = Type ; M =  *m ; N = *n; IT= 0; LR = *lr ;
+      C2F(intersci).ntypes[*lw - 1] = Type;
+      C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
+      C2F(intersci).lad[*lw - 1] = *lr;
       break;
     case 'z' : 
       IT = 1;
+      if (!(*lstk(lw1) % 2) ) *lstk(lw1) = *lstk(lw1)+1;
       if (! C2F(cremat)(fname, &lw1, &IT, m, n, lr, &lcs, nlgh))    return FALSE_;
-      Type1 = Type ; M =  *m ; N = *n; LR = *lr ;
-      C2F(intersci).ladc[*lw - 1] = *lr + M*N;
+      C2F(intersci).ntypes[*lw - 1] = Type;
+      C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
+      C2F(intersci).lad[*lw - 1] = *lr;
+      *lr = sadr(*lr);
       break;
     case 'l' : 
       C2F(crelist)(&lw1, m, lr);
-      Type1 = '$' ; M =  *m ; N = 1; IT= 0; LR = *lr ;
+      C2F(intersci).ntypes[*lw - 1] = '$';
+      C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
+      C2F(intersci).lad[*lw - 1] = *lr;
       break;
     case 't' : 
       C2F(cretlist)(&lw1, m, lr);
-      Type1 = '$' ; M =  *m ; N = 1; IT= 0; LR = *lr ;
+      C2F(intersci).ntypes[*lw - 1] = '$';
+      C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
+      C2F(intersci).lad[*lw - 1] = *lr;
       break;
     case 'm' : 
       C2F(cremlist)(&lw1, m, lr);
-      Type1 = '$' ; M =  *m ; N = 1; IT= 0; LR = *lr ;
+      C2F(intersci).ntypes[*lw - 1] = '$';
+      C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
+      C2F(intersci).lad[*lw - 1] = *lr;
       break;
     case 'r' : 
       if (! C2F(cremat)(fname, &lw1, &it, m, n, lr, &lcs, nlgh)) return FALSE_;
       *lr = iadr(*lr);
-      Type1 = Type ; M =  *m ; N = *n; IT= 0; LR = *lr ;
+      C2F(intersci).ntypes[*lw - 1] = Type;
+      C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
+      C2F(intersci).lad[*lw - 1] = *lr;
       break ;
     case 'i' :
       if (! C2F(cremat)(fname, &lw1, &it, m, n, lr, &lcs, nlgh)) return FALSE_;
       *lr = iadr(*lr) ;
-      Type1 = Type ; M =  *m ; N = *n; IT= 0; LR = *lr ;
+      C2F(intersci).ntypes[*lw - 1] = Type;
+      C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
+      C2F(intersci).lad[*lw - 1] = *lr;
       break ;
     case 'b' :
       if (! C2F(crebmat)(fname, &lw1, m, n, lr, nlgh))  return FALSE_; 
-      Type1 = Type ; M =  *m ; N = *n; IT= 0; LR = *lr ;
+      C2F(intersci).ntypes[*lw - 1] = Type;
+      C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
+      C2F(intersci).lad[*lw - 1] = *lr;
       break;
     case 'p' : 
       if (! C2F(crepointer)(fname, &lw1, lr, nlgh))    return FALSE_;
-      Type1 = '$' ; M =  1 ; N = 1; IT= 0; LR = *lr ;
+      C2F(intersci).ntypes[*lw - 1] = '$';
+      C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
+      C2F(intersci).lad[*lw - 1] = *lr;
       break;
     case 'I' : 
       it = *lr ; /* on entry lr gives the int type */ 
       if (! C2F(creimat)(fname, &lw1, &it, m, n, lr, nlgh))    return FALSE_;
-      Type1 = '$' ; M =  *m ; N = *n; IT= 0; LR = *lr ;
+      C2F(intersci).ntypes[*lw - 1] = '$';
+      C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
+      C2F(intersci).lad[*lw - 1] = *lr;
+      break;
+    case 'h' : 
+      if (! C2F(crehmat)(fname, &lw1, m, n, lr, nlgh))    return FALSE_;
+      C2F(intersci).ntypes[*lw - 1] = Type;
+      C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
+      C2F(intersci).lad[*lw - 1] = *lr;
       break;
     }
-  C2F(intersci).ntypes[*lw - 1] = Type1;
-  C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
-  C2F(intersci).nbrows[*lw - 1] = M; 
-  C2F(intersci).nbcols[*lw - 1] = N;
-  C2F(intersci).itflag[*lw - 1] = IT;
-  C2F(intersci).lad[*lw - 1] = LR;
   return TRUE_; 
 }
 
@@ -536,28 +559,27 @@ int C2F(createcvar)(lw, typex, it, m, n, lr, lc, type_len)
   switch ( Type )  {
   case 'd' : 
     if (! C2F(cremat)(fname, &lw1, it, m, n, lr, lc, nlgh))  return FALSE_;
-    break;
-  case 'z' : 
-    if (! C2F(cremat)(fname, &lw1, it, m, n, lr, lc, nlgh))    return FALSE_;
+    C2F(intersci).ntypes[*lw - 1] = Type;
+    C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
+    C2F(intersci).lad[*lw - 1] = *lr;
     break;
   case 'r' : 
     if (! C2F(cremat)(fname, &lw1, it, m, n, lr, lc, nlgh))  return FALSE_;
     *lr = iadr(*lr);
     *lc = *lr + *m * *n;
+    C2F(intersci).ntypes[*lw - 1] = Type;
+    C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
+    C2F(intersci).lad[*lw - 1] = *lr;
     break;
   case 'i' : 
     if (! C2F(cremat)(fname, &lw1, it, m, n, lr, lc, nlgh))  return FALSE_;
     *lr = iadr(*lr);
     *lc = *lr + *m * *n;
+    C2F(intersci).ntypes[*lw - 1] = Type;
+    C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
+    C2F(intersci).lad[*lw - 1] = *lr;
     break;
   }
-  C2F(intersci).ntypes[*lw - 1] = Type;
-  C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
-  C2F(intersci).nbrows[*lw - 1] = *m;
-  C2F(intersci).nbcols[*lw - 1] = *n;
-  C2F(intersci).itflag[*lw - 1] = *it;
-  C2F(intersci).lad[*lw - 1] = *lr;
-  C2F(intersci).ladc[*lw - 1] = *lc;
   return TRUE_;
 } 
 
@@ -585,8 +607,6 @@ int C2F(createlist)(lw, nel)
   C2F(crelist)(&lw1, nel, &lr);
   C2F(intersci).ntypes[*lw - 1] = '$';
   C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
-  C2F(intersci).nbrows[*lw - 1] = *nel;
-  C2F(intersci).nbcols[*lw - 1] = 1;
   C2F(intersci).lad[*lw - 1] = lr;
   return TRUE_;
 } 
@@ -666,12 +686,14 @@ int C2F(createvarfrom)(lw, typex, m, n, lr, lar, type_len)
     if (*lar != -1)  C2F(dcopy)(&MN, stk(*lar), &cx1, stk(*lr), &cx1);
     *lar = *lr;
     break;
+  case 'h' :
+    if (! C2F(crehmat)(fname, &lw1, m, n, lr, nlgh))  return FALSE_;
+    if (*lar != -1)  C2F(dcopy)(&MN, stk(*lar), &cx1, stk(*lr), &cx1);
+    *lar = *lr;
+    break;
   }
   C2F(intersci).ntypes[*lw - 1] = '$';
   C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
-  C2F(intersci).nbrows[*lw - 1] = M;
-  C2F(intersci).nbcols[*lw - 1] = N;
-  C2F(intersci).itflag[*lw - 1] = 0;
   C2F(intersci).lad[*lw - 1] = *lr;
   return TRUE_;
 }
@@ -740,11 +762,7 @@ int C2F(createcvarfrom)(lw, typex, it, m, n, lr, lc, lar, lac, type_len)
   }
   C2F(intersci).ntypes[*lw - 1] = '$';
   C2F(intersci).iwhere[*lw - 1] = *lstk(lw1);
-  C2F(intersci).nbrows[*lw - 1] = *m;
-  C2F(intersci).nbcols[*lw - 1] = *n;
-  C2F(intersci).itflag[*lw - 1] = *it;
   C2F(intersci).lad[*lw - 1] = *lr;
-  C2F(intersci).ladc[*lw - 1] = *lc;
   return TRUE_;
 }
 
@@ -849,6 +867,15 @@ int C2F(createlistvarfrom)(lnumber, number, typex, m, n, lr, lar, type_len)
     if (*lar != -1) *stk(*lr)= *stk(*lar);
     *lar = *lr;
     break;
+  case 'h' :
+    ix1 = *lnumber + Top - Rhs;
+    if (! C2F(listcrehmat)(fname, &ix1, number, &C2F(intersci).lad[*lnumber - 1],
+			   m, n, lr, nlgh)) {
+      return FALSE_;
+    }
+    if (*lar != -1) C2F(dcopy)(&mn, stk(*lar), &cx1,stk(*lr) , &cx1);
+    *lar = *lr;
+    break;
   default :
     Scierror(999,"%s: (createlistvar) bad third argument!\r\n",fname);
     return FALSE_;
@@ -1113,11 +1140,74 @@ int C2F(createlistcvarfromptr)(lnumber, number, typex,it, m, n, iptr, iptc, type
 }
 
 
+/*---------------------------------------------------------------------
+ * use the rest of the stack as working area 
+ * the allowed size (in double) is returned in m
+ *---------------------------------------------------------------------*/
+
+int C2F(creatework)(number,m,lr)
+     integer *number,*m, *lr;
+{
+  int n,it=0,lw1,lcs,il;
+  char *fname = Get_Iname();
+  if (*number > intersiz) {
+    Scierror(999,"%s: (creatework) too many arguments in the stack edit stack.h and enlarge intersiz\r\n",
+	     fname);
+    return FALSE_ ;
+  }
+  Nbvars = Max(*number,Nbvars);
+  lw1 = *number + Top - Rhs;
+  if (lw1 < 0) {
+    Scierror(999,"%s: bad call to creatework! (1rst argument)\r\n",
+	     fname);
+    return FALSE_ ;
+  }
+  il = iadr(*lstk(lw1));
+  *m = *lstk(Bot ) - sadr(il+4);
+  n = 1;
+  if (! C2F(cremat)(fname, &lw1, &it, m, &n, lr, &lcs, nlgh))    return FALSE_;
+  return TRUE_; 
+}
+
+
+/*---------------------------------------------------------------------
+ * This can be used with creatework to 
+ * set the size of object which was intialy sized to the whole 
+ * remaining space with creatework 
+ * Moreover informations the objet is recorded 
+ *---------------------------------------------------------------------*/
+
+int C2F(setworksize)(number,size)
+     integer *number,*size;
+{
+  int lw1;
+  char *fname = Get_Iname();
+  if (*number > intersiz) {
+    Scierror(999,"%s: (creatework) too many arguments in the stack edit stack.h and enlarge intersiz\r\n",
+	     fname);
+    return FALSE_ ;
+  }
+  Nbvars = Max(*number,Nbvars);
+  lw1 = *number + Top - Rhs;
+  if (lw1 < 0) {
+    Scierror(999,"%s: bad call to setworksize! (1rst argument)\r\n",
+	     fname);
+    return FALSE_ ;
+  }
+  *lstk(lw1+1) = *lstk(lw1) + *size ;
+  C2F(intersci).ntypes[lw1 - 1] = '$';
+  C2F(intersci).iwhere[lw1 - 1] = *lstk(lw1);
+  C2F(intersci).lad[lw1 - 1] = 0; /* not to be used XXXX */ 
+  return TRUE_; 
+}
+
+
 /*---------------------------------------------------------------------
  * getmatdims :
  *     check if argument number <<number>> is a matrix and 
  *     returns its dimensions
  *---------------------------------------------------------------------*/
+
 int C2F(getmatdims)(number, m, n)
      integer *number, *m, *n;
 {
@@ -1141,6 +1231,7 @@ int C2F(getmatdims)(number, m, n)
   *n = *istk(il + 2);
   return TRUE_;
 }
+
 /*---------------------------------------------------------------------
  * getrhsvar :
  *     get the argument number <<number>> 
@@ -1163,7 +1254,7 @@ int C2F(getrhsvar)(number, typex, m, n, lr, type_len)
      integer *m, *n, *lr;
      unsigned long type_len;
 {
-  int ierr=0, il1,ild1,nn;
+  int ierr=0,il1,ild1,nn;
   int lrr;
   char *fname = Get_Iname();
   char **items, namex[nlgh+1];
@@ -1206,41 +1297,74 @@ int C2F(getrhsvar)(number, typex, m, n, lr, type_len)
 
       C2F(in2str)(&ix2, istk(*lr), cstk(cadr(*lr)), ix2 + 1);
       *lr = cadr(*lr);
+      C2F(intersci).ntypes[*number - 1] = Type ;
+      C2F(intersci).iwhere[*number - 1] = *lstk(lw);
+      C2F(intersci).lad[*number - 1] = *lr;
       break;
 
     case 'd' :
       if (! C2F(getmat)(fname, &topk, &lw, &it, m, n, lr, &lc, nlgh)) return FALSE_;
+      C2F(intersci).ntypes[*number - 1] = Type ;
+      C2F(intersci).iwhere[*number - 1] = *lstk(lw);
+      C2F(intersci).lad[*number - 1] = *lr;
       break ;
     case 'z' :
       if (! C2F(getmat)(fname, &topk, &lw, &it, m, n, lr, &lc, nlgh)) return FALSE_;
       ix2 = *m * *n;
-      if (it != 1) {
+      if ((it != 1) && (ix2 !=0)) {
 	Scierror(999," Waiting for a complex argument (z)"); return FALSE_;
       };
-      SciToF77(stk(*lr), ix2, ix2);
+      if (!(*lr % 2) ) {  /* bad adress (lr is even) shift up the stack */
+	double2z(stk(*lr), stk(*lr)-1, ix2, ix2);
+	*istk(iadr(*lr)-4)=133;
+	*istk(iadr(*lr)-3)=iadr(*lr + 2*ix2-1);
+	*istk( iadr(*lr + 2*ix2-1) )= *m;
+	*istk( iadr(*lr + 2*ix2-1) +1 )= *n;
+	C2F(intersci).ntypes[*number - 1] = Type ;
+	C2F(intersci).iwhere[*number - 1] = *lstk(lw);
+	C2F(intersci).lad[*number - 1] = *lr-1;
+	*lr = sadr(*lr-1);
+      }
+      else {
+	SciToF77(stk(*lr), ix2, ix2);
+	C2F(intersci).ntypes[*number - 1] = Type ;
+	C2F(intersci).iwhere[*number - 1] = *lstk(lw);
+	C2F(intersci).lad[*number - 1] = *lr;
+	*lr = sadr(*lr);
+      };
       break ;
     case 'r' :
       if (! C2F(getmat)(fname, &topk, &lw, &it, m, n, lr, &lc, nlgh))  return FALSE_;
       ix1 = *m * *n;
       C2F(simple)(&ix1, stk(*lr), sstk(iadr(*lr)));
       *lr = iadr(*lr);
+      C2F(intersci).ntypes[*number - 1] = Type ;
+      C2F(intersci).iwhere[*number - 1] = *lstk(lw);
+      C2F(intersci).lad[*number - 1] = *lr;
       break;
     case 'i' :
       if (! C2F(getmat)(fname, &topk, &lw, &it, m, n, lr, &lc, nlgh)) return FALSE_;
       ix1 = *m * *n;
       C2F(entier)(&ix1, stk(*lr), istk(iadr(*lr)));
       *lr = iadr(*lr) ;
+      C2F(intersci).ntypes[*number - 1] = Type ;
+      C2F(intersci).iwhere[*number - 1] = *lstk(lw);
+      C2F(intersci).lad[*number - 1] = *lr;
       break;
     case 'b' : 
       if (! C2F(getbmat)(fname, &topk, &lw, m, n, lr, nlgh))  return FALSE_;
+      C2F(intersci).ntypes[*number - 1] = Type ;
+      C2F(intersci).iwhere[*number - 1] = *lstk(lw);
+      C2F(intersci).lad[*number - 1] = *lr;
       break;
-    case 'l' :
-    case 't' :
-    case 'm' :
+    case 'l' :    case 't' :    case 'm' :
       *n = 1;
       if (! C2F(getilist)(fname, &topk, &lw, m, n, lr, nlgh))  return FALSE_;
       /* No data conversion for list members ichar(type)='$' */
       Type = '$' ;
+      C2F(intersci).ntypes[*number - 1] = Type ;
+      C2F(intersci).iwhere[*number - 1] = *lstk(lw);
+      C2F(intersci).lad[*number - 1] = *lr;
       break;
     case 'S' :
       /** getwsmat : must be back in stack1.c from xawelm.f */
@@ -1249,11 +1373,14 @@ int C2F(getrhsvar)(number, typex, m, n, lr, type_len)
       ScilabMStr2CM(istk(il1),&nn,istk(ild1),&items,&ierr);
       if ( ierr == 1) return FALSE_;
       Type = '$';
-	/*
-	 * Warning : lr must have the proper size when calling getrhsvar 
-	 * char **Str1; .... GetRhsVar(...., &lr) 
-	 */
+      /*
+       * Warning : lr must have the proper size when calling getrhsvar 
+       * char **Str1; .... GetRhsVar(...., &lr) 
+       */
       *((char ***) lr) = items ;
+      C2F(intersci).ntypes[*number - 1] = Type ;
+      C2F(intersci).iwhere[*number - 1] = *lstk(lw);
+      C2F(intersci).lad[*number - 1] = *lr;
       break;
     case 's' :
       /* sparse matrices */ 
@@ -1266,6 +1393,9 @@ int C2F(getrhsvar)(number, typex, m, n, lr, type_len)
       Sp->R = stk(lr1);
       Sp->I = (it==1) ? stk(lc): NULL;
       Type = '$';
+      C2F(intersci).ntypes[*number - 1] = Type ;
+      C2F(intersci).iwhere[*number - 1] = *lstk(lw);
+      C2F(intersci).lad[*number - 1] = *lr;
       break;
     case 'I' :
       /* int matrices */ 
@@ -1275,6 +1405,9 @@ int C2F(getrhsvar)(number, typex, m, n, lr, type_len)
       Im->m = *m ; Im->n = *n ; Im->it = it; Im->l = lr1;
       Im->D = istk(lr1);
       Type = '$';
+      C2F(intersci).ntypes[*number - 1] = Type ;
+      C2F(intersci).iwhere[*number - 1] = *lstk(lw);
+      C2F(intersci).lad[*number - 1] = *lr;
       break;
     case 'f' :
       /* XXXXXX : gros bug ici car getexternal a besoin de savoir 
@@ -1294,17 +1427,23 @@ int C2F(getrhsvar)(number, typex, m, n, lr, type_len)
 	return FALSE_;
       }
       Type = '$';
+      C2F(intersci).ntypes[*number - 1] = Type ;
+      C2F(intersci).iwhere[*number - 1] = *lstk(lw);
+      C2F(intersci).lad[*number - 1] = *lr;
       break;
     case 'p' : 
       if (! C2F(getpointer)(fname, &topk, &lw,lr, nlgh)) return FALSE_;
+      C2F(intersci).ntypes[*number - 1] = Type ;
+      C2F(intersci).iwhere[*number - 1] = *lstk(lw);
+      C2F(intersci).lad[*number - 1] = *lr;
       break;
+    case 'h' :
+      if (! C2F(gethmat)(fname, &topk, &lw, m, n, lr, nlgh)) return FALSE_;
+      C2F(intersci).ntypes[*number - 1] = Type ;
+      C2F(intersci).iwhere[*number - 1] = *lstk(lw);
+      C2F(intersci).lad[*number - 1] = *lr;
+      break ;
     }
-  C2F(intersci).ntypes[*number - 1] = Type ;
-  C2F(intersci).iwhere[*number - 1] = *lstk(lw);
-  C2F(intersci).nbrows[*number - 1] = *m;
-  C2F(intersci).nbcols[*number - 1] = *n;
-  C2F(intersci).itflag[*number - 1] = it;
-  C2F(intersci).lad[*number - 1] = *lr;
   return TRUE_;
 } 
 
@@ -1322,7 +1461,7 @@ int C2F(getrhscvar)(number, typex, it, m, n, lr, lc, type_len)
      integer *it, *m, *n, *lr, *lc;
      unsigned long type_len;
 {
-  integer ix1, lw, topk, ix2;
+  integer ix1, lw, topk;
   unsigned char Type = *typex;
   char *fname = Get_Iname();
   
@@ -1342,14 +1481,6 @@ int C2F(getrhscvar)(number, typex, it, m, n, lr, lc, type_len)
   case 'd' :
     if (! C2F(getmat)(fname, &topk, &lw, it, m, n, lr, lc, nlgh)) return FALSE_;
     break;
-  case 'z' :
-    if (! C2F(getmat)(fname, &topk, &lw, it, m, n, lr, lc, nlgh)) return FALSE_;
-    ix2 = *m * *n;
-    if (*it != 1) {
-      Scierror(999," Waiting for a complex argument (z)"); return FALSE_;
-    };
-    SciToF77(stk(*lr), ix2, ix2);
-    break ;
   case 'r' :
     if (! C2F(getmat)(fname, &topk, &lw, it, m, n, lr, lc, nlgh)) return FALSE_;
     ix1 = *m * *n * (*it + 1);
@@ -1367,11 +1498,7 @@ int C2F(getrhscvar)(number, typex, it, m, n, lr, lc, type_len)
   }
   C2F(intersci).ntypes[*number - 1] = Type;
   C2F(intersci).iwhere[*number - 1] = *lstk(lw);
-  C2F(intersci).nbrows[*number - 1] = *m;
-  C2F(intersci).nbcols[*number - 1] = *n;
-  C2F(intersci).itflag[*number - 1] = *it;
   C2F(intersci).lad[*number - 1] = *lr;
-  C2F(intersci).ladc[*number - 1] = *lc;
   return TRUE_;
 }
 
@@ -1450,13 +1577,25 @@ int C2F(getlistrhsvar)(lnumber, number, typex, m, n, lr, type_len)
     break;
   case 'z' :
     if (! C2F(getlistmat)(fname, &topk, &lw,number, &it, m, n, lr, &lc, nlgh)) return FALSE_;
-    ix1 = *m * *n;
-    if (it != 1) {
+    ix2 = *m * *n;
+    if ((it != 1) && (ix2 !=0)){
       Scierror(999,"%s: argument %d >(%d) should be a complex matrix\r\n",
 	       fname, Rhs + (lw -topk) , *number);
       return FALSE_;
     };
-    SciToF77(stk(*lr), ix1, ix1);
+      if (!(*lr % 2) ) {  /* bad adress (lr is even) shift up the stack */
+	double2z(stk(*lr), stk(*lr)-1, ix2, ix2);
+	ix2=2*ix2;
+	*istk(iadr(*lr)-4)=133;
+	*istk(iadr(*lr)-3)=iadr(*lr + ix2);
+	*istk( iadr(*lr + ix2) )= *m;
+	*istk( iadr(*lr + ix2) +1 )= *n;
+	*lr = sadr(*lr-1); 
+      } else
+	{
+      SciToF77(stk(*lr), ix2, ix2);
+      *lr = sadr(*lr);
+	}
     break;
   case 'S' :
     /** getwsmat : must be back in stack1.c from xawelm.f */
@@ -1611,6 +1750,7 @@ int C2F(createvarfromptr)(number, typex, m, n, iptr, type_len)
       Nbvars = Max(*number,Nbvars);
       if ( !cre_smat_from_str(fname,&lw1, m, n, (char **) iptr, nlgh)) 
 	return FALSE_;
+      C2F(intersci).iwhere[*number - 1] = *lstk(lw1);
       C2F(intersci).ntypes[*number - 1] = '$';
       break;
     case 's' :
@@ -1618,6 +1758,7 @@ int C2F(createvarfromptr)(number, typex, m, n, iptr, type_len)
       Nbvars = Max(*number,Nbvars);
       if ( !cre_sparse_from_ptr(fname,&lw1, m, n, (SciSparse *) iptr, nlgh))
 	return FALSE_;
+      C2F(intersci).iwhere[*number - 1] = *lstk(lw1);
       C2F(intersci).ntypes[*number - 1] = '$';
       break;
     default :
@@ -1765,6 +1906,12 @@ int C2F(scifunction)(number, ptr, mlhs, mrhs)
 {
   integer cx26 = 26;
   integer ix1, krec, iflagint, ix, k, intop, il, ir, lw;
+  
+  if ( intersci_push() == 0 ) 
+    {
+      Scierror(999,"scifunction: Running out of memory \r\n");
+      goto L9999;
+    }
 
   /*     macro execution */
   intop = Top;
@@ -1895,6 +2042,7 @@ int C2F(scifunction)(number, ptr, mlhs, mrhs)
   /* + */
   Top = intop;
   ix1 = *mlhs;
+  intersci_pop();
   for (ix = 1; ix <= ix1; ++ix) {
     lw = Top - Rhs + *number + ix - 1;
     C2F(intersci).ntypes[lw - 1] = '$';
@@ -1904,6 +2052,7 @@ int C2F(scifunction)(number, ptr, mlhs, mrhs)
  L9999:
   Top = intop;
   --C2F(recu).niv;
+  intersci_pop();
   return FALSE_;
 } 
 
@@ -2002,6 +2151,13 @@ int C2F(scibuiltin)(number, ifun, ifin, mlhs, mrhs)
   integer krec, srhs, slhs, iflagint;
   integer ix, k, intop, il, ir, lw, pt0;
   intop = Top;
+  
+  if ( intersci_push() == 0 ) 
+    {
+      Scierror(999,"scifunction: Running out of memory \r\n");
+      goto L9999;
+    }
+
   Top = Top - Rhs + *number + *mrhs - 1;
   slhs = Lhs;
   srhs = Rhs;
@@ -2123,12 +2279,14 @@ int C2F(scibuiltin)(number, ifun, ifin, mlhs, mrhs)
   Lhs = slhs;
   Rhs = srhs;
   Top = intop;
+  intersci_pop();
   for (ix = 0 ; ix < *mlhs ; ++ix) {
     lw = Top - Rhs + *number + ix ;
     C2F(intersci).ntypes[lw - 1] = '$';
   }
   return TRUE_;
  L9999:
+  intersci_pop();
   return FALSE_;
 }
 
@@ -2313,13 +2471,63 @@ integer C2F(maxvol)(lw, lw_type, type_len)
     case 'i' : return iadr(m);break;
     case 'r' : return iadr(m);break;
     case 'c' : return cadr(m);break;
-    case 'z' : return sadr(m)-1;break;
+    case 'z' : return sadr(m)-3;break;
     }
   /* should never get there */
   return m; 
 }
 
 
+/*---------------------------------------------
+ * This function checks all the variables which 
+ * where references and restore their contents 
+ * to Scilab value. 
+ *---------------------------------------------*/ 
+
+static int Check_references()
+{
+  int ivar ; 
+  for (ivar = 1; ivar <= Rhs ; ++ivar) 
+    {
+      unsigned char Type = C2F(intersci).ntypes[ivar - 1];
+      if ( Type != '$') 
+	{
+	  int lw = ivar + Top - Rhs;
+	  int il = iadr(*lstk(lw));
+	  if ( *istk(il) < 0) 
+	    {
+	      int m,n,it,size;
+	      /* back conversion if necessary of a reference */ 
+	      /* sciprint("%d: is a reference\r\n",ivar);  */
+	      if ( *istk(il) < 0)  il = iadr(*istk(il +1));
+	      m =*istk(il +1);
+	      n =*istk(il +2);
+	      it = *istk(il +3);
+	      switch ( Type ) {
+	      case 'i' : 
+	      case 'r' : 
+	      case 'd' :
+		size  = m * n * (it + 1); break; 
+	      case 'z' :
+		size  = 0;break; /* size is unsued for 'z' in ConvertData;*/
+	      case 'c' : 
+		size =*istk(il + 4  +1) - *istk(il + 4 ); break;
+	      case 'b' :
+		size = m*n ; break;
+	      }
+	      ConvertData(&Type,size,C2F(intersci).lad[ivar - 1]);
+	      C2F(intersci).ntypes[ivar - 1] = '$';
+	    }
+	}
+      else 
+	{
+	  /* sciprint("%d: is of type $ \n",ivar);  */
+	}
+    }
+  return TRUE_; 
+}
+
+
 
 
 /*---------------------------------------------------------------------
@@ -2334,11 +2542,22 @@ integer C2F(maxvol)(lw, lw_type, type_len)
 int C2F(putlhsvar)()
 {
   integer ix2, ivar, ibufprec, ix, k, lcres, nbvars1;
+  integer plhsk;
+  Check_references();
+  
+  for (k = 1; k <= Lhs; k++)
+    {
+      plhsk=*lstk(LhsVar(k)+Top-Rhs);
+      if (*istk( iadr(plhsk) ) < 0) {
+	if (*lstk(Bot) > *lstk(*istk(iadr (plhsk) +2)) )
+	LhsVar(k)=*istk(iadr(plhsk)+2);
+	/* lcres = 0 */
+      }
+    }
 
+  if (C2F(iop).err > 0||C2F(errgst).err1> 0)  return TRUE_ ; 
   if (C2F(com).fun== -1 ) return TRUE_ ; /* execution continue with an 
 					    overloaded function */
-
-
   if (LhsVar(1) == 0) 
     {
       Top = Top - Rhs + Lhs;
@@ -2393,6 +2612,7 @@ int C2F(putlhsvar)()
   return TRUE_;
 } 
 
+
 /*---------------------------------------------------------------------
  * mvfromto : 
  *     this routines copies the variable number i
@@ -2418,22 +2638,22 @@ int C2F(putlhsvar)()
 static int C2F(mvfromto)(itopl, ix)
      integer *itopl, *ix;
 {
-  integer ix1, m,n,it,lcs,lrs ,il; 
+  integer ix1, m,n,it,lcs,lrs,l,ilp,size,pointed;
   unsigned char Type ;
-  int iwh;
-  int izpos,spos;
-/*   FD modif 
-was:
-  m = C2F(intersci).nbrows[*ix - 1];
-  n = C2F(intersci).nbcols[*ix - 1];
-  it = C2F(intersci).itflag[*ix - 1];
-  Type = C2F(intersci).ntypes[*ix - 1];  */
+  double wsave;
 
-  iwh = C2F(intersci).iwhere[*ix - 1];
-  m =*istk( iadr(iwh) +1);
-  n =*istk( iadr(iwh) +2);
-  it = *istk( iadr(iwh) +3);
   Type = C2F(intersci).ntypes[*ix - 1];
+  if ( Type != '$') 
+    {
+      /* int iwh = *ix + Top - Rhs;
+	 ilp = iadr(*lstk(iwh)); */ 
+      int iwh = C2F(intersci).iwhere[*ix - 1];
+      ilp = iadr(iwh); 
+      if ( *istk(ilp) < 0)  ilp = iadr(*istk(ilp +1));
+      m =*istk(ilp +1);
+      n =*istk(ilp +2);
+      it = *istk(ilp +3);
+    }
 
   switch ( Type ) {
   case 'i' : 
@@ -2461,29 +2681,35 @@ was:
      */
     if (C2F(intersci).lad[*ix - 1] != lrs) {
       ix1 = m * n * (it + 1);
-      C2F(dcopy)(&ix1, stk(C2F(intersci).lad[*ix - 1]), &cx1, stk(lrs), &cx1);
+      l=C2F(intersci).lad[*ix - 1];
+      if (abs(l-lrs)<ix1)
+	C2F(unsfdcopy)(&ix1, stk(l), &cx1, stk(lrs), &cx1);
+      else
+	C2F(dcopy)(&ix1, stk(l), &cx1, stk(lrs), &cx1);
       C2F(intersci).lad[*ix - 1] = lrs;
     }
     break;
   case 'z' :
-    if (! C2F(cremat)("mvfromto", itopl, &it, &m, &n, &lrs, &lcs, 8L)) {
-      return FALSE_;
-    }
-    ix1 = m * n * (it + 1);
-    F77ToSci(stk(C2F(intersci).lad[*ix - 1]), m*n, m*n);
-    if (C2F(intersci).lad[*ix - 1] != lrs) {
-      ix1 = m * n * (it + 1);
-      C2F(dcopy)(&ix1, stk(C2F(intersci).lad[*ix - 1]), &cx1, stk(lrs), &cx1);
+    if ( *istk(ilp) == 133 ) {
+      wsave=*stk(C2F(intersci).lad[*ix - 1]); 
+      n=*istk(m+1);m=*istk(m);it=1;
+      if (! C2F(cremat)("mvfromto", itopl, &it, &m, &n, &lrs, &lcs, 8L)) {
+      return FALSE_;  }
+      z2double(stk(C2F(intersci).lad[*ix - 1]),stk(lrs),m*n, m*n);
+      *stk(lrs)=wsave;
       C2F(intersci).lad[*ix - 1] = lrs;
-      C2F(intersci).ladc[*ix - 1] = lrs +m*n;
+      }
+    else { 
+      if (! C2F(cremat)("mvfromto", itopl, &it, &m, &n, &lrs, &lcs, 8L)) {
+	return FALSE_;
+      }
+    z2double(stk(C2F(intersci).lad[*ix - 1]), stk(lrs), m*n, m*n);
+    C2F(intersci).lad[*ix - 1] = lrs;
     }
     break;
   case 'c' : 
-    /*  FD added  next 3 */
-  il = iadr(iwh);
-  m = *istk(il + 4  +1) - *istk(il + 4 );
-  n = 1;
-
+    m = *istk(ilp + 4  +1) - *istk(ilp + 4 );
+    n = 1;
     ix1 = m * n;
     if (! C2F(cresmat2)("mvfromto", itopl, &ix1, &lrs, 8L)) {
       return FALSE_;
@@ -2500,8 +2726,35 @@ was:
     C2F(icopy)(&ix1, istk(C2F(intersci).lad[*ix - 1]), &cx1,istk(lrs), &cx1);
     C2F(intersci).lad[*ix - 1] = lrs;
     break;
-  case 'p' :
-  case '$' :
+  case '-' :
+    /*    reference  '-' = ascii(45) */
+    ilp = iadr(*lstk(*ix));
+    size = *istk(ilp+3);
+    pointed = *istk(ilp+2);
+    if (! C2F(cremat)("mvfromto", itopl, (it=0 ,&it), (m=1, &m), &size, &lrs, &lcs, 8L)) {
+      return FALSE_;
+    }
+    if ( C2F(vcopyobj)("mvfromto", &pointed, itopl, 8L) == FALSE_) 
+	  return FALSE_;
+    break;
+  case 'h' :
+    if (! C2F(crehmat)("mvfromto", itopl, &m, &n, &lrs, 8L)) {
+      return FALSE_;
+    }
+    /* no copy if the two objects are the same 
+     * the cremat above is kept to deal with possible size changes 
+     */
+    if (C2F(intersci).lad[*ix - 1] != lrs) {
+      ix1 = m * n;
+      l=C2F(intersci).lad[*ix - 1];
+      if (abs(l-lrs)<ix1)
+	C2F(unsfdcopy)(&ix1, stk(l), &cx1, stk(lrs), &cx1);
+      else
+	C2F(dcopy)(&ix1, stk(l), &cx1, stk(lrs), &cx1);
+      C2F(intersci).lad[*ix - 1] = lrs;
+    }
+    break;
+  case 'p' :   case '$' :
     /*     special case */
     if (Top - Rhs + *ix != *itopl) 
       {
@@ -2513,6 +2766,36 @@ was:
   return TRUE_;
 } 
 
+
+
+/*---------------------------------------------------------------------
+ * copyref 
+ * copy object at position from to position to 
+ * without changing data. 
+ * The copy is only performed if object is a reference 
+ * and ref object is replaced by its value 
+ *---------------------------------------------------------------------*/
+
+int Ref2val(int from , int to ) 
+{
+  integer il,lw;
+  lw = from + Top - Rhs;
+  if ( from  > Rhs) {
+    Scierror(999,"copyref: bad call to isref! (1rst argument)\r\n");
+    return FALSE_;
+  }
+  il = iadr(*lstk(lw));
+  if ( *istk(il) < 0) 
+    {
+      int lwd ; 
+      /* from contains a reference */ 
+      lw= *istk(il+2); 
+      lwd = to + Top -Rhs;
+      C2F(copyobj)("copyref", &lw, &lwd, strlen("copyref"));
+    }
+  return 0;
+}
+
 /*---------------------------------------------------------------------
  * convert2sci : 
  *     this routine converts data of variable number num 
@@ -2531,61 +2814,6 @@ int C2F(convert2sci)(ix)
 
 
 
-/*---------------------------------------------------------------------
- * int tryenhaut:
- *     this routines checks if the creation of a variable at position 
- *     itopl on the stack would give an adress >= adress of the variable number i 
- *---------------------------------------------------------------------*/
-
-int C2F(tryenhaut)(itopl, ix)
-     integer *itopl, *ix;
-{
-  integer ix1, m,n,it,lcs,lrs ;
-  unsigned char Type ;
-
-  m = C2F(intersci).nbrows[*ix - 1];
-  n = C2F(intersci).nbcols[*ix - 1];
-  it = C2F(intersci).itflag[*ix - 1];
-  Type = (unsigned char) C2F(intersci).ntypes[*ix - 1];
-  switch ( Type ) {
-  case 'i' : 
-    if (! C2F(fakecremat)(itopl, &it, &m, &n, &lrs, &lcs)) return FALSE_;
-    if (it == 0) {
-      if ( sadr(C2F(intersci).lad[*ix - 1]) <= lrs) return FALSE_;
-    } else {
-      if ( sadr(C2F(intersci).ladc[*ix - 1]) <= lcs) return FALSE_;
-    }
-    break;
-  case 'r' : 
-    if (! C2F(fakecremat)(itopl, &it, &m, &n, &lrs, &lcs)) return FALSE_;
-    if (it == 0) {
-      if (sadr(C2F(intersci).lad[*ix - 1]) <= lrs) return  FALSE_;
-    } else {
-      if ( sadr(C2F(intersci).ladc[*ix - 1]) <= lcs) return  FALSE_;
-    }
-    break;
-  case 'b' : 
-    if (! C2F(fakecrebmat)(itopl, &m, &n, &lrs)) 	return FALSE_;
-    if (C2F(intersci).lad[*ix - 1] <= lrs) return  FALSE_;
-    break;
-  case 'd' : 
-    if (! C2F(fakecremat)(itopl, &it, &m, &n, &lrs, &lcs)) return FALSE_;
-    if (it == 0) {
-      if (C2F(intersci).lad[*ix - 1] <= lrs) return FALSE_;
-    } else {
-      if (C2F(intersci).ladc[*ix - 1] <= lcs) return FALSE_;
-    }
-    break;
-  case 'c' : 
-    ix1 = m * n;
-    if (! C2F(fakecresmat2)(itopl, &ix1, &lrs)) return FALSE_;
-    ix1 = sadr(C2F(intersci).lad[*ix - 1]);
-    if ( sadr(ix1) <= lrs) return FALSE_ ;
-    break;
-  }
-  return TRUE_;
-} 
-
 /*-----------------------------------------------------------
  * strcpy_tws : fname[0:nlgh-2]=' '
  * fname[nlgh-1] = '\0'
@@ -2682,7 +2910,8 @@ void ConvertData(type,size,l)
      char *type;
      int size,l;
 {
-  int zero=0,mu=-1;
+  int zero=0,mu=-1; int laddr; int prov,m,n,it;
+  double wsave;
   switch (type[0]) {
   case 'c' :
     C2F(cvstr1)(&size,(int *) cstk(l),cstk(l),&zero,size);
@@ -2693,8 +2922,23 @@ void ConvertData(type,size,l)
   case 'i' :
     C2F(int2db)(&size,istk(l),&mu,(double *)istk(l),&mu);
     break;
- case 'z' :
-   F77ToSci(stk(l), size, size);
+  case 'z' :
+    if (*istk( iadr(iadr(l))-2 ) == 133 ){  /* values @ even adress */
+      prov=*istk( iadr(iadr(l))-1 );
+      m=*istk(prov);n=*istk(prov+1);it=1;
+      laddr=iadr(l);       wsave=*stk(laddr);   
+      /* make header */
+      *istk( iadr(iadr(l))-2 ) = 1;
+      *istk( iadr(iadr(l))-1 ) = m;
+      *istk( iadr(iadr(l)) ) = n;
+      *istk( iadr(iadr(l))+1 ) = it;
+      /* convert values */
+      z2double(stk(laddr),stk(laddr+1),m*n, m*n);
+      *stk(laddr+1)=wsave;
+    } else
+      {
+	F77ToSci((double *) zstk(l), size, size);
+      }
   }
 }
 
@@ -2708,6 +2952,7 @@ static int check_prop(mes,pos,m)
 {
   if ( m ) 
     { 
+      /* XXXX moduler 999 en fn des messages */
       Scierror(999,"%s: %s %s\r\n",
 	       Get_Iname(),
 	       ArgPosition(pos),
@@ -2878,7 +3123,7 @@ int check_list_one_dim(lpos,pos,dim,val,valref)
 
 
 /*---------------------------------------------------------------------
- * Utility for ? 
+ * Utility for hand writen data extraction or creation 
  *---------------------------------------------------------------------*/
 
 int C2F(createdata)(lw, n)
@@ -2907,13 +3152,176 @@ int C2F(createdata)(lw, n)
 
 
 void *GetData(lw)
+     /* Usage: header = (int *) GetData(lw); header[0] = type of variable lw etc */
      int lw;
 {
   int lw1 = lw + Top - Rhs ;
-  int *loci = (int *) stk( *lstk(lw1));
+  int l1 = *lstk(lw1);
+  int *loci = (int *) stk(l1);
+  if (loci[0] < 0) 
+    {
+      l1 = loci[1];
+      loci = (int *) stk(l1);
+    }
   C2F(intersci).ntypes[lw - 1] = '$';
-  C2F(intersci).iwhere[lw - 1] = *lstk(lw1);
-  C2F(intersci).lad[lw - 1] = *lstk(lw1);
+  C2F(intersci).iwhere[lw - 1] = l1;
+  C2F(intersci).lad[lw - 1] = l1;
   return loci;
 }
 
+void *GetRawData(lw)
+     /* same as GetData BUT does not go to the pointed variable if lw is a reference */
+     int lw;
+{
+  int lw1 = lw + Top - Rhs ;
+  int l1 = *lstk(lw1);
+  int *loci = (int *) stk(l1);
+  C2F(intersci).ntypes[lw - 1] = '$';
+  C2F(intersci).iwhere[lw - 1] = l1;
+  return loci;
+}
+
+void *GetDataFromName( char *name )
+     /* usage:  header = (int *) GetDataFromName("pipo"); header[0] = type of variable pipo etc... */
+{
+  void *header; int lw; int fin;
+ if (C2F(objptr)(name,&lw,&fin,strlen(name))) {
+    header = istk( iadr(*lstk(fin)));  
+    return (void *) header;
+  }
+ else
+    {  
+      Scierror(999,"GetDataFromName: variable %s not found\r\n",name);
+      return (void *) 0;
+    }
+}
+
+int C2F(createreference)(number, pointed)
+     int number; int pointed;
+/* variable number is created as a reference to variable pointed */
+{
+  int offset; int point_ed; int *header;
+  CreateData( number, 4*sizeof(int) );
+  header =  GetRawData(number);
+  offset = Top -Rhs;
+  point_ed = offset + pointed;
+  header[0]= - *istk( iadr(*lstk( point_ed )) );  /* reference : 1st entry (type) is opposite */
+  header[1]= *lstk(point_ed);  /* pointed adress */
+  header[2]= point_ed; /* pointed variable */
+  header[3]= *lstk(point_ed + 1)- *lstk(point_ed);  /* size of pointed variable */
+  C2F(intersci).ntypes[number-1]= '-';
+  return 1;
+}
+
+int C2F(changetoref)(number, pointed)
+     int number; int pointed;
+/* variable number is changed as a reference to variable pointed */
+{
+  int offset; int point_ed; int *header;
+  header =  GetRawData(number);
+  offset = Top - Rhs;
+  point_ed = offset + pointed;
+  header[0]= - *istk( iadr(*lstk( point_ed )) );  /* reference : 1st entry (type) is opposite */
+  header[1]= *lstk(point_ed);  /* pointed adress */
+  header[2]= pointed; /* pointed variable */
+  header[3]= *lstk(point_ed + 1) - *lstk(point_ed);  /* size of pointed variable */
+  C2F(intersci).ntypes[number-1]= '-';
+  return 1;
+}
+
+int C2F(createreffromname)(number, name)
+     int number; char *name;
+     /* variable number is created as a reference pointing to variable "name" */
+     /* name must be an existing Scilab variable */
+{
+  int *header; int lw; int fin;
+  CreateData(number, 4*sizeof(int));
+  header = (int *) GetData(number);
+  if (C2F(objptr)(name,&lw,&fin,strlen(name))) {
+    header[0]= - *istk( iadr(*lstk(fin))); /* type of reference = - type of pointed variable */
+    header[1]= lw; /* pointed adress */
+    header[2]= fin; /* pointed variable */
+    header[3]= *lstk(fin+1)- *lstk(fin);  /*size of pointed variable */
+    return 1;
+  }
+  else
+    {  
+      Scierror(999,"CreateRefFromName: variable %s not found\r\n",name);
+      return 0;
+    }
+}
+
+/*-------------------------------------------------------
+ * protect the intersci common during recursive calls 
+ *-------------------------------------------------------*/ 
+
+typedef struct inter_s_ { 
+  int iwhere,nbrows,nbcols,itflag,ntypes,lad,ladc,lhsvar;
+} intersci_state ;
+
+typedef struct inter_l {
+  intersci_state *state ;
+  int nbvars;
+  struct inter_l * next ;
+} intersci_list ;
+
+static intersci_list * L_intersci;
+
+
+static int intersci_push() 
+{
+  int i;
+  intersci_list *loc;
+  intersci_state *new ;
+  new = malloc( Nbvars * sizeof(intersci_state) );
+  if (new == 0 ) return 0;
+  loc = malloc( sizeof(intersci_list) );
+  if ( loc == NULL ) return 0;
+  loc->next = L_intersci;
+  loc->state = new; 
+  loc->nbvars =  Nbvars;
+  for ( i = 0 ; i <  Nbvars ; i++ ) 
+    {
+      loc->state[i].iwhere = C2F(intersci).iwhere[i];
+      loc->state[i].ntypes = C2F(intersci).ntypes[i];
+      loc->state[i].lad    = C2F(intersci).lad[i];
+      loc->state[i].lhsvar = C2F(intersci).lhsvar[i];
+    }
+  L_intersci = loc;
+  return 1;
+}
+
+static void intersci_pop()
+{
+  int i;
+  intersci_list *loc = L_intersci;
+  if ( loc == NULL ) return ;
+  Nbvars =  loc->nbvars;
+  for ( i = 0 ; i <  Nbvars ; i++ ) 
+    {
+      C2F(intersci).iwhere[i] =   loc->state[i].iwhere ;
+      C2F(intersci).ntypes[i] =   loc->state[i].ntypes ;
+      C2F(intersci).lad[i] =   loc->state[i].lad    ;
+      C2F(intersci).lhsvar[i] =   loc->state[i].lhsvar ;
+    }
+  L_intersci = loc->next ;
+  FREE(loc->state);
+  FREE(loc);
+}
+
+/* 
+static void intersci_show()
+{
+  int i;
+  fprintf(stderr,"======================\n");
+  for ( i = 0 ; i < C2F(intersci).nbvars ; i++ ) 
+    {
+      fprintf(stderr,"%d %d %d\n",i,
+	      C2F(intersci).iwhere[i],
+	      C2F(intersci).ntypes[i]);
+    }
+  fprintf(stderr,"======================\n");
+}
+
+*/
+
