@@ -29,6 +29,12 @@ c     9         10       11        12    13
 c     strcat    strindex strsubst ascii  grep
 
 c     
+c      if ( fin.eq.8)  then 
+c         call intssort(id)
+c      else 
+c         call cstrelm()
+c      endif
+c      return 
 
       goto (10,20,25,50,60,70,80,90,100,110,120,125,130) fin
 c     
@@ -165,6 +171,11 @@ c
 c
 c     strcat(tr [,ins])
 c
+      if (rhs.eq.3) then 
+         call cstrelm() 
+         return 
+      endif
+
       if(rhs.ne.1.and.rhs.ne.2) then
          call error(39)
          return
@@ -230,7 +241,7 @@ c
          istk(ilr)=10
          istk(ilr+1)=1
          istk(ilr+2)=1
-         istk(ilr+3)=1
+         istk(ilr+3)=0
          istk(ilr+4)=1
          istk(ilr+5)=1+vol
          l=ilr+6
@@ -257,7 +268,7 @@ c
          istk(ilr)=10
          istk(ilr+1)=1
          istk(ilr+2)=1
-         istk(ilr+3)=1
+         istk(ilr+3)=0
          istk(ilr+4)=1
          istk(ilr+5)=1+vol
          l=ilr+6
@@ -398,7 +409,7 @@ c     a match found
          endif
       endif
       stk(lpos+mc-1)=ll1-l1+1
-      ll1=ll1+k-1
+c      ll1=ll1+k-1
       goto 10
  35   continue
 c     end of string str1 reached
@@ -1163,11 +1174,6 @@ c
          ilr=il
          if(istk(il).lt.0) il=iadr(istk(il+1))
          ref=ilr.ne.il
-         if(istk(il+3).ne.0) then
-            err=1
-            call error(52)
-            return
-         endif
          m=istk(il+1)
          n=istk(il+2)
          if(m*n.eq.0) then
@@ -1427,8 +1433,8 @@ c     sort(a,'r')  <=>  sort(a,1)
 c
       integer id(nsiz),tops,vol,sel,eol
       logical ref
-      external strord,getcode
-      integer strord,getcode
+      external strord,getfastcode
+      integer strord,getfastcode
       character*1 c
       integer iadr,sadr
       data eol/99/
@@ -1477,8 +1483,8 @@ c     argument is a vector of ascii codes return a scilab string
          istk(ilr+5)=1+n
          lr=ilr+6
          do 20 i=0,n-1
-            m=int(stk(l+i))
-            istk(lr+i)=getcode(m)
+            c=char(int(stk(l+i)))
+            istk(lr+i)=getfastcode(c)
  20      continue
          lstk(top+1)=sadr(lr+n)
       elseif(istk(il).eq.10) then
