@@ -256,6 +256,11 @@ c     get arg1
       il1=iadr(lstk(top))
       ilrs=il1
       if(istk(il1).lt.0) il1=iadr(istk(il1+1))
+      if (istk(il1).eq.10.or.istk(il1).eq.15) then
+         top=top0
+         fin=-fin
+         return
+      endif
       m1=istk(il1+1)
       n1=istk(il1+2)
 c
@@ -479,7 +484,7 @@ c     .     arg4([],arg2)=[],  arg4(arg1,[])=[] --> arg4
             istk(ilrs+2)=n4
             istk(ilrs+3)=0
             volr=istk(id4+mn4)-1
-            call icopy(mn4+volr,istk(id4),1,istk(ilrs+4),1)
+            call icopy(mn4+1+volr,istk(id4),1,istk(ilrs+4),1)
             lstk(top+1)=sadr(ilrs+5+mn4+volr)
             goto 999
          elseif(m2.eq.-1) then
