@@ -5,30 +5,35 @@
 #include "men_scilab.h"
 #endif
 
-int MatrixDialogWindow();
+int MatrixDialogWindow(void);
 
-MADialog MAD;
+MADialog MAD = { NULL,NULL,NULL,NULL,-1,0,0,0};
 
 /*************************************************     
  * Interface with Scilab 
  **********************************************************/
 
-void C2F(xmatdg)(label,ptrlab,nlab,value,ptrv,descv,ptrdescv,desch,ptrdesch,nl,nc,res,ptrres,ierr)
-     int *label,*ptrlab,*nlab,*value,*ptrv,*descv,*ptrdescv,*desch,*ptrdesch,*nl,*nc,*res,*ptrres,*ierr;
+void C2F(xmatdg)(int *label, int *ptrlab, int *nlab, int *value, int *ptrv, int *descv, int *ptrdescv, int *desch, int *ptrdesch, int *nl, int *nc, int *res, int *ptrres, int *ierr)
 {
   int i,rep;
-  int maxchars= *ierr;
+  int maxchars; 
+  if ( MAD.nv >= 0) 
+    {
+      sciprint("Only one madialog at a time please \r\n");
+      return ;
+    }
+  maxchars = *ierr;
   *ierr=0;
   MAD.nv = *nl*(*nc);
   /* conversion of scilab characters into strings */
   ScilabMStr2C(label,nlab,ptrlab,&(MAD.labels),ierr);
-  if ( *ierr == 1) return;
+  if ( *ierr == 1) { MAD.nv = -1; return; }
   ScilabMStr2CM(descv,nl,ptrdescv,&(MAD.VDesc),ierr);
-  if ( *ierr == 1) return;
+  if ( *ierr == 1) { MAD.nv = -1; return; }
   ScilabMStr2CM(desch,nc,ptrdesch,&(MAD.HDesc),ierr);
-  if ( *ierr == 1) return;
+  if ( *ierr == 1) { MAD.nv = -1; return; }
   ScilabMStr2CM(value,&(MAD.nv),ptrv,&(MAD.data),ierr);
-  if ( *ierr == 1) return;
+  if ( *ierr == 1) { MAD.nv = -1; return; }
   MAD.nl = *nl;
   MAD.nc = *nc;
   MAD.ierr = 0;
@@ -46,13 +51,15 @@ void C2F(xmatdg)(label,ptrlab,nlab,value,ptrv,descv,ptrdescv,desch,ptrdesch,nl,n
   for (i=0;i< MAD.nl*MAD.nc;i++) FREE(MAD.data[i]); FREE(MAD.data);
   for (i=0;i< MAD.nl;i++) FREE(MAD.VDesc[i]); FREE(MAD.VDesc);
   for (i=0;i< MAD.nc;i++) FREE(MAD.HDesc[i]); FREE(MAD.HDesc);
+  MAD.nv = -1;
+
 }
 
 /*************************************************     
  * Test function 
  **********************************************************/
 
-int TestMatrixDialogWindow()
+int TestMatrixDialogWindow(void)
 {
   int rep,i;
   static char *labels = "LaBel";
