@@ -1,10 +1,10 @@
-      subroutine dmpdsp(mp,d,nl,m,n,var,lvar,maxc,mode,ll,lunit,
-     1     cw,iw)
-c     !but
+      subroutine dmpdsp(mp,d,nl,mm,nn,var,lvar,maxc,mode,ll,lunit,
+     1    cw,iw)
+c!but
 c     dmpdsp ecrit une matrice polynomiale (ou un polynome) sous
 c     la forme d'un tableau de polynomes, avec gestion automatique de
 c     l'espace disponible.
-c     !liste d'appel
+c!liste d'appel
 c     
 c     subroutine dmpdsp(mp,d,nl,m,n,var,lvar,maxc,mode,ll,lunit,
 c     1                  cw,iw)
@@ -35,7 +35,9 @@ c     lunit : etiquette logique du support d'edition
 c     cw : chaine de caracteres de travail de longueur au moins 2*ll
 c     iw : tableau de travail entier de taille au moins egale a
 c     d(nl*n+1)-d(1) + m*n+1
-c     !
+c!
+c     Copyright INRIA
+
       double precision mp(*),a
       integer d(*),iw(*),maxc,mode,fl,c1,c2,typ
       integer sl,sk
@@ -43,6 +45,9 @@ c     !
       character var*(*),cw*(*),sgn*1,dl*1
       character*10 form(2),fexp,expo
 c     
+      m=abs(mm)
+      n=abs(nn)
+
       cw=' '
       write(form(1),130) maxc,maxc-7
       dl=' '
@@ -138,6 +143,15 @@ c
  21   continue
       nbloc=min(nbloc,n)
 c     
+      l1=1
+      if(mm.lt.0) then
+         write(cw(l1:l1+4),'(''eye *'')') 
+         l1=l1+5
+         call basout(io,lunit,cw(1:l1-1))
+         call basout(io,lunit,' ')
+         if(io.eq.-1) goto 99
+      endif
+
 c     
 c     phase d'edition : les deux chaines de caracteres representant
 c     la ligne des exposants et la ligne des coefficients,sont
