@@ -1,3 +1,4 @@
+
       subroutine coselm
 c ====================================================================
 c
@@ -23,11 +24,11 @@ c
       endif
 c
 c     functions/fin
-c     var2vec  vec2var get_import set_import get_curblk getlabel
-c       1          2       3         4         5          6
-c
-c     
-      goto(10,20,30,40,50,60) fin
+c     var2vec  vec2var get_import set_import get_curblk getlabel duplicate
+c       1          2       3         4         5          6         7
+c     scicos_cpass2  diffobjs
+c           8            9
+      goto(10,20,30,40,50,60,70,80,90) fin
 
 c     var2vec
  10   continue
@@ -95,6 +96,22 @@ c     getblocklabel
       call intgetlabel
       goto 999
 c
+c     duplicate
+ 70   continue
+      call intduplicate('duplicate')
+      call putlhsvar
+      goto 999
+c     cpass2
+ 80   continue
+      call intcpass2('scicos_cpass2')
+      call putlhsvar
+      goto 999
+c     cpass2
+ 90   continue
+      call intdiffobjs('diffobjs')
+      call putlhsvar
+      goto 999
+c     
  999  return
       end
 
