@@ -56,7 +56,8 @@ c
          if(outptr(kfun+1)-outptr(kfun).gt.0) then
             nclock=ordclk(ii,2)
             flag=1
-            call callf(kfun,nclock,funptr,funtyp,told,w,x,xptr,z,
+            call callf(kfun,nclock,funptr,funtyp,told,
+     $           x(xptr(nblk+1)),x,x,xptr,z,
      $           zptr,iz,izptr,rpar,rpptr,ipar,ipptr,tvec,
      $           ntvec,inpptr,inplnk,outptr,outlnk,lnkptr,
      $           outtb,flag) 
@@ -72,28 +73,25 @@ c
 c     .     Initialize tvec
          ntvec=clkptr(kfun+1)-clkptr(kfun)
          if(ntvec.gt.0) then
-            if(funtyp(kfun).ne.-1)  call dset(ntvec,told-1.0d0,tvec,1)
-c     
-            flag=3
-            call callf(kfun,ordclk(ii,2),funptr,funtyp,told,w,x,
-     $           xptr,z,zptr,iz,izptr,rpar,rpptr,ipar,ipptr,tvec,
-     $           ntvec,inpptr,inplnk,outptr,outlnk,lnkptr,
-     $           outtb,flag) 
-            if(flag.lt.0) then
-               ierr=5-flag
-               return
-            endif
-c     
-            if (ntvec.ge.1) then
-               if(funtyp(kfun).eq.-1) then
-                  urg=urg+1
-                  call putevs(tevts,evtspt,nevts,pointi,
-     &                 told,ntvec+clkptr(kfun)-1,ierr1)
-                  if (ierr1 .ne. 0) then
-C     !                 event conflict
-                     ierr = 3
-                     return
+            if(funtyp(kfun).lt.0)  then
+               if(funtyp(kfun).eq.-1)  then
+                  if (outtb(lnkptr(inplnk(inpptr(kfun)))).le.0) then
+                     ntvec=2
+                  else
+                     ntvec=1
                   endif
+               elseif (funtyp(kfun).eq.-2)  then
+                  ntvec=max(min(int(outtb(
+     $                 lnkptr(inplnk(inpptr(kfun))))),
+     $                 ntvec),1)
+               endif
+               urg=urg+1
+               call putevs(tevts,evtspt,nevts,pointi,
+     &              told,ntvec+clkptr(kfun)-1,ierr1)
+               if (ierr1 .ne. 0) then
+C     !                 event conflict
+                  ierr = 3
+                  return
                endif
             endif
          endif
@@ -159,7 +157,7 @@ c
          if(outptr(kfun+1)-outptr(kfun).gt.0) then
             flag=1
             call callf(kfun,nclock,funptr,funtyp,told,
-     $           x,x,xptr,z,zptr,iz,izptr,rpar,
+     $           x(xptr(nblk+1)),x,x,xptr,z,zptr,iz,izptr,rpar,
      $           rpptr,ipar,ipptr,tvec,ntvec,inpptr,
      $           inplnk,outptr,outlnk,lnkptr,outtb,flag) 
             if (flag .lt. 0) then
@@ -170,28 +168,26 @@ c
 c     
          ntvec=clkptr(kfun+1)-clkptr(kfun)
          if(ntvec.gt.0) then
-            if(funtyp(kfun).ne.-1) call dset(ntvec,told-1.0d0,tvec,1)
+            if(funtyp(kfun).lt.0) then
 c     
-            flag=3
-            call callf(kfun,nclock,funptr,funtyp,told,w,x,
-     $           xptr,z,zptr,iz,izptr,rpar,rpptr,ipar,ipptr,tvec,
-     $           ntvec,inpptr,inplnk,outptr,outlnk,lnkptr,
-     $           outtb,flag) 
-            if(flag.lt.0) then
-               ierr=5-flag
-               return
-            endif
-c     
-            if (ntvec.ge.1) then
-               if(funtyp(kfun).eq.-1) then
-                  urg=urg+1
-                  call putevs(tevts,evtspt,nevts,pointi,
-     &                 told,ntvec+clkptr(kfun)-1,ierr1)
-                  if (ierr1 .ne. 0) then
-C     !                 event conflict
-                     ierr = 3
-                     return
+               if (funtyp(kfun).eq.-1) then
+                  if (outtb(lnkptr(inplnk(inpptr(kfun)))).le.0) then
+                     ntvec=2
+                  else
+                     ntvec=1
                   endif
+               elseif (funtyp(kfun).eq.-2) then
+                  ntvec=max(min(int(outtb(
+     $                 lnkptr(inplnk(inpptr(kfun))))),
+     $                 ntvec),1)
+               endif
+               urg=urg+1
+               call putevs(tevts,evtspt,nevts,pointi,
+     &              told,ntvec+clkptr(kfun)-1,ierr1)
+               if (ierr1 .ne. 0) then
+C     !                 event conflict
+                  ierr = 3
+                  return
                endif
             endif
          endif
@@ -262,80 +258,7 @@ c
 c     
 c     
       kiwa=0
-      urg=0
-      keve = pointi
-      pointi=evtspt(keve)
-      evtspt(keve)=-1
-c     
-      nord=ordptr(keve+1)-ordptr(keve)
-      if(nord.eq.0) return
-
-         kiwa=kiwa+1
-         iwa(kiwa)=keve
- 
-
-
-      do 80 ii=ordptr(keve),ordptr(keve+1)-1
-         kfun=ordclk(ii,1)
-        
-c     
-         if(outptr(kfun+1)-outptr(kfun).gt.0) then
-            nclock=ordclk(ii,2)
-            flag=1
-            call callf(kfun,nclock,funptr,funtyp,told,w,x,xptr,z,
-     $           zptr,iz,izptr,rpar,rpptr,ipar,ipptr,tvec,
-     $           ntvec,inpptr,inplnk,outptr,outlnk,lnkptr,
-     $           outtb,flag) 
-            if(flag.lt.0) then
-               ierr=5-flag
-               return
-            endif
-         endif
- 80   continue
-c     
-      do 60 ii=ordptr(keve),ordptr(keve+1)-1
-         kfun=ordclk(ii,1)
-c     .     Initialize tvec
-         ntvec=clkptr(kfun+1)-clkptr(kfun)
-         if(ntvec.gt.0) then
-            if(funtyp(kfun).ne.-1) call dset(ntvec,told-1.0d0,tvec,1)
-c     
-            flag=3
-            call callf(kfun,ordclk(ii,2),funptr,funtyp,told,w,x,
-     $           xptr,z,zptr,iz,izptr,rpar,rpptr,ipar,ipptr,tvec,
-     $           ntvec,inpptr,inplnk,outptr,outlnk,lnkptr,
-     $           outtb,flag) 
-            if(flag.lt.0) then
-               ierr=5-flag
-               return
-            endif
-c     
-            if (ntvec.ge.1) then
-               if(funtyp(kfun).ne.-1) then
-                  do 70 i = 1,ntvec
-                     if (tvec(i) .ge. told) then
-                        call addevs(tevts,evtspt,nevts,pointi,
-     &                       tvec(i),i+clkptr(kfun)-1,ierr1)
-                        if (ierr1 .ne. 0) then
-C     !                 event conflict
-                           ierr = 3
-                           return
-                        endif
-                     endif
- 70               continue
-               else
-                  urg=urg+1
-                  call putevs(tevts,evtspt,nevts,pointi,
-     &                 told,ntvec+clkptr(kfun)-1,ierr1)
-                  if (ierr1 .ne. 0) then
-C     !                 event conflict
-                     ierr = 3
-                     return
-                  endif
-               endif
-            endif
-         endif
- 60   continue
+      urg=1
       if (urg.gt.0)  then
  43      call edoit(neq,x,xptr,z,zptr,iz,izptr,told,tf
      $        ,tevts,evtspt,nevts,pointi,inpptr,inplnk,outptr
@@ -361,9 +284,14 @@ c     .  update continuous and discrete states on event
 C     If continuous state jumps, do cold restart
             if(xptr(kfun+1)-xptr(kfun)+zptr(kfun+1)-zptr(kfun)
      $           .gt.0) then 
-               if(xptr(kfun+1)-xptr(kfun).gt.0) hot=.false.
+c     Solution not satisfying but... Have to find a better test
+c     to know if state can jump. If we only leave the first test
+c     it sets hot to false at every event!
+               if(xptr(kfun+1)-xptr(kfun).gt.0.and.ordclk(ii,2).ne.0)
+     $              hot=.false.
                flag=2
-               call callf(kfun,ordclk(ii,2),funptr,funtyp,told,w,x,
+               call callf(kfun,ordclk(ii,2),funptr,funtyp,told,
+     $              x(xptr(nblk+1)),x,x,
      $              xptr,z,zptr,iz,izptr,rpar,rpptr,ipar,ipptr,tvec,
      $              ntvec,inpptr,inplnk,outptr,outlnk,lnkptr,
      $              outtb,flag) 
@@ -443,7 +371,8 @@ c
          if(outptr(kfun+1)-outptr(kfun).gt.0) then
             nclock=ordclk(ii,2)
             flag=1
-            call callf(kfun,nclock,funptr,funtyp,told,w,x,xptr,z,
+            call callf(kfun,nclock,funptr,funtyp,told,
+     $           x(xptr(nblk+1)),x,x,xptr,z,
      $           zptr,iz,izptr,rpar,rpptr,ipar,ipptr,tvec,
      $           ntvec,inpptr,inplnk,outptr,outlnk,lnkptr,
      $           outtb,flag) 
@@ -459,21 +388,21 @@ c
 c     .     Initialize tvec
          ntvec=clkptr(kfun+1)-clkptr(kfun)
          if(ntvec.gt.0) then
-            if(funtyp(kfun).ne.-1) call dset(ntvec,told-1.0d0,tvec,1)
+            if (funtyp(kfun).ge.0) then
+               call dset(ntvec,told-1.0d0,tvec,1)
 c     
-            flag=3
-            call callf(kfun,ordclk(ii,2),funptr,funtyp,told,w,x,
-     $           xptr,z,zptr,iz,izptr,rpar,rpptr,ipar,ipptr,tvec,
-     $           ntvec,inpptr,inplnk,outptr,outlnk,lnkptr,
-     $           outtb,flag) 
-            if(flag.lt.0) then
-               ierr=5-flag
-               return
-            endif
+               flag=3
+               call callf(kfun,ordclk(ii,2),funptr,funtyp,told,
+     $              x(xptr(nblk+1)),x,x,
+     $              xptr,z,zptr,iz,izptr,rpar,rpptr,ipar,ipptr,tvec,
+     $              ntvec,inpptr,inplnk,outptr,outlnk,lnkptr,
+     $              outtb,flag) 
+               if(flag.lt.0) then
+                  ierr=5-flag
+                  return
+               endif
 c     
-
-            if (ntvec.ge.1) then
-               if(funtyp(kfun).ne.-1) then
+               if (ntvec.ge.1) then
                   do 70 i = 1,ntvec
                      if (tvec(i) .ge. told) then
                         call addevs(tevts,evtspt,nevts,pointi,
@@ -485,19 +414,30 @@ C     !                 event conflict
                         endif
                      endif
  70               continue
-               else
-                  urg=urg+1
-                  call putevs(tevts,evtspt,nevts,pointi,
-     &                 told,ntvec+clkptr(kfun)-1,ierr1)
-                  if (ierr1 .ne. 0) then
-C     !                 event conflict
-                     ierr = 3
-                     return
+               endif
+
+            else
+               if (funtyp(kfun).eq.-1) then
+                  if (outtb(lnkptr(inplnk(inpptr(kfun)))).le.0) then
+                     ntvec=2
+                  else
+                     ntvec=1
                   endif
+               elseif (funtyp(kfun).eq.-2) then
+                  ntvec=max(min(int(outtb(
+     $                 lnkptr(inplnk(inpptr(kfun))))),
+     $                 ntvec),1)
+               endif
+               urg=urg+1
+               call putevs(tevts,evtspt,nevts,pointi,
+     &              told,ntvec+clkptr(kfun)-1,ierr1)
+               if (ierr1 .ne. 0) then
+C     !                 event conflict
+                  ierr = 3
+                  return
                endif
             endif
          endif
  60   continue
       end
 
-
