@@ -11,12 +11,6 @@ c
       integer nipar,nu,ny
 
 c
-      common /dbcos/ idb
-c
-      if(idb.eq.1) then
-         write(6,'(''lusat     t='',e10.3,'' flag='',i1)') t,flag
-      endif
-
  10   do 15 i=1,nu
          if (u(i).le.rpar(1))then
             y(i)=rpar(1)*rpar(3)
