@@ -13,12 +13,7 @@ c
 
 
       integer i
-      common /dbcos/ idb
-c
-      if(idb.eq.1) then
-         write(6,'(''qzcel    t='',e10.3,'' flag='',i1)') t,flag
-      endif
-      
+c      
       do 15 i=1,nu
         y(i)=rpar(i)*ANINT(u(i)/rpar(i)-0.5d0)
  15   continue
