@@ -56,7 +56,8 @@ c
          if(outptr(kfun+1)-outptr(kfun).gt.0) then
             nclock=ordclk(ii,2)
             flag=1
-            call callf(kfun,nclock,funptr,funtyp,told,x,x,xptr,z,
+            call callf(kfun,nclock,funptr,funtyp,told,
+     $           xd,x,x,xptr,z,
      $           zptr,iz,izptr,rpar,rpptr,ipar,ipptr,tvec,
      $           ntvec,inpptr,inplnk,outptr,outlnk,lnkptr,
      $           outtb,flag) 
@@ -69,31 +70,27 @@ c
 c     .     Initialize tvec
          ntvec=clkptr(kfun+1)-clkptr(kfun)
          if(ntvec.gt.0) then
-            call dset(ntvec,told-1.0d0,tvec,1)
+            if(funtyp(kfun).lt.0) then
 c     
-            flag=3
-            call callf(kfun,ordclk(ii,2),funptr,funtyp,told,x,x,
-     $           xptr,z,zptr,iz,izptr,rpar,rpptr,ipar,ipptr,tvec,
-     $           ntvec,inpptr,inplnk,outptr,outlnk,lnkptr,
-     $           outtb,flag) 
-            if(flag.lt.0) then
-               ierr=5-flag
-               return
-            endif
-c     
-            if (ntvec.ge.1) then 
-               do 70 i = 1,ntvec
-                  if (tvec(i) .gt. told) then
-                     urg=urg+1
-                     call putevs(tevts,evtspt,nevts,pointi,
-     &                    tvec(i),i+clkptr(kfun)-1,ierr1)
-                     if (ierr1 .ne. 0) then
-C     !                 event conflict
-                        ierr = 3
-                        return
-                     endif
+               if (funtyp(kfun).eq.-1) then
+                  if (outtb(lnkptr(inplnk(inpptr(kfun)))).le.0) then
+                     ntvec=2
+                  else
+                     ntvec=1
                   endif
- 70            continue
+               elseif (funtyp(kfun).eq.-2) then
+                  ntvec=max(min(int(outtb(
+     $                 lnkptr(inplnk(inpptr(kfun))))),
+     $                 ntvec),1)
+               endif
+               urg=urg+1
+               call putevs(tevts,evtspt,nevts,pointi,
+     &              told,ntvec+clkptr(kfun)-1,ierr1)
+               if (ierr1 .ne. 0) then
+C     !                 event conflict
+                  ierr = 3
+                  return
+               endif
             endif
          endif
  60   continue
@@ -150,6 +147,7 @@ c
       double precision atol,rtol,ttol,deltat
       common /costol/ atol,rtol,ttol,deltat
 c     
+
       urg=0
       do 19 jj=1,nzord
          kfun=zord(jj)
@@ -157,9 +155,10 @@ c
          if(outptr(kfun+1)-outptr(kfun).gt.0) then
             flag=1
             call callf(kfun,nclock,funptr,funtyp,told,
-     $           x,x,xptr,z,zptr,iz,izptr,rpar,
+     $           xd,x,x,xptr,z,zptr,iz,izptr,rpar,
      $           rpptr,ipar,ipptr,tvec,ntvec,inpptr,
      $           inplnk,outptr,outlnk,lnkptr,outtb,flag) 
+
             if (flag .lt. 0) then
                ierr = 5 - flag
                return
@@ -168,30 +167,28 @@ c
 c     
          ntvec=clkptr(kfun+1)-clkptr(kfun)
          if(ntvec.gt.0) then
-            call dset(ntvec,told-1.0d0,tvec,1)
+            if(funtyp(kfun).lt.0) then
 c     
-            flag=3
-            call callf(kfun,nclock,funptr,funtyp,told,x,x,
-     $           xptr,z,zptr,iz,izptr,rpar,rpptr,ipar,ipptr,tvec,
-     $           ntvec,inpptr,inplnk,outptr,outlnk,lnkptr,
-     $           outtb,flag) 
-            if(flag.lt.0) then
-               ierr=5-flag
-               return
-            endif
-c     
-            do 70 i = 1,ntvec
-               if (tvec(i) .ge. told) then
-                  urg=urg+1
-                  call putevs(tevts,evtspt,nevts,pointi,
-     &                 tvec(i),i+clkptr(kfun)-1,ierr1)
-                  if (ierr1 .ne. 0) then
-C     !                 event conflict
-                     ierr = 3
-                     return
+               if (funtyp(kfun).eq.-1) then
+                  if (outtb(lnkptr(inplnk(inpptr(kfun)))).le.0) then
+                     ntvec=2
+                  else
+                     ntvec=1
                   endif
+               elseif (funtyp(kfun).eq.-2) then
+                  ntvec=max(min(int(outtb(
+     $                 lnkptr(inplnk(inpptr(kfun))))),
+     $                 ntvec),1)
                endif
- 70         continue
+               urg=urg+1
+               call putevs(tevts,evtspt,nevts,pointi,
+     &              told,ntvec+clkptr(kfun)-1,ierr1)
+               if (ierr1 .ne. 0) then
+C     !                 event conflict
+                  ierr = 3
+                  return
+               endif
+            endif
          endif
  19   continue
 c
