@@ -27,7 +27,17 @@ extern char * SciGetLine __PARAMS((char *));
 extern FILE *GetFile __PARAMS((int *));
 extern void C2F(zzledt1) __PARAMS((char *buffer, int *buf_size, int *len_line, int *eof, long int dummy1)); 
 extern int C2F(xscion) __PARAMS((int *));
-extern int sciprint2 __PARAMS((int i,char *fmt, ...));
+
+#ifdef __STDC__ 
+extern int  sciprint2(int iv,char *fmt,...) ;
+#else 
+/*VARARGS0*/
+extern int sciprint2() ;
+#endif 
+
+
+/* extern int sciprint2 __PARAMS((int i,char *fmt, ...));*/
+
 static int do_printf __PARAMS((char *fname,FILE * fp, char *format,int n_args,
 			      int arg_cnt,int lcount,char **strv));
 
@@ -76,17 +86,16 @@ static int GetScalarInt __PARAMS((char *fname,int *first,int *arg,int narg,
 static int GetScalarDouble  __PARAMS((char *fname,int *first,int *arg,int narg,
 				     int *ir,int ic,double *dval));
 static int StringConvert __PARAMS((char *str));
-static int ReadLine __PARAMS((FILE *fd));
+
 int NumTokens __PARAMS((char *str));
 
 /*********************************************************************
  * Scilab printf function OK 
  *********************************************************************/
 
-int int_objprintf(fname)
-     char *fname;
+int int_objprintf(char *fname)
 {
-  static int l1, m1, n1, lcount, rval, k, typ, mx, mk, nk;
+  static int l1, m1, n1, lcount, rval, k, mx, mk, nk;
   Nbvars = 0;
   CheckRhs(1,1000);
   CheckLhs(0,1);
@@ -95,6 +104,11 @@ int int_objprintf(fname)
       Scierror(999,"Error:\tRhs must be > 0\r\n");
       return 0;
     }
+
+  for (k=2;k<=Rhs;k++) {
+    if (VarType(k) !=1 && VarType(k) !=10) {OverLoad(k);return 0;}
+  }
+
   GetRhsVar(1,"c",&m1,&n1,&l1);
 
   mx=0;
@@ -125,8 +139,7 @@ int int_objprintf(fname)
  * Scilab fprintf function OK 
  *********************************************************************/
 
-int int_objfprintf(fname)
-     char *fname;
+int int_objfprintf(char *fname)
 {
   FILE *f;
   static int l1, m1, n1,l2,m2,n2,lcount,rval, mx, mk, nk, k;
@@ -138,6 +151,9 @@ int int_objfprintf(fname)
       Scierror(999,"Error:\tRhs must be >= 2\r\n");
       return 0;
     }
+  for (k=3;k<=Rhs;k++) {
+    if (VarType(k) !=1 && VarType(k) !=10) {OverLoad(k);return 0;}
+  }
   GetRhsVar(1,"i",&m1,&n1,&l1); /* file id */
   GetRhsVar(2,"c",&m2,&n2,&l2); /* format */
   if ((f= GetFile(istk(l1))) == (FILE *)0)
@@ -173,8 +189,7 @@ int int_objfprintf(fname)
  * Scilab sprintf function OK 
  *********************************************************************/
 
-int int_objsprintf(fname)
-     char *fname;
+int int_objsprintf(char *fname)
 {
   unsigned long lstr;
   static int l1, m1, n1,n2,lcount,rval,blk=200;
@@ -190,6 +205,9 @@ int int_objsprintf(fname)
       Scierror(999,"Error:\tRhs must be > 0\r\n");
       return 0;
     }
+  for (k=2;k<=Rhs;k++) {
+    if (VarType(k) !=1 && VarType(k) !=10) {OverLoad(k);return 0;}
+  }
   GetRhsVar(1,"c",&m1,&n1,&l1);
   n=0; /* output line counter */
   nmax=0;
@@ -258,10 +276,10 @@ int int_objsprintf(fname)
   if (rval == RET_BUG) return 0;
   /** Create a Scilab String : lstr must not be freed **/
   n2=1;
-  CreateVarFromPtr( 2, "S", &n, &n2, strs);
+  CreateVarFromPtr(Rhs+1, "S", &n, &n2, strs);
   for (k=0;k<n;k++) free(strs[k]);
   free(strs);
-  LhsVar(1)=2;
+  LhsVar(1)=Rhs+1;
   PutLhsVar();    
   return 0;
  mem:
@@ -275,8 +293,7 @@ int int_objsprintf(fname)
 #define MAXSTR 512
 
 
-int int_objscanf(fname)
-     char *fname;
+int int_objscanf(char *fname)
 {
   static char String[MAXSTR];
   static int l1, m1, n1, len= MAXSTR-1,iarg,maxrow,nrow,rowcount,ncol;
@@ -329,7 +346,12 @@ int int_objscanf(fname)
     /** use the scaned line as input **/
     args = Rhs; /* args set to Rhs on entry */
     if (do_scanf("scanf",(FILE *) 0,cstk(l1),&args,String,&retval,buf,type) < 0) return 0;
-
+    if ( retval == EOF) {
+      /* 
+	 Scierror(999,"Error: in %s: end of file reached\r\n",fname);
+	 return 0;
+      */
+    }
     if ((err=Store_Scan(&nrow,&ncol,type_s,type,&retval,&retval_s,
 			buf,&data,rowcount,args)) <0 ) {
       switch (err) {
@@ -360,8 +382,7 @@ int int_objscanf(fname)
  * Scilab sscanf function
  *********************************************************************/
 
-int int_objsscanf(fname)
-     char *fname;
+int int_objsscanf(char *fname)
 {
   static int l1, m1, n1,l2,m2,n2,iarg,maxrow,nrow,rowcount,ncol;
   int args,retval,retval_s,err,n_count,lw,il1,ild1,skip;
@@ -404,7 +425,7 @@ int int_objsscanf(fname)
   while (1) {
     rowcount++;
     if ((maxrow >= 0) && (rowcount >= maxrow)) break;
-
+    if ( k >= m1*n1 ) break;
     skip=*istk(ild1+k)-1;
     SciStrtoStr(istk(il1+skip),&n_count,istk(ild1+k),&str);
     k +=n_count;
@@ -412,7 +433,14 @@ int int_objsscanf(fname)
     args = Rhs; /* args set to Rhs on entry */
     err = do_scanf("sscanf",(FILE *)0,cstk(l2),&args,str,&retval,buf,type);
     free(str);
-    if ( err < 0)  return 0;
+    if ( err < 0 )  return 0;
+    if ( retval == EOF) {
+      /* 
+	 first returned argument wil be set to -1 
+	 Scierror(999,"Error: in %s: end of string reached\r\n",fname);
+	 return 0;
+      */
+    }
     if ((err=Store_Scan(&nrow,&ncol,type_s,type,&retval,&retval_s,
 			buf,&data,rowcount,args)) <0 ) {
       switch (err) {
@@ -442,8 +470,7 @@ int int_objsscanf(fname)
  * Scilab fscanf function
  *********************************************************************/
 
-int int_objfscanf(fname)
-     char *fname;
+int int_objfscanf(char *fname)
 {
   static int l1, m1, n1,l2,m2,n2,iarg,maxrow,nrow,rowcount,ncol;
   FILE  *f;
@@ -488,6 +515,12 @@ int int_objfscanf(fname)
     args = Rhs; /* args set to Rhs on entry */
     pos=ftell(f);
     if ( do_scanf("fscanf",f,cstk(l2),&args,(char *)0,&retval,buf,type) < 0 )  return 0;
+    if ( retval == EOF) {
+      /* 
+      Scierror(999,"Error: in %s: end of file reached\r\n",fname);
+      return 0;
+      */
+    }
     if ((err=Store_Scan(&nrow,&ncol,type_s,type,&retval,&retval_s,
 			buf,&data,rowcount,args)) <0 ) {
       switch (err) {
@@ -521,8 +554,7 @@ int int_objfscanf(fname)
  * Scilab numtokens
  *********************************************************************/
 
-int int_objnumTokens(fname)
-     char *fname;
+int int_objnumTokens(char *fname)
 {
   static int l1,m1,n1,l2,un=1;
   Nbvars = 0;
@@ -539,20 +571,21 @@ int int_objnumTokens(fname)
 
 /*********************************************************************
  * Scilab fprintfMat function
+ * fprintfMat('pipo',rand(2,2),'%f',['comment un';'comment 2'])
  *********************************************************************/
 
-int int_objfprintfMat(fname)
-     char *fname;
+int int_objfprintfMat(char *fname)
 {
-  int l1, m1, n1,l2,m2,n2,m3,n3,l3,i,j;
+  int l1, m1, n1,l2,m2,n2,m3,n3,l3,i,j,mS,nS;
   FILE  *f;
+  char **Str2;
   char *Format;
   Nbvars = 0;
-  CheckRhs(1,3); 
+  CheckRhs(1,4); 
   CheckLhs(1,1);
   GetRhsVar(1,"c",&m1,&n1,&l1);/* file name */
   GetRhsVar(2,"d",&m2,&n2,&l2);/* data */
-  if ( Rhs == 3) 
+  if ( Rhs >= 3) 
     {
       GetRhsVar(3,"c",&m3,&n3,&l3);/* format */
       StringConvert(cstk(l3));  /* conversion */
@@ -562,12 +595,23 @@ int int_objfprintfMat(fname)
     {
       Format = "%f";
     }
+  if ( Rhs >= 4 )
+    {
+      GetRhsVar(4,"S",&mS,&nS,&Str2);
+    }
   if (( f = fopen(cstk(l1),"w")) == (FILE *)0) 
     {
       Scierror(999,"Error: in function %s, cannot open file %s\r\n",
 	       fname,cstk(l1));
       return 0;
     }
+
+  if ( Rhs >= 4 )
+    {
+      for ( i=0 ; i < mS*nS ; i++) 
+	fprintf(f,"%s\n",Str2[i]);
+    }
+
   for (i = 0 ; i < m2 ; i++ ) 
     {
       for ( j = 0 ; j < n2 ; j++) 
@@ -579,28 +623,44 @@ int int_objfprintfMat(fname)
     }
   fclose(f);
   LhsVar(1)=0 ; /** no return value **/
+  if ( Rhs >= 4) FreeRhsSVar(Str2);
   PutLhsVar();
   return 0;
 }  
 
 /*********************************************************************
  * Scilab fscanMat function
+ * fscanfMat('pipo')
+ * [A,b]=fscanfMat('pipo')
  *********************************************************************/
 #define INFOSIZE 1024
-static char Info[INFOSIZE];
 
-int int_objfscanfMat(fname)
-     char *fname;
+static int  Info_size = 0;
+static char *Info= NULL;
+static int ReadLine __PARAMS((FILE *fd,int *mem));
+
+
+int int_objfscanfMat(char *fname)
 {
+  char **Str;
+  int mem=0;
   double x;
   static int l1, m1, n1,l2,m2,n2;
   int i,j,rows,cols,lres,n;
   int vl=-1;
   FILE  *f;
   char *Format;
+  if ( Info == NULL ) {
+    if (( Info =malloc(INFOSIZE*sizeof(char)))==NULL) {
+      Scierror(999,"Error: in function %s, no more memory\r\n",fname);
+      return 0;
+    }
+    Info_size = INFOSIZE;
+  }
+
   Nbvars = 0;
-  CheckRhs(1,1); /** just 1 <<pour l''instant>> **/
-  CheckLhs(1,1);
+  CheckRhs(1,1); /** just 1 **/
+  CheckLhs(1,2);
   GetRhsVar(1,"c",&m1,&n1,&l1);/* file name */
   if ( Rhs == 2) 
     {
@@ -622,7 +682,11 @@ int int_objfscanfMat(fname)
   strcpy(Info,"--------");
   n =0; 
   while ( sscanf(Info,"%lf",&x) <= 0 && n != EOF ) 
-    { n=ReadLine(f); vl++;}
+    { 
+      n=ReadLine(f,&mem); 
+      if ( mem == 1) return 0;
+      vl++;
+    }
   if ( n == EOF )
     {
       Scierror(999,"Error: in function %s, cannot read data in file %s\r\n",
@@ -634,7 +698,8 @@ int int_objfscanfMat(fname)
   rows = 1;
   while (1) 
     { 
-      n=ReadLine(f);
+      n=ReadLine(f,&mem);
+      if ( mem == 1) return 0;
       if ( n == EOF ||  n == 0 ) break;
       if ( sscanf(Info,"%lf",&x) <= 0) break;
       rows++;
@@ -644,7 +709,41 @@ int int_objfscanfMat(fname)
   /** second pass to read data **/
   rewind(f);
   /** skip non numeric lines **/
-  for ( i = 0 ; i < vl ; i++) ReadLine(f);
+  if ( Lhs >= 2 && vl != 0 ) {
+    if ((Str = malloc((vl+1)*sizeof(char *)))==NULL) {
+      Scierror(999,"Error: in function %s, no more memory \r\n", fname);
+      return 0;
+    }
+    Str[vl]=NULL;
+  }
+
+  for ( i = 0 ; i < vl ; i++) 
+    {
+      ReadLine(f,&mem);
+      if ( mem == 1) return 0;
+      if ( Lhs >= 2) {
+	if ((Str[i]=malloc((strlen(Info)+1)*sizeof(char)))==NULL) { 
+	  int j;
+	  for ( j=0 ; j < i; j++) {FREE(Str[i]); FREE(Str);}
+	  Scierror(999,"Error: in function %s, no more memory \r\n", fname);
+	  return 0;
+	}
+	strcpy(Str[i],Info);
+      }
+    }
+
+  if ( Lhs >= 2) {
+    int un=1,zero=0,l;
+    if ( vl > 0 ) 
+      {
+	CreateVarFromPtr(Rhs+2,"S",&vl,&un,Str);
+	FreeRhsSVar(Str);
+      }
+    else 
+      {CreateVar(Rhs+2,"c",&zero,&zero,&l);}
+    LhsVar(2)=Rhs+2;
+  }
+
   for (i=0; i < rows ;i++)
     for (j=0;j < cols;j++)
       { 
@@ -655,33 +754,38 @@ int int_objfscanfMat(fname)
   fclose(f);
   LhsVar(1)=Rhs+1;
   PutLhsVar();
+  /* just in case Info is too Big */ 
+  if ( Info_size > INFOSIZE ) 
+    {
+      Info_size = INFOSIZE;
+      Info = realloc(Info,Info_size*sizeof(char));
+    }
   return 0;
 }  
 
-static int ReadLine_Old(fd)
-     FILE *fd;
-{
-  int n;
-  n= fscanf(fd,"%[^\n]%*c",Info);
-  if ( n==0) n=fscanf(fd,"%*c");
-  return(n);
-}
 
-static int ReadLine(fd)
-     FILE *fd;
+static int ReadLine(FILE *fd,int *mem)
 {
   int n=0;
   while (1)
     {
-      char c = getc(fd);
-      if ( n > INFOSIZE) 
+      char c = (char) getc(fd);
+      if ( n > Info_size ) 
 	{
+	  Info_size += INFOSIZE;
+	  if (( Info = realloc(Info,Info_size*sizeof(char)))==NULL) {
+	    Scierror(999,"Error: no more memory\r\n");
+	    *mem=1;
+	    return EOF;
+	  }
+	  /* 
 	  sciprint("Error Info buffer is too small (too many columns in your file ?)\r\n");
-	  return EOF ;/** A changer XXXX : pour retourner un autre message **/
+	  return EOF ;
+	  */
 	}
       Info[n]= c ; 
       if ( c == '\n') { Info[n] = '\0' ; return 1;}
-      else if ( c == EOF ) return EOF;  
+      else if ( c == (char)EOF ) return EOF;  
       n++;
     }
 }
@@ -692,7 +796,7 @@ static int ReadLine(fd)
  * Test de TestNumTokens 
  ***************************************/
 #ifdef TEST 
-static void TestNumTokens()
+static void TestNumTokens(void)
 {
   char buf[30], format[20];
   strcpy(format,"%d Tokens in <%s>\n");
@@ -707,8 +811,7 @@ static void TestNumTokens()
 }
 #endif 
 
-int NumTokens(string)
-     char string[];
+int NumTokens(char *string)
 {
   char buf[128];
   int n=1;
@@ -749,21 +852,12 @@ int NumTokens(string)
 typedef int (*PRINTER) __PARAMS((FILE *, char *,...));
 typedef int (*FLUSH) __PARAMS((FILE *));
 
-int voidflush(fp) 
-     FILE *fp ;
+int voidflush(FILE *fp)
 {
   return 0;
-};
+}
 
-static int do_scanf (fname,fp,format,nargs,strv,retval,buf,type)
-     char *fname;
-     FILE *fp;
-     char *format;
-     int  *nargs;
-     char *strv;
-     int *retval;
-     rec_entry buf[];
-     sfdir  type[];
+static int do_scanf (char *fname, FILE *fp, char *format, int *nargs, char *strv, int *retval, rec_entry *buf, sfdir *type)
 {
   int i;
   char sformat[MAX_STR];
@@ -1132,12 +1226,7 @@ static int do_scanf (fname,fp,format,nargs,strv,retval,buf,type)
 static char sprintf_buff[MAX_SPRINTF_SIZE];
 static char *sprintf_limit = sprintf_buff + MAX_SPRINTF_SIZE;
 
-static int do_printf (fname,fp,format,nargs,argcnt,lcount,strv)
-     char *fname;
-     FILE *fp;
-     char *format;
-     int nargs,argcnt,lcount;
-     char **strv;
+static int do_printf (char *fname, FILE *fp, char *format, int nargs, int argcnt, int lcount, char **strv)
 {
   int previous_t=0; 
   int m1;
@@ -1160,7 +1249,6 @@ static int do_printf (fname,fp,format,nargs,argcnt,lcount,strv)
   int retval;			/* Attempt to return C-printf() return-val */
   arg_cnt = argcnt;
   ccount = 1;
-
   q = format;
   retval = 0;
 
@@ -1448,7 +1536,6 @@ static int do_printf (fname,fp,format,nargs,argcnt,lcount,strv)
 
       save = *q;
       *q = 0;
-
       /* ready to call printf() */
       /* 
        * target:   The output file (or variable for sprintf())
@@ -1544,9 +1631,7 @@ static int do_printf (fname,fp,format,nargs,argcnt,lcount,strv)
  * Utility functions 
  ****************************************************/
 
-static int  GetString(fname,previous_t,arg,narg,ic,ir,sval) 
-     char *fname,**sval;
-     int *previous_t,*arg,narg,*ic,ir;
+static int  GetString(char *fname, int *previous_t, int *arg, int narg, int *ic, int ir, char **sval)
 {
   int mx,nx,il,ild,lw,k,one=1;
   char *p;
@@ -1577,8 +1662,7 @@ static int  GetString(fname,previous_t,arg,narg,ic,ir,sval)
 
 /** changes `\``n` --> `\n` idem for \t and \r  **/
 
-static int StringConvert(str)
-     char *str;
+static int StringConvert(char *str)
 {
   char *str1;
   int count=0;
@@ -1604,9 +1688,7 @@ static int StringConvert(str)
   *str1 = '\0';
   return count;
 }
-static int GetScalarInt(fname,previous_t,arg,narg,ic,ir,ival) 
-     char *fname;
-     int *previous_t,*arg,narg,*ic,ir,*ival;
+static int GetScalarInt(char *fname, int *previous_t, int *arg, int narg, int *ic, int ir, int *ival)
 {
   int mx,nx,lx;
 
@@ -1632,10 +1714,7 @@ static int GetScalarInt(fname,previous_t,arg,narg,ic,ir,ival)
   return OK;
 }
 
-static int GetScalarDouble(fname,previous_t,arg,narg,ic,ir,dval)
-     char *fname;
-     int *previous_t,*arg,narg,*ic,ir;
-     double *dval;
+static int GetScalarDouble(char *fname, int *previous_t, int *arg, int narg, int *ic, int ir, double *dval)
 {
   int mx,nx,lx;
 
@@ -1661,10 +1740,8 @@ static int GetScalarDouble(fname,previous_t,arg,narg,ic,ir,dval)
   return OK;
 }
 
-static int Sci_Store(nrow,ncol,data,type,retval_s)
-     int nrow,ncol,retval_s;
-     entry *data;
-     sfdir  *type;
+
+static int Sci_Store(int nrow, int ncol, entry *data, sfdir *type, int retval_s)
 {
   int cur_i,i,j,i1,one=1,zero=0,k,l,iarg,colcount;
   sfdir cur_type;
@@ -1675,11 +1752,11 @@ static int Sci_Store(nrow,ncol,data,type,retval_s)
     Scierror(998,"Error:\ttoo many directive in scanf\r\n");
     return RET_BUG;
   }
+  iarg=Rhs;
   if (Lhs > 1) {
-    CreateVar(1, "d", &one, &one, &l);
+    CreateVar(++iarg, "d", &one, &one, &l);
     *stk(l) = (double) retval_s;
-    iarg=2;
-    LhsVar(1)=1;
+    LhsVar(1)=iarg;
     if (ncol==0) goto Complete;
 
     for ( i=0 ; i < ncol ; i++) { 
@@ -1687,30 +1764,31 @@ static int Sci_Store(nrow,ncol,data,type,retval_s)
 	if( (temp = (char **) malloc(nrow*ncol*sizeof(char **)))==NULL) return MEM_LACK;
 	k=0;
 	for (j=0;j<nrow;j++) temp[k++]=data[i+ncol*j].s;
-	CreateVarFromPtr(iarg+i, "S", &nrow, &one, temp);
+	CreateVarFromPtr(++iarg, "S", &nrow, &one, temp);
 	free(temp);
 	for (j=0;j<nrow;j++) free(data[i+ncol*j].s);
       }
       else {
-	CreateVar(iarg+i, "d", &nrow, &one, &l);
+	CreateVar(++iarg, "d", &nrow, &one, &l);
 	for ( j=0 ; j < nrow ; j++) 
 	  *stk(l+j)= data[i+ncol*j].d;
       }
 
-      LhsVar(iarg+i)=iarg+i;
+      LhsVar(i+2)=iarg;
     }
     free(data);
     /** we must complete the returned arguments up to Lhs **/
   Complete:
     for ( i = ncol+2; i <= Lhs ; i++) 
       {
-	CreateVar(i,"d",&zero,&zero,&l);
-	LhsVar(i) = i;
+	iarg++;
+	CreateVar(iarg,"d",&zero,&zero,&l);
+	LhsVar(i) = iarg;
       }
   }
   else {/* Lhs==1 */
     char *ltype="cblock";
-    int multi=0,endblk,ii;
+    int multi=0,endblk,ii,n;
 
     cur_type=type[0];
     
@@ -1721,10 +1799,11 @@ static int Sci_Store(nrow,ncol,data,type,retval_s)
       }
     if (multi) {
       i=strlen(ltype);
-      CreateVarFromPtr(1, "c", &one, &i, &ltype);
-      iarg=1;
+      iarg=Rhs;
+      CreateVarFromPtr(++iarg, "c", &one, &i, &ltype); /* the mlist type field */
       cur_type=type[0];
       i=0;cur_i=i;
+
       while (1) {
 	if (i < ncol)  
 	  endblk=(type[i] != cur_type);
@@ -1760,25 +1839,28 @@ static int Sci_Store(nrow,ncol,data,type,retval_s)
 	}
 	i++;
       }
-      i = 1;
-      C2F(mkmlistfromvars)(&i,&iarg);
-      LhsVar(1)=1;
+      n=iarg-Rhs; /* number of list fields*/
+      
+      iarg++;
+      i=Rhs+1;
+      C2F(mkmlistfromvars)(&i,&n);
+      LhsVar(1)=i;
     }
     else {
       if (nrow==0) {
-	CreateVar(1, "d", &zero, &zero, &l);}
+	CreateVar(Rhs+1, "d", &zero, &zero, &l);}
       else if ( (cur_type == SF_C) || (cur_type == SF_S) ) {
 	if( (temp = (char **) malloc(nrow*ncol*sizeof(char **)))==NULL) return MEM_LACK;
 	k=0;
 	for (i1=0;i1<ncol;i1++)
 	  for (j=0;j<nrow;j++) temp[k++]=data[i1+ncol*j].s;
-	CreateVarFromPtr(1, "S", &nrow, &ncol, temp);
+	CreateVarFromPtr(Rhs+1, "S", &nrow, &ncol, temp);
 	free(temp);
 	for (i1=0;i1<ncol;i1++)
 	  for (j=0;j<nrow;j++) free(data[i1+ncol*j].s);
       }
       else {
-	CreateVar(1, "d", &nrow, &ncol, &l);
+	CreateVar(Rhs+1, "d", &nrow, &ncol, &l);
 	ii=0;
 	for (i1=0;i1<ncol;i1++) {
 	  for ( j=0 ; j < nrow ; j++) 
@@ -1787,7 +1869,7 @@ static int Sci_Store(nrow,ncol,data,type,retval_s)
 	}
       }
     }
-    LhsVar(1)=1;
+    LhsVar(1)=Rhs+1;
   }
   PutLhsVar();
   return 0;
@@ -1798,13 +1880,7 @@ static int Sci_Store(nrow,ncol,data,type,retval_s)
  *   table 
  ************************************************************************/
 
-static int Store_Scan(nrow,ncol,type_s,type,retval,retval_s,buf,data,rowcount,n)
-     int rowcount,n;
-     int *ncol, *nrow, *retval, *retval_s;
-     entry **data;
-     sfdir  *type_s,*type;
-     rec_entry *buf;
-     
+static int Store_Scan(int *nrow, int *ncol, sfdir *type_s, sfdir *type, int *retval, int *retval_s, rec_entry *buf, entry **data, int rowcount, int n)
 { 
   int i,j,nr,nc,err;
   entry * Data;
@@ -1899,10 +1975,7 @@ static int Store_Scan(nrow,ncol,type_s,type,retval,retval_s,buf,data,rowcount,n)
 
 
 
-static void Free_Scan(nrow,ncol,type_s,data)
-     int ncol, nrow;
-     entry **data;
-     sfdir  *type_s;
+static void Free_Scan(int nrow, int ncol, sfdir *type_s, entry **data)
 {
   int i,j;
   entry * Data;
@@ -1927,9 +2000,7 @@ static void Free_Scan(nrow,ncol,type_s,data)
  * '\n'   char
  ********************************************************/
 
-int SciStrtoStr(Scistring,nstring,ptrstrings,strh)
-     int *Scistring,*nstring,*ptrstrings;
-     char **strh;
+int SciStrtoStr(int *Scistring, int *nstring, int *ptrstrings, char **strh)
 {
   char *s,*p;
   int li,ni,*SciS,i,job=1;
