@@ -23,8 +23,8 @@ extern unsigned char ulaw_comp_table[16384];
 #define st_ulaw_to_linear(ulawbyte) ulaw_exp_table[ulawbyte]
 #define st_linear_to_ulaw(linearword) ulaw_comp_table[(linearword / 4) & 0x3fff]
 #else
-unsigned char st_linear_to_ulaw( /* int sample */ );
-int st_ulaw_to_linear( /* unsigned char ulawbyte */ );
+unsigned char st_linear_to_ulaw(  int sample  );
+int st_ulaw_to_linear(  unsigned char ulawbyte  );
 #endif
 
 #ifdef FAST_ALAW_CONVERSION
@@ -33,8 +33,8 @@ extern unsigned char Alaw_comp_table[16384];
 #define st_Alaw_to_linear(Alawbyte) Alaw_exp_table[Alawbyte]
 #define st_linear_to_Alaw(linearword) Alaw_comp_table[(linearword / 4) & 0x3fff]
 #else
-unsigned char st_linear_to_Alaw( /* int sample */ );
-int st_Alaw_to_linear( /* unsigned char ulawbyte */ );
+unsigned char st_linear_to_Alaw(  int sample  );
+int st_Alaw_to_linear(  unsigned char ulawbyte  );
 #endif
 
 #ifdef	USG
