@@ -31,9 +31,8 @@ ft_t ft;
 static void checkformat __PARAMS((ft_t ft));
 static void cleanup  __PARAMS((void));
 static void init  __PARAMS((void));
-#if defined(unix) || defined(AMIGA) || defined(ARM) || defined(aix)
 static int filetype __PARAMS((int fd));
-#endif
+
 
 
 /************************************************************
@@ -45,13 +44,9 @@ static int filetype __PARAMS((int fd));
  ************************************************************/
 
 
-int C2F(loadwave)(filename,res,size_res,flag,Wi,ierr)
-     char *filename;
-     double *res;
-     integer *ierr,*size_res,flag;
-     WavInfo *Wi;
+int C2F(loadwave)(char * filename,double *res, integer * size_res,
+		  integer flag,WavInfo *Wi, integer *ierr)
 {
-  double maxi,sum;
   long i,size_max;
 #if defined(__alpha)
   int buf[BUFSIZ];
@@ -97,11 +92,14 @@ int C2F(loadwave)(filename,res,size_res,flag,Wi,ierr)
       return 0;
     }
   if ( flag == 1) 
-    sciprint("Input file: using sample rate %lu\r\n\tsize %s, style %s, %d %s\r\n",
-	   informat.info.rate, sizes[informat.info.size], 
-	   styles[informat.info.style], informat.info.channels, 
-	   (informat.info.channels > 1) ? "channels" : "channel");
-  
+    {
+      sciprint("Input file: using sample rate %lu\r\n", 
+	       informat.info.rate);
+      sciprint("\tsize %s, style %s, %d %s\r\n",
+	       sizes[informat.info.size], 
+	       styles[informat.info.style], informat.info.channels, 
+	       (informat.info.channels > 1) ? "channels" : "channel");
+  }
   /* read chunk */
   size_max = *size_res ; 
   *size_res  = 0;
@@ -150,10 +148,8 @@ int C2F(loadwave)(filename,res,size_res,flag,Wi,ierr)
  * savewave 
  ************************************************************/
 
-int C2F(savewave)(filename,res,rate,size_res,ierr)
-     char *filename;
-     double *res;
-     integer *ierr,*size_res,*rate ;
+int C2F(savewave)(char * filename,double *res,integer * rate,
+		  integer *size_res,integer *ierr)
 {
   long buf[BUFSIZ];
   long i,size_max;
@@ -238,7 +234,7 @@ int C2F(savewave)(filename,res,rate,size_res,ierr)
 }
 
 
-void init() {
+void init(void) {
   /* init files */
   informat.info.rate      = 0;
   informat.info.size      = -1;
@@ -255,9 +251,10 @@ void init() {
  * Process input file -> effect table -> output file
  *	one buffer at a time
  */
-#if defined(netbsd) || defined(freebsd) || defined(unix) || defined(AMIGA) || defined(ARM) || defined(aix)
-int filetype(fd)
-     int fd;
+#if defined(DOS) || defined(__OS2__) || defined(WIN32) || defined (__MWERKS__)
+int filetype(int fd) { return 0;}
+#else 
+int filetype(int fd)
 {
   struct stat st;
   fstat(fd, &st);
@@ -267,7 +264,7 @@ int filetype(fd)
 
 /* called from util.c:fail */
 
-void cleanup() 
+void cleanup(void)
 {
   if (informat.fp)
     fclose(informat.fp);
@@ -275,8 +272,7 @@ void cleanup()
 
 /* check that all settings have been given */
 
-static void checkformat(ft) 
-     ft_t ft;
+static void checkformat(ft_t ft)
 {
   if (ft->info.rate == 0)
     {
