@@ -11,7 +11,7 @@
  * Lance Norskog And Sundry Contributors are not responsible for 
  * the consequences of using this software.
  */
-#if (defined(netbsd) || defined(freebsd)) && !defined(unix) 
+#if (defined(netbsd) || defined(freebsd) || defined(__APPLE__)) && !defined(unix) 
 #define unix
 #endif
 
@@ -148,7 +148,7 @@ void wshort(P2(ft_t ft, unsigned short us));
 unsigned long  rlong(P1(ft_t ft));		
 void  wlong(P2(ft_t ft, unsigned long ul));
 float          rfloat(P1(ft_t ft));
-void           wfloat(P2(ft_t ft, double f));
+void           wfloat(P2(ft_t ft, float f));
 double         rdouble(P1(ft_t ft));
 void           wdouble(P2(ft_t ft, double d));
 
@@ -215,6 +215,18 @@ IMPORT int soxpreview;	/* Preview mode: be fast and ugly */
 #define WRITEBINARY	"wb"
 #endif
 
+/* default values */ 
+#ifndef READBINARY 
+#define READBINARY "r"
+#endif
+
+#ifndef WRITEBINARY
+#define WRITEBINARY "w"
+#endif
+
+ 
+
+
 /* Error code reporting */
 #ifdef	QNX
 #include <errno.h>
@@ -236,7 +248,13 @@ char *version();			/* return version number */
 
 #include "../machine.h" 
 
+#if defined(__alpha)
+int wavread __PARAMS((ft_t ft, int *buf, long int len));
+#else
 int wavread __PARAMS((ft_t ft, long int *buf, long int len));
+#endif
+
+
 void  wavstartread __PARAMS((ft_t ft,WavInfo *,int flag));
 void wavwrite __PARAMS((ft_t ft, long int *buf, long int len));
 void wavstartwrite __PARAMS((ft_t ft));
