@@ -50,7 +50,7 @@
 static char copyright[] =
     "Sparse1.3: Copyright (c) 1985,86,87,88 by Kenneth S. Kundert";
 static char RCSid[] =
-    "@(#)$Header: spAllocate.c,v 1.2 88/06/18 11:12:22 kundert Exp $";
+    "@(#)$Header: /usr/local/cvsroot/scilab2.7/routines/sparse/spAllocate.c,v 1.1.1.1 2001/04/26 07:48:07 scilab Exp $";
 #endif
 
 
@@ -72,7 +72,9 @@ static char RCSid[] =
 #include "spmatrix.h"
 #include "spDefs.h"
 
-
+static InitializeElementBlocks();
+static RecordAllocation();
+static AllocateBlockOfAllocationList();
 
 
 
