@@ -38,7 +38,7 @@
 static char copyright[] =
     "Sparse1.3: Copyright (c) 1985,86,87,88 by Kenneth S. Kundert";
 static char RCSid[] =
-    "@(#)$Header: spSolve.c,v 1.2 88/06/18 11:15:54 kundert Exp $";
+    "@(#)$Header: /usr/local/cvsroot/scilab2.7/routines/sparse/spSolve.c,v 1.1.1.1 2001/04/26 07:48:07 scilab Exp $";
 #endif
 
 
@@ -60,8 +60,8 @@ static char RCSid[] =
 #include "spmatrix.h"
 #include "spDefs.h"
 
-
-
+static void SolveComplexMatrix();
+static void SolveComplexTransposedMatrix();
 
 
 /*
@@ -138,7 +138,6 @@ register  RealVector  Intermediate;
 register  RealNumber  Temp;
 register  int  I, *pExtOrder, Size;
 ElementPtr  pPivot;
-void SolveComplexMatrix();
 
 /* Begin `spSolve'. */
     ASSERT( IS_VALID(Matrix) AND IS_FACTORED(Matrix) );
@@ -473,7 +472,7 @@ register  RealVector  Intermediate;
 register  int  I, *pExtOrder, Size;
 ElementPtr  pPivot;
 RealNumber  Temp;
-void SolveComplexTransposedMatrix();
+
 
 /* Begin `spSolveTransposed'. */
     ASSERT( IS_VALID(Matrix) AND IS_FACTORED(Matrix) );
