@@ -103,9 +103,9 @@ c     this line is not modified
                if(l.le.ma) then
                   indr(l)=inda(l)
                   call icopy(indr(l),inda(ma+ja),1,indr(mr+jr),1)
-                  call dcopy(indr(l),ar(ja),1,rr(jr),1)
+                  call unsfdcopy(indr(l),ar(ja),1,rr(jr),1)
                   if(ita.ne.0) then
-                     call dcopy(indr(l),ai(ja),1,ri(jr),1)
+                     call unsfdcopy(indr(l),ai(ja),1,ri(jr),1)
                   else
                      call dset(indr(l),0.0d0,ri(jr),1)
                   endif
@@ -289,9 +289,9 @@ c     *     the a(l,:) is not modified
                   indr(l)=inda(l)
                   call icopy(indr(l),inda(ma+ja+ja1),1,indr(mr+jr)
      $                 ,1)
-                  call dcopy(indr(l),ar(ja+ja1),1,rr(jr),1)
+                  call unsfdcopy(indr(l),ar(ja+ja1),1,rr(jr),1)
                   if(ita.ne.0) then
-                     call dcopy(indr(l),ai(ja+ja1),1,ri(jr),1)
+                     call unsfdcopy(indr(l),ai(ja+ja1),1,ri(jr),1)
                   else
                      call dset(indr(l),0.0d0,ri(jr),1)
                   endif
