@@ -4,7 +4,7 @@
 #ifndef STACK_SCI 
 #define STACK_SCI 
 
-#if !(defined __ABSC__) && !(defined __MATH__)
+#if !(defined __ABSC__) && ( !(defined __MATH__)  || (defined __APPLE__))
 #include "graphics/Math.h"
 #else
 #include "machine.h"
@@ -14,6 +14,26 @@
 
 #include "stack-def.h"
 
+/*-------------------------------------------------
+ * types 
+ * -------------------------------------------------*/
+
+typedef enum {
+  sci_matrix= 1 ,
+  sci_poly= 2 ,
+  sci_boolean= 4 ,
+  sci_sparse= 5  ,
+  sci_boolean_sparse= 6,
+  sci_ints= 8,
+  sci_handles=9,
+  sci_strings= 10,
+  sci_u_function= 11,
+  sci_c_function= 13 ,
+  sci_lib=  14,
+  sci_list= 15,
+  sci_tlist= 16,
+  sci_mlist= 17
+} sci_types; 
 
 /*-------------------------------------------------
  * structure used for sparse matrix 
@@ -65,9 +85,10 @@ typedef struct sciintmat {
 #include "interf/stack2.h" 
 #include "interf/stack3.h" 
 
-/*********************************
- * to simplify interface design 
- *********************************/
+
+/*-------------------------------------------------
+ * set of defines for interface simplication 
+ * -------------------------------------------------*/
 
 static int c1_local;
 static int c_local;
@@ -89,13 +110,15 @@ static int c_local;
 #define Lhs C2F(com).lhs
 #define Bot C2F(vstk).bot
 #define Err C2F(iop).err
+#define Leps_sci  *stk(C2F(vstk).leps) 
 
 #define stk(x)  ( C2F(stack).Stk + x-1 )
 #define istk(x) (((int *) C2F(stack).Stk) + x-1 )
 #define sstk(x) (((float *) C2F(stack).Stk) + x-1 )
 #define cstk(x) (((char *) C2F(stack).Stk) + x-1 )
 typedef struct { double r, i; } doublecomplex;
-#define zstk(x) (doublecomplex *) (C2F(stack).Stk + x-1 )
+/* #define zstk(x) (doublecomplex *) (C2F(stack).Stk + x-1 )  */
+#define zstk(x) (((doublecomplex *) C2F(stack).Stk) + x-1 )
 
 #define lstk(x) (((integer *) C2F(vstk).Lstk) + x-1 )
 #define infstk(x) (((integer *) C2F(vstk).Infstk) + x-1 )
@@ -121,6 +144,11 @@ extern  void * GetFuncPtr __PARAMS((char *,int,void *,void (*f)(),int *,int*,int
 
 #define CreateCVarFromPtr(n,ct,it,mx,nx,lrx,lcx) if ( ! C2F(createcvarfromptr)((c_local=n,&c_local),ct,it,mx,nx,(double *)lrx,(double *) lcx,1L)) \
 					     { return 0;} 
+#define CreateRefFromName(n,nx) if(! C2F(createreffromname)(n,nx)){return 0;}
+
+#define CreateRef(num, point) if(! C2F(createreference)(num,point)){return 0;}
+
+#define ChangeToRef(num, point) C2F(changetoref)(num,point)
 
 #define FreePtr(lx) C2F(freeptr)((double **) lx)
 
@@ -138,6 +166,13 @@ extern  void * GetFuncPtr __PARAMS((char *,int,void *,void (*f)(),int *,int*,int
 #define CreateVar(n,ct,mx,nx,lx) if(! C2F(createvar)((c_local=n,&c_local),ct,mx,nx,(void *)lx, 1L))\
         { return 0;  }
 
+
+#define CreateWork(n,mx,lx) if(! C2F(creatework)((c_local=n,&c_local),mx,(void *)lx))\
+        { return 0;  }
+
+#define SetWorkSize(n,mx) if(! C2F(setworksize)((c_local=n,&c_local),mx))\
+        { return 0;  }
+
 #define CreateData(n,nx) if(! C2F(createdata)((c_local=n,&c_local),nx))\
         { return 0;  }
 
@@ -157,6 +192,8 @@ extern  void * GetFuncPtr __PARAMS((char *,int,void *,void (*f)(),int *,int*,int
 
 #define WriteMatrix(ct,mx,nx,w)  if (! C2F(cwritemat)(ct,mx,nx,w,strlen(ct) )) {	return 0; }
 
+#define PutVar(num, nam)  if (! C2F(putvar)( (c_local=num, &c_local), nam, strlen(nam) )) {	return 0; }
+
 #define ReadString(ct,mx,w)  if (! C2F(creadchain)(ct,mx,w,strlen(ct),strlen(w) )) {	return 0; }
 
 #define WriteString(ct,mx,w)  if (! C2F(cwritechain)(ct,mx,w,strlen(ct),strlen(w) )) {	return 0; }
@@ -305,6 +342,10 @@ extern void C2F(freeptr) __PARAMS((double *ip[]));
 
 extern void *GetData __PARAMS((int lw));
 
+extern void *GetRawData __PARAMS((int lw));
+
+extern void *GetDataFromName __PARAMS(( char *name));
+
 #endif /*  STACK_SCI  */
 
 
