@@ -42,14 +42,17 @@ c
       character cstk*(4*vsiz)
       equivalence (cstk,stk(1))
 
+      complex*16 zstk(vsiz/2)
+      equivalence (zstk(1),stk(1))
+
       integer bot,top,idstk(nsiz,isizt),lstk(isizt),leps,bbot,bot0,isiz
       integer gbot,gtop,infstk(isizt)
       common /vstk/ bot,top,idstk,lstk,leps,bbot,bot0,infstk,
      $     gbot,gtop,isiz
 
       integer ids(nsiz,psiz),pstk(psiz),rstk(psiz),pt,niv,macr,paus
-      integer icall
-      common /recu/ ids,pstk,rstk,pt,niv,macr,paus,icall
+      integer icall,krec
+      common /recu/ ids,pstk,rstk,pt,niv,macr,paus,icall,krec
 
       integer ddt,err,lct(8),lin(lsiz),lpt(6),hio,rio,wio,rte,wte
       common /iop/ ddt,err,lct,lin,lpt,hio,rio,wio,rte,wte
