@@ -3,6 +3,7 @@
 #include <math.h>
 
 #include "../machine.h"
+#include "Sun.h"
 
 #ifdef WIN32 
 #ifndef __CYGWIN32__
@@ -15,8 +16,7 @@
 /* testing Nan returns 1 if a Nan is found and 0 elsewhere */
 /* should be changed to use a libm isnan function when possible */
 
-integer C2F(isanan)(x)
-     double *x ;
+integer C2F(isanan)(double *x)
 {
 #ifdef _ISANAN
   return(_isnan(*x)== 1);
@@ -42,3 +42,7 @@ int main()
 			
 #endif 
 
+
+
+
+
