@@ -1,8 +1,7 @@
-/* Copyright INRIA/ENPC */
-/*********************************
+/*--------------------------------------------------------------
  * Link version for SYSV machine 
- *********************************/
-
+ * Copyright (C) Inria/Enpc 
+ *--------------------------------------------------------------*/
 
 #include <stdio.h>
 #include <ctype.h>
@@ -11,6 +10,7 @@
 #include <sys/stat.h>
 #include <sys/file.h>
 
+#include "../stack-def.h"
 
 #ifndef hppa
 #include <dlfcn.h>
@@ -33,12 +33,14 @@
 #endif
 #endif
 
+
 #if defined(linux) || defined(netbsd) || defined(freebsd)
 #include <unistd.h>
 #include <sys/wait.h>
 #endif 
 
-#if !defined(linux) && !defined(netbsd)  && !defined(freebsd)
+#if !defined(linux) && !defined(netbsd)  && !defined(freebsd) && !defined(__APPLE__)
+
 #ifndef hppa
 #if (defined(sun) && ! defined(SYSV)) 
 #else 
@@ -50,6 +52,7 @@
 #if !defined(linux) && !defined(netbsd) && !defined(freebsd)
 #ifdef __alpha
 #include <c_asm.h>
+#define RTLD_GLOBAL 0
 #endif
 #endif
 
@@ -64,11 +67,12 @@
 
 #include <string.h>
 
-
 #define round(x,s) (((x) + ((s)-1)) & ~((s)-1))
 #define Min(x,y)	(((x)<(y))?(x):(y))
 #define Max(x,y)	(((x)>(y))?(x):(y))
 
+#define debug C2F(iop).ddt==1
+
 /* extern char *strchr();  */
 extern int Use_cpp_code;
 extern char * Use_c_cpp;
@@ -76,14 +80,17 @@ extern char * Use_c_cpp;
 extern char * get_sci_tmp_dir();
 
 static void Sci_Delsym __PARAMS((int ));
-static int Sci_dlopen __PARAMS((char *loaded_files[]));
+static int Sci_dlopen __PARAMS((char *loaded_files[],int global));
 static int Sci_dlsym __PARAMS((char *ename,int  ishared,char * strf));
 static int SetArgv  __PARAMS((char *argv[], char *files[],int first,int max,int *err));
 static int SetArgv1  __PARAMS((char *argv[], char *files,int first,int max,int *err));
+static int CreateCppShared(char **loaded_files, char *tmp_file);
+static int CreateShared(char **loaded_files, char *tmp_file);
 
 int Call_shl_load = 0;
 
 
+
 /*************************************
  * New version : link entry names 
  *   from new shared lib created with 
@@ -94,17 +101,19 @@ int Call_shl_load = 0;
  *   -5 : pb with one of the entry point 
  *************************************/
 
-void SciLink(iflag,rhs,ilib,files,en_names,strf)
-     int iflag,*ilib,*rhs;
-     char *files[],*en_names[],*strf;
+void SciLink(int iflag, int *rhs, int *ilib, char **files, char **en_names, char *strf)
 {
   int i;
   if ( iflag == 0 )
     {
-      *ilib  = Sci_dlopen(files);
+      if ( * rhs == 1 ) 
+	/* if no entry names are given we try a dl_open with global option*/
+	*ilib  = Sci_dlopen(files,1);
+      else 
+	*ilib  = Sci_dlopen(files,0);
     }
-  if (*ilib  == -1 ) return;
-  sciprint("shared archive loaded\r\n");
+  if ( *ilib  == -1 ) return;
+  if ( iflag == 0) sciprint("shared archive loaded\r\n");
   if ( *rhs >= 2) 
     {
       i=0 ;
@@ -122,7 +131,7 @@ void SciLink(iflag,rhs,ilib,files,en_names,strf)
  * or 0 elsewhere 
  *************************************/
 
-int LinkStatus()
+int LinkStatus(void)
 {
   return(1);
 }
@@ -131,8 +140,7 @@ int LinkStatus()
  * Unlink a shared lib 
  *************************************/
 
-void C2F(isciulink)(i) 
-     integer *i;
+void C2F(isciulink)(integer *i)
 {
   /* delete entry points in shared lib *i */
   Sci_Delsym(*i);
@@ -197,10 +205,13 @@ void call_ctor_dtor(handle,loading)
 #define SHARED_SUF ".sl"
 #endif
 
+#ifndef RTLD_GLOBAL
+#define RTLD_GLOBAL 0
+#endif
 
 
-static int Sci_dlopen(loaded_files)
-     char *loaded_files[];
+
+static int Sci_dlopen(char **loaded_files,int global)
 {
   int i=0;
 #ifndef hppa
@@ -209,7 +220,7 @@ static int Sci_dlopen(loaded_files)
   shl_t hd1;
   void (*init_ctor)() = 0;
 #endif
-  char tmp_file[TMPL],*libs,*getenv();
+  char tmp_file[TMPL],*getenv(const char *);
   /** XXXXX **/
   if ( strncmp(loaded_files[0],"scilab",6) !=0)
     {
@@ -217,7 +228,7 @@ static int Sci_dlopen(loaded_files)
 	   && strstr(loaded_files[0],SHARED_SUF)!= NULL)
 	{
 	  strcpy(tmp_file,loaded_files[0]);
-	  sciprint("Loading shared executable %s\r\n",loaded_files[0]);
+	  if (debug) sciprint_nd("Loading shared executable %s\r\n",loaded_files[0]);
 	}
       else 
 	{
@@ -232,7 +243,13 @@ static int Sci_dlopen(loaded_files)
       /* this will load the shared library */
 #ifndef hppa
       Call_shl_load = 0;
-      hd1 = dlopen(tmp_file, RTLD_NOW);
+      if ( global == 1) 
+	{
+	  /* sciprint("Using global\r\n"); */ 
+	  hd1 = dlopen(tmp_file, RTLD_NOW | RTLD_GLOBAL );
+	}
+      else 
+	hd1 = dlopen(tmp_file, RTLD_NOW  );
 #else
       Call_shl_load = 1;
       hd1 = shl_load(tmp_file, BIND_IMMEDIATE | BIND_VERBOSE,0L);
@@ -289,9 +306,7 @@ static int Sci_dlopen(loaded_files)
 
 /** creates a shared executable from the set of files **/
   
-int CreateShared(loaded_files,tmp_file)
-  char *loaded_files[];
- char *tmp_file;
+static int CreateShared(char **loaded_files, char *tmp_file)
 {
   int argc=3,err=0;
   static int count=0;
@@ -299,14 +314,14 @@ int CreateShared(loaded_files,tmp_file)
   char *libs,*tmpdir;
   libs=getenv("SYSLIBS");
    /** XXXXX **/
-  sciprint("linking files ");
+  if (debug) sciprint_nd("linking files ");
   while ( loaded_files[i] != NULL) 
     {
-      sciprint("%s ",loaded_files[i]);
+      if (debug) sciprint_nd("%s ",loaded_files[i]);
       i++;
     }
 
-  sciprint(" to create a shared executable\r\n");
+  if (debug) sciprint_nd(" to create a shared executable\r\n");
   count++;
   /* be sure that tmpdir exists */
   tmpdir = get_sci_tmp_dir();
@@ -381,9 +396,7 @@ int CreateShared(loaded_files,tmp_file)
 
 /** creates a shared executable from the set of C++ files **/
 
-int CreateCppShared(loaded_files,tmp_file)
-  char *loaded_files[];
- char *tmp_file;
+static int CreateCppShared(char **loaded_files, char *tmp_file)
 {
   int argc=3,err=0;
   static int count=0;
@@ -391,17 +404,17 @@ int CreateCppShared(loaded_files,tmp_file)
   char *libs, *exec_cpp, *tmpdir;
   libs=getenv("SYSLIBS");
    /** XXXXX **/
-  sciprint("linking files ");
+  if (debug) sciprint_nd("linking files ");
   while ( loaded_files[i] != NULL) 
     {
-      sciprint("%s ",loaded_files[i]);
+      if (debug) sciprint_nd("%s ",loaded_files[i]);
       i++;
     }
 
-  sciprint(" to create a shared executable\r\n");
+  if (debug) sciprint_nd(" to create a shared executable\r\n");
   count++;
   tmpdir = get_sci_tmp_dir();
-  sprintf(tmp_file, "%s/SL_%d_XXXXXX",tmpdir,(int) getpid(),count);
+  sprintf(tmp_file, "%s/SL_%d_XXXXXX",tmpdir,(int) getpid()); /*,count);*/
   
   mktemp(tmp_file);
   {
@@ -459,10 +472,7 @@ int CreateCppShared(loaded_files,tmp_file)
  * return FAIL or OK 
  *************************************/
 
-static int Sci_dlsym(ename,ishared,strf)
-     int ishared;
-     char *ename;
-     char *strf;
+static int Sci_dlsym(char *ename, int ishared, char *strf)
 {
 #ifdef hppa
   shl_t hd1;
@@ -519,7 +529,7 @@ static int Sci_dlsym(ename,ishared,strf)
   else 
     {
       /* we don't add the _ in the table */
-      sciprint("Linking %s \r\n",ename);
+      if (debug) sciprint("Linking %s \r\n",ename);
       strncpy(EP[NEpoints].name,ename,MAXNAME);
       EP[NEpoints].Nshared = ish;
       NEpoints++;
@@ -534,8 +544,7 @@ static int Sci_dlsym(ename,ishared,strf)
  ****************************************************/
 
 
-static void Sci_Delsym( ishared) 
-     int ishared;
+static void Sci_Delsym(int ishared)
 {
   int ish = Min(Max(0,ishared),ENTRYMAX-1);
   int i=0;
@@ -583,10 +592,7 @@ static void Sci_Delsym( ishared)
  * first 
  *******************************************************/
 
-static int SetArgv(argv,files,first,max,err)
-     char *argv[];
-     char *files[];
-     int first,max,*err;
+static int SetArgv(char **argv, char **files, int first, int max, int *err)
 {
   int i=0,j=first;
   *err=0;
@@ -599,10 +605,7 @@ static int SetArgv(argv,files,first,max,err)
   return(j);
 }
 
-static int SetArgv1(argv,files,first,max,err)
-     char *argv[];
-     char *files;
-     int first,max,*err;
+static int SetArgv1(char **argv, char *files, int first, int max, int *err)
 {
   int j=first;
   char *loc = files;
