@@ -3,7 +3,7 @@
 #include "../machine.h"
 #include <stdio.h>
 
-#ifdef __STDC__
+#if defined(__STDC__) || defined(__MSC__) || defined(__CYGWIN__) ||  (defined __ABSC__)
 #include <stdlib.h>
 #ifndef WIN32
 #include <sys/types.h>
@@ -13,22 +13,15 @@
 extern  char  *getenv();
 #endif
 
-#if (defined __MSC__) || (defined __ABSC__)
-#include <stdlib.h> 
-#ifdef __MINGW32__
-/** XXXXX missing in mingw32 **/
-#define putenv(x) 
-#else 
+#if (defined __MSC__) || (defined __ABSC__) || defined(__MINGW32__) 
 #ifdef __ABSC__
 #define putenv(x) abs_putenv(x)
 #define getpid() getpid_()
 #else
 #define putenv(x) _putenv(x)
 #endif
-#endif 
 #endif
 
-
 extern void C2F(setprlev) __PARAMS((int*));
 
 static char tmp_dir[256],buf[256];
@@ -39,7 +32,7 @@ static char tmp_dir[256],buf[256];
  * and fixes the TMPDIR env variable
  ****************************/
 
-void C2F(settmpdir)()
+void C2F(settmpdir)(void)
 {
   static int first =0;
   if ( first == 0 ) 
@@ -66,7 +59,7 @@ void C2F(settmpdir)()
  * get a reference to tmp_dir 
  ****************************/
 
-char *get_sci_tmp_dir() 
+char *get_sci_tmp_dir(void)
 {
   /* just in case */
   C2F(settmpdir)();
@@ -81,7 +74,7 @@ char *get_sci_tmp_dir()
   extern void hppa_sci_unlink_shared();
 #endif
 
-void C2F(tmpdirc)()
+void C2F(tmpdirc)(void)
 {
   char *tmp_dir = get_sci_tmp_dir(); 
 #ifdef WIN32 
