@@ -36,8 +36,11 @@ c
             pt=pt-1
          elseif (r.eq.402) then 
             pt=pt-1
-         elseif (r.eq.403.or.r.eq.404.or.r.eq.406.or.r.eq.407) then
+C         elseif (r.eq.403.or.r.eq.404.or.r.eq.406.or.r.eq.407) then
+         elseif (r.ge.403.and.r.le.407) then
             goto 50
+         elseif (r.eq.408) then
+            goto 60
          endif
          return
       endif
@@ -61,16 +64,16 @@ c     .     a() -->a
          endif
          nt=1
       else
+         call ref2val
          nt=rhs
       endif
       do 03 i=1,nt
          vt1=abs(ogettype(top+1-i))
-c         if(vt1.eq.129.and.fin.eq.extrac) vt1=2
          if(vt1.gt.vt) vt=vt1
  03   continue
 
 c
-      goto (10,20,05,30,70,35,04,75,04,40,60,04,60,60,50,50,50) ,vt
+      goto (10,20,05,30,70,35,04,75,76,40,60,04,60,60,50,50,50) ,vt
 c     overloadable ops
       if(vt.eq.129.and.fin.eq.3) goto 20
  04   op=fin
@@ -98,10 +101,12 @@ c     overloadable ops
       goto 80
  75   call intops
       goto 80
+ 76   call hndlops
+      goto 80
 
 c
  80   if(err.gt.0) return
- 81   call iset(lhs,0,infstk(max(top-lhs+1,1)),1)
+ 81   call iset(rhs,0,infstk(max(top-lhs+1,1)),1)
 c
       if(fun.ne.0) then 
 c     .  appel d'un matfn necessaire pour achever l'evaluation
@@ -112,13 +117,16 @@ c     .  *call* matfns
          return
       endif
 c
-      if(fin.le.0) then
+      if(icall.eq.5) return
+
+      if(fin.lt.0) then
          op=-fin
          fin=-fin
          goto 90
       endif
 
-      if(rstk(pt).eq.406.or.rstk(pt).eq.405) then
+c      if(rstk(pt).eq.406.or.rstk(pt).eq.405) then
+      if(rstk(pt).eq.406) then
 c     .  list recursive extraction insertion 
          goto 50
       endif
