@@ -66,22 +66,26 @@ c
       pt0=0
       if(pt.le.pt0) goto 50
       if(erecmode) then
-
 c     error recovery mode
          p=pt+1
-c        . looking if error has occured in execstr deff getf or comp
+c        . looking if error has occurred in execstr deff getf or comp
  20      p=p-1
          if(p.le.errpt) then
             pt0=pt
             goto 50
          endif
-         if(rstk(p).eq.502) then 
+         if(rstk(p).eq.1001) then
+c     .     error has occurred in an external
+            errtyp=0
+            pt0=p
+         elseif(rstk(p).eq.502) then 
             if(rstk(p-1).eq.903) then
-c     .     error has occured in execstr
+c     .     error has occurred in execstr
+
                errtyp=0
                pt0=p
             elseif(rstk(p-1).eq.904.or.rstk(p-1).eq.901) then
-c     .     error has occured in comp
+c     .     error has occurred in comp
                errtyp=0
                pt0=p
             else
@@ -189,7 +193,8 @@ c
      +     240,241,242,243,244,245,246,247,248,249,
      +     250,251,252,253,254,255,256,257,258,259,
      +     260,261,262,263,264,265,266,267,268,269,
-     +     270),n-199
+     +     270,271,272,273,274,275,276,277,278,279,
+     +     280),n-199
       if(n.ge.10000) return
       goto 998
 c
@@ -244,7 +249,7 @@ c
    18 call msgout(io,lunit,'too many variables!')
       go to 999
    19 call msgout(io,lunit,
-     &           'singular matrix')
+     &           'Problem is singular')
       go to 999
    20 if(err.ne.1) then
          write(buf(1:3),'(i3)') err
@@ -803,6 +808,8 @@ c
       goto 999
  200  continue
       goto 999
+c     messages from 201 to 203 and 205 to 214 are no more used by error 
+c     (see Scierror  in stack1.c)
  201  continue
       write(buf(1:3),'(i3)') err
       call cvname(ids(1,pt+1),buf(4:4+nlgh),1)
@@ -830,15 +837,14 @@ c
      +        ' : wrong type argument,')
       call msgout(io,lunit,' expecting a real vector')
       goto 999
+
  204  continue
       write(buf(1:3),'(i3)') err
-      call cvname(ids(1,pt+1),buf(4:4+nlgh),1)
-      nl=lnblnk(buf(4:3+nlgh))
       call msgout(io,lunit,
-     +     'Argument '//buf(1:3)//' of '//buf(4:3+nl)//
-     +        ' : wrong type argument,')
-      call msgout(io,lunit,' expecting a scalar')
+     +     'Argument '//buf(1:3)//', wrong type argument:'//
+     +     ' expecting a scalar')
       goto 999
+
  205  continue
       write(buf(1:3),'(i3)') err
       call cvname(ids(1,pt+1),buf(4:4+nlgh),1)
@@ -1077,9 +1083,10 @@ C     errors from semidef
       goto 999
  246  continue
       call cvname(ids(1,pt+1),buf,1)
-      call msgout(io,lunit,'impossible to overload this function for'//
+      call msgout(io,lunit,'function not defined for'//
      &     ' given argument type(s)')
-      call msgout(io,lunit,'       undefined function '//buf(1:nlgh))
+      call msgout(io,lunit,'Check arguments or define function '
+     &     //buf(1:nlgh)//' for overloading')
       goto 999
  247  continue
       goto 999
@@ -1151,23 +1158,87 @@ C     errors from semidef
       goto 999
  263  continue
       call msgout(io,lunit,'Error while writing in file,'//
-     &     '(disk full or delete file)')
+     &     '(disk full or deleted file)')
       goto 999
  264  continue
+      if(err.ne.1) then
+         write(buf(1:3),'(i3)') err
+         call msgout(io,lunit,buf(1:3)//
+     +        'th argument must not contain NaN or Inf')
+      else
+         call msgout(io,lunit,
+     +        'argument must not  contain NaN or Inf')
+      endif
       goto 999
  265  continue
+          call msgout(io,lunit,
+     +        'A and B must have equal number of rows')
       goto 999
  266  continue
+          call msgout(io,lunit,
+     +        'A and B must have equal number of columns')
       goto 999
  267  continue
+          call msgout(io,lunit,
+     +        'A and B must have equal dimensions')
       goto 999
  268  continue
+      write(buf(1:3),'(i3)') err
+      call msgout(io,lunit,
+     +     'invalid return value for function passed in argument '//
+     +     buf(1:3))
       goto 999
  269  continue
+      if(err.ne.1) then
+         write(buf(1:3),'(i3)') err
+         call msgout(io,lunit,buf(1:3)//
+     +        'th argument eigenvalues must have negative real parts')
+      else
+         call msgout(io,lunit,
+     +        'argument eigenvalues must have negative real parts')
+      endif
       goto 999
  270  continue
+      if(err.ne.1) then
+         write(buf(1:3),'(i3)') err
+         call msgout(io,lunit,buf(1:3)//
+     +        'th argument eigenvalues modulus must be less than one')
+      else
+         call msgout(io,lunit,
+     +        'argument eigenvalues modulus must be less than one')
+      endif
+      goto 999
+
+ 271  continue
+      if(err.ne.1) then
+         write(buf(1:3),'(i3)') err
+         call msgout(io,lunit,buf(1:3)//
+     +        'Size varying argument a*eye(), (arg '//buf(1:3)//
+     +        ') not allowed here')
+      else
+         call msgout(io,lunit,'Size varying argument a*eye()'//
+     +        ' not allowed here')
+      endif
+      goto 999
+ 272  continue
+      goto 999
+ 273  continue
+      goto 999
+ 274  continue
+      goto 999
+ 275  continue
+      goto 999
+ 276  continue
+      goto 999
+
+ 277  continue
+      goto 999
+ 278  continue
+      goto 999
+ 279  continue
+      goto 999
+ 280  continue
       goto 999
-c
 c
 c---------------------------------------------------------------------
  998  continue
@@ -1237,6 +1308,7 @@ c
                m=11
                first=.false.
                nlc=0
+               call linestore(lct(8))
             else
                buf='line '
                m=6
@@ -1246,7 +1318,10 @@ c
             m=m+4
             buf(m+1:m+18)=' of function     '
             m=m+13
-            if (km.le.isiz) call cvname(idstk(1,km),buf(m+1:m+nlgh),1)
+            if (km.le.isiz) then
+               call cvname(idstk(1,km),buf(m+1:m+nlgh),1)
+               call funnamestore(buf(m+1:m+nlgh),nlgh) 
+            endif
             m=m+nlgh
          else
             buf='in  execstr instruction'
@@ -1365,6 +1440,7 @@ c
          call basout(io,lunit,line(1:max(m,1)))
       endif
  1000 line=' '
+      if(m1+15.gt.ll) m1=ll-16
       line(m1+1:m1+9)=mg
       write(line(m1+11:m1+15),'(i5)') n
       line(m1+16:m1+16)=bel
