@@ -16,6 +16,12 @@ c     Copyright INRIA
 c     
 c      integer         nunit,unit(50)
 c      common /units / nunit,unit
+c
+c     common for scicos debug mode
+
+      common /cosdebug/ cosd
+      integer cosd
+
 c     common for Control-C interruptions
       logical         iflag
       common /basbrk/ iflag
@@ -38,10 +44,12 @@ c     ippty: interfaces properties
       integer i,k,l,nc,mode(2),vsizg
       integer eps(nsiz),im(nsiz),exp(nsiz),pi(nsiz),bl(nsiz),io(nsiz)
       integer true(nsiz),false(nsiz),dollar(nsiz)
+      integer idloc(nsiz)
       integer offset,goffset
       integer iadr,sadr
 c     
       double precision  iov(2)
+      character*(nlgh) vname 
 c     character set
 c     0       10       20       30       40       50
 c     
@@ -183,6 +191,10 @@ c
 c     .  initial debug mode
 c     .  ------------------
       ddt = 0
+
+c
+c     .  scicos initial debug mode
+      cosd = 0
 c     
 c     .  character set
 c     .  -------------
@@ -224,14 +236,50 @@ c     . hard predefined variables
       lstk(gtop+1)=goffset+1
       gbot=isizt
       lstk(gbot)=lstk(gtop+1)+vsizg-1
-
-
-      bot=isiz-8
+c
+c     12 is the number of predefined variables 
+      bot=isiz-12
       bbot=bot
       bot0=bot
-      l=vsizr-(8*sadr(5)+2)-2*sadr(4)-sadr(10)-2
+c     memory requested for predefined variables 
+c     mxn bmat -> size : sadr(2+m*n+2)
+c     $        -> size : sadr(10-1) + 2 
+c     mxn mat  -> size : sadr(3)+m*n*(it+1)
+c     string   -> size : sadr(6+nchar)+1
+      call getcomp(buf,nbuf)
+      lpvar = (sadr(10-1) + 2) 
+     $     + 5*sadr(5) 
+     $     + 4*(sadr(3)+1)
+     $     + 2*(sadr(3)+2)
+     $     + 1*(sadr(6+nbuf)+1)
+      l=vsizr-lpvar
       k=bot
       lstk(k)=lstk(1)-1+l
+c     . COMPILER
+      vname = ' '
+      vname(1:8) = "COMPILER"
+      call cvname(idloc,vname,0)
+      call cresmatvar(idloc,k,buf,nbuf)
+      k=k+1
+c     . %gtk 
+      vname = ' '
+      vname(1:4) = "%gtk"
+      call withgtk(irep)
+      call cvname(idloc,vname,0)
+      call crebmatvar(idloc,k,1,1,irep)
+      k=k+1
+c     . %pvm
+      vname(1:4) = "%pvm"
+      call withpvm(irep)
+      call cvname(idloc,vname,0)
+      call crebmatvar(idloc,k,1,1,irep)
+      k=k+1
+c     . %tk 
+      vname(1:4) = "%tk "
+      call withtk(irep)
+      call cvname(idloc,vname,0)
+      call crebmatvar(idloc,k,1,1,irep)
+      k=k+1
 c     .  $    : formal index
       call putid(idstk(1,k),dollar)
       il=iadr(lstk(k))
@@ -260,6 +308,10 @@ c     .  %eps : machine precision
       call crematvar(eps,k,0,1,1,dlamch('p'),0.0d0)
       leps=sadr( iadr(lstk(k)) +4)
       k=k+1
+c     . %test 
+c      call cvname(idloc,"%test",0)
+c      call crematvar(idloc,k,0,1,1,dlamch('p'),0.0d0)
+c      k=k+1
 c     .  %io : standard input&output
       iov(1)=dble(rte)
       iov(2)=dble(wte)
@@ -358,4 +410,35 @@ c
       call icopy(m*n,val,1,istk(lr),1)
       end
 
+
+      subroutine cresmatvar(id,lw,str,lstr)
+C     crebmat without check and call to putid 
+C     implicit undefined (a-z)
+      integer iadr,sadr,lw,m,n,il,id(*),lr,nchar
+      integer mn
+      include '../stack.h'
+      character str*(*)
 c     
+      iadr(l)=l+l-1
+      sadr(l)=(l/2)+1
+c     
+      call putid(idstk(1,lw),id)
+      il = iadr(lstk(lw))
+      mn = 1 
+      ix1 = il + 4 + (lstr + 1) + (mn + 1)
+      istk(il ) = 10
+      istk(il +1) = 1
+      istk(il +2) = 1
+      istk(il +3) = 0
+      ilp = il + 4
+      istk(ilp) = 1
+      istk(ilp+1) = istk(ilp) + lstr
+      ilast = ilp + mn
+      lr1 = ilast + istk(ilp )
+      call cvstr(lstr,istk(lr1),str,0)
+      ix1 = ilast + istk(ilast )
+      lstk(lw +1) = sadr(ix1)
+      return 
+      end 
+
+
