@@ -39,12 +39,13 @@ c
       if(istk(ilk).eq.10) then
 c     an execstr
          exec=.false.
+         vargout=.false.
          mrhs=0
          rhs=0
          mlhs=0
          l=ilk+5+istk(ilk+1)*istk(ilk+2)
          lf=l+istk(ilk+4+istk(ilk+1)*istk(ilk+2))-1
-         last=isiz-4
+         last=bbot
          if(macr.ne.0.or.paus.ne.0) then
             k=lpt(1)-(13+nsiz)
             last=lin(k+5)
@@ -54,8 +55,15 @@ c     a macro
          exec=rstk(pt).eq.909.or.rstk(pt).eq.903
          wmac=0
          if(nmacs.gt.0) then
+            if(rstk(pt).eq.602) then
+c     .        see run to explain the following
+               lcn=pstk(pt)-4-(nsiz+3)+1
+               call putid(id,istk(lcn))
+            else
+               call putid(id,ids(1,pt))
+            endif
             do 15 im=1,nmacs
-               if(eqid(ids(1,pt),macnms(1,im))) then
+               if(eqid(id,macnms(1,im))) then
                   wmac=im
                   goto 16
                endif
@@ -196,6 +204,7 @@ c     and not 0
          endif
       endif
 c     
+      ids(6,pt)=toperr
       toperr=top
       if(istk(ilk).eq.13) then
          lct(8)=1
@@ -217,13 +226,14 @@ c
 c     fin de l'execution d'une macro
 c-----------------------------------
 c     handle errcatch
-      if(errct.ne.0.and.errpt.ge.pt.and.rstk(pt-1).ne.903) then
+      exec=rstk(pt-1).eq.909.or.rstk(pt-1).eq.903
+      if(errct.ne.0.and.errpt.ge.pt.and..not.exec) then
          errct=0
          errpt=0
          err1=0
          err2=0
       endif
-      exec=rstk(pt-1).eq.909.or.rstk(pt-1).eq.903
+
 c     restaure  pointers
       k = lpt(1) - (13+nsiz)
       ilk=lin(k+6)
@@ -237,6 +247,8 @@ c
       lhs=ids(2,pt)
       lct(4)=pstk(pt)
       vargout=ids(4,pt).eq.1
+      toperr=ids(6,pt)
+
 c     
       if(comp(1).ne.0) then
          comp(2)=comp(1)
@@ -371,7 +383,7 @@ c     exec
       lin(k+2) = lpt(2)
       lin(k+3) = lpt(3)
       lin(k+4) = lpt(4)
-      lin(k+5) = isiz-4
+      lin(k+5) = bot0
 c     two following lines set information necessary for  stackp to know 
 c     current macro context
       if(macr.ge.1) lin(k+5)=lin(lpt(1)-(8+nsiz))
