@@ -22,6 +22,8 @@ c
      &     181,182,183,184,185,186,187,188,189,190,
      &     191,192,193,194,195,196,197,198,199,200,
      &     201,202,203,204,205,206,207,208,209,210) n
+      call basout(io,wte,' Warning:')
+      call basout(io,wte,buf(1:lnblnk(buf)))
  101  continue
       call  basout(io,wte,' Warning:')
       call basout(io,wte,'  Non convergence in the QZ algorithm.')
@@ -58,9 +60,10 @@ c---------------------- message de matlu et matnew---------------------
  105  continue
       call basout(io,wte,' warning')
       call basout(io,wte,
-     +     ' matrix is close to singular or badly scaled.')
+     $     ' matrix is close to singular or badly scaled. rcond = '//
+     $     buf(1:13))
       call basout(io,wte,
-     +              ' results may be inaccurate. rcond ='//buf(1:13))
+     +              'computing least squares solution. (see lsq)')
       goto 9999
  106  continue
       call basout(io,wte,'  Warning.')
@@ -68,8 +71,6 @@ c---------------------- message de matlu et matnew---------------------
       call basout(io,wte,
      +     ' results may be inaccurate. rcond ='//buf(1:13))
       goto 9999
-c----------------------------------------------------------------------
-c---------------------- message d'obsolescence -----------------------------
  107  continue
       call basout(io,wte,' Warning: obsolete use of = instead of ==')
       call showstack()
@@ -79,6 +80,8 @@ c---------------------- message d'obsolescence -----------------------------
       call showstack()
       goto 9999
  109  continue
+      write(buf(1:5),'(1pI5)') ierr
+      call basout(io, wte, 'rank defficient. rank = '//buf(1:5))
       goto 9999
  110  continue
       goto 9999
@@ -411,12 +414,29 @@ c
       call basout(io,wte,'Undefined display for this data type')
       goto 9999
  201  continue
+      
+      call cvname(ids(1,pt+1),line(1:nlgh),1)
+      nl=lnblnk(line(1:nlgh))
+      call basout(io,wte,' Warning: primitive function '//line(1:nl)//
+     &    ' has moved')
+      call basout(io,wte,' rebuild  your function libraries')
+c      call showstack()
       goto 9999
  202  continue
+      call cvname(ids(1,pt+1),line(1:nlgh),1)
+      nl=lnblnk(line(1:nlgh))
+      call basout(io,wte,' Warning: primitive function '//line(1:nl)//
+     &    ' is now a Scilab function') 
+      call basout(io,wte,' rebuild  your function libraries')
+c      call showstack()
       goto 9999
  203  continue
+      call basout(io,wte,' roundoff errors make leading eigenvalues ')
+      call basout(io,wte,
+     &     ' in the Schur form no longer satisfy criterion')
       goto 9999
  204  continue
+      call basout(io,wte,' Formal variable name has been truncated')
       goto 9999
  205  continue
       goto 9999
