@@ -6,18 +6,19 @@ c     ==============================================================
 c     Copyright INRIA
       include '../stack.h'
 c
-      double precision dlamch
+      double precision dlamch,x
       integer id(nsiz),j,vt,semi
 c
-      integer ogettype,lr,lc,lr1,lc1
+      integer ogettype,lr,lc,lr1,lc1,v
       character*4 name
+      logical eqid
       logical getmat,cremat,smatj,lmatj,getsmat,getilist,getpoly,pmatj
 c
-c
-      integer iadr
+      integer iadr,sadr
       data semi/43/
 c
       iadr(l)=l+l-1
+      sadr(l)=(l/2)+1
 c
       if (ddt .eq. 4) then
          write(buf(1:4),'(i4)') j
@@ -36,20 +37,47 @@ c
       return
 c---  matrices scalaires 
  10   if (.not.getmat("nextj",top-1,top-1,it,m,n,lr,lc)) return
+
       if (m.eq.-3) then
 C        boucle implicite 
-         if (.not.cremat("nextj",top,0,1,1,lr1,lc1)) return
-         stk(lr1) = stk(lr) + (j - 1)*stk(lr + 1)
-         if( stk(lr+1) * (stk(lr1) - stk(lr+2)) .gt. 0) then
-            if(abs(stk(lr1)-stk(lr+2)).gt.
-     $           abs(stk(lr+1)*dlamch('p'))) goto 50
+         x = stk(lr) + (j - 1)*stk(lr + 1)
+         if( stk(lr+1) * (x - stk(lr+2)) .gt. 0.0d0) then
+            if(abs(x-stk(lr+2)).ge.
+     $           2.0d0*max(abs(stk(lr+1)),abs(stk(lr+2)))*dlamch('p'))
+     $           goto 50
          endif
+         if (j.gt.1) then
+c     .     check if loop variable has moved since previous j
+            k=idstk(1,top-1)
+            if(k.ge.bot.and.eqid(id,idstk(1,k))) then
+c     .        No, loop variable is updated in place
+               lr1=sadr(iadr(lstk(k))+4)
+               stk(lr1)=x
+               top=top-1
+               return
+            endif
+         endif
+         if (.not.cremat("nextj",top,0,1,1,lr1,lc1)) return
+         stk(lr1)=x
       else
          if (j .gt. n .or. m.eq.0) go to 50
+         if (j.gt.1) then
+            k=idstk(1,top-1)
+            if(k.ge.bot.and.eqid(id,idstk(1,k))) then
+c     .        loop variable is updated in place
+               lr1=sadr(iadr(lstk(k))+4)
+               call unsfdcopy(m,stk(lr+(j-1)*m),1,stk(lr1),1)
+               if(it.eq.1) call unsfdcopy(m,stk(lc+(j-1)*m),1,
+     $              stk(lr1+m),1)
+               top=top-1
+               return
+            endif
+         endif
          if (.not.cremat("nextj",top,it,m,1,lr1,lc1)) return
-         call dcopy(m,stk(lr+(j-1)*m),1,stk(lr1),1)
-         if(it.eq.1) call dcopy(m,stk(lc+(j-1)*m),1,stk(lc1),1)
+         call unsfdcopy(m,stk(lr+(j-1)*m),1,stk(lr1),1)
+         if(it.eq.1) call unsfdcopy(m,stk(lc+(j-1)*m),1,stk(lc1),1)
       endif
+
       goto 21
 c--   matrices de polynomes
  20   if (.not.getpoly("nextj",top-1,top-1,it,m,n,name,namel,ilp,lr,lc))
@@ -69,7 +97,20 @@ c---- listes
       goto 21
  21   rhs = 0
       sym=semi
+      if (j.gt.1) then
+         k=idstk(1,top-1)
+         v=lstk(top+1)-lstk(top)
+         if(k.ge.bot.and.eqid(id,idstk(1,k))
+     $        .and.v.eq.lstk(k+1)-lstk(k)) then
+            call unsfdcopy(v,stk(lstk(top)),-1,stk(lstk(k)),-1)
+            top=top-1
+            return
+         endif
+      endif
       call stackp(id,0)
+c     save location where loop variable has been saved in the expression
+c     identifier 
+      idstk(1,top) = fin
       return
  50   top=top-1
       il = iadr(lstk(top))
