@@ -9,7 +9,7 @@ c
       sadr(l)=(l/2)+1
 c
 
-      if(rhs.le.0) return
+      if(rhs.le.0.or.top.lt.rhs) return
 
       vol=0
       ref=.false.
@@ -41,7 +41,7 @@ c
          lstk(topk+1)=le
          lk=lstk(k)
          le=le-vol
-         if(lk.ne.le) call dcopy(vol,stk(lk),-1,stk(le),-1)
+         if(lk.ne.le) call unsfdcopy(vol,stk(lk),-1,stk(le),-1)
          topk=topk-1
  20   continue
       return
