@@ -58,8 +58,9 @@ c
          goto 91
       endif
       if(err1.ne.0) then
-c     .  errcatch in exec(function,'errrcatch')
-         if(rstk(pt-1).eq.909) return
+c     .  errcatch in exec(function,'errrcatch') or catched error in an
+C     external
+         if(rstk(pt-1).eq.909.or.rstk(pt).eq.1001) return
       endif
       if(lc-l0.ne.nc) goto 11
       r=rstk(pt)-610
@@ -70,7 +71,7 @@ c     nouvelle 'operation'
       op=istk(lc)
       goto(20, 25, 40, 42, 30, 41, 45, 49, 49, 55,
      &     15, 90, 95, 100,105,110,120,130,140,150,
-     &     160,170,180,190,200,210) ,op
+     &     160,170,180,190,200,210,220) ,op
 c     matfns
       if(op.ge.100) goto 80
 c     return
@@ -152,17 +153,20 @@ c     allops
       rhs=istk(lc+2)
       lhs=istk(lc+3)
       lc=lc+4
-      
+      if(fin.eq.extrac) then
+         call isafunptr(top,id,ifun,ifin)
+         if(ifun.ne.0) then
+            top=top-1
+            rhs=rhs-1
+            fun=ifun
+            fin=ifin
+            goto 81
+         endif
+      endif
       if(fin.eq.extrac.or.fin.eq.insert) call adjustrhs
       pt=pt+1
       rstk(pt)=601
       ids(1,pt)=tref
-c     following lines have been suppressed accordint to a modifiction in
-c     intl_i  22/08/00
-c      if(istk(lc).eq.1) then 
-c     .  if next op is stackp put name in ids for insertion
-c         call putid(ids(1,pt),istk(lc+1))
-c      endif
       icall=4
       pstk(pt)=lc
 c     *call* allops
@@ -522,24 +526,24 @@ c     *call* macro
 c     
 c     break
  95   continue
-      pt=pt+1
- 96   pt=pt-1
-      if(pt.eq.0) then
+      p=pt+1
+ 96   p=p-1
+      if(p.eq.0) then
          lc=lc+1
          goto 10
       endif
-      if(rstk(pt).eq.612) then
+      if(rstk(p).eq.612) then
 c     break dans un for
-         l0=ids(1,pt)
+         l0=ids(1,p)
          lc=l0+istk(l0-1-nsiz)
-         pt=pt-1
+         pt=p-1
          top=top-1
          goto 70
-      elseif(rstk(pt).eq.616.and.istk(pstk(pt)).eq.9) then
+      elseif(rstk(p).eq.616.and.istk(pstk(p)).eq.9) then
 c     break dans un while 
-         l0=pstk(pt)
+         l0=pstk(p)
          lc=l0+abs(istk(l0+1))
-         pt=pt-1
+         pt=p-1
          goto 70
       else
          goto 96
@@ -744,6 +748,14 @@ c     character string vector
       endif
       lc=lc+5+n+nc
       goto 10
+
+
+ 220  continue
+c     varfun
+      call varfunptr(istk(lc+3),istk(lc+1),istk(lc+2))
+      lc=lc+3+nsiz
+      goto 10
+
 c
  998  continue
       lhs=0
