@@ -1,14 +1,19 @@
-/* Copyright INRIA */
+/* Copyright INRIA/ENPC */
+#include <string.h>
 #include "../machine.h"
 #ifdef WIN32 
-#ifndef __CYGWIN32__
+#if !(defined __CYGWIN32__) && !(defined __ABSC__)
 #include <direct.h>
 #define chdir(x) _chdir(x)
 #define GETCWD(x,y) _getcwd(x,y)
 #else 
+#ifndef __ABSC__
 #include <unistd.h>
 extern void sciprint(char *fmt,...);
 #define GETCWD(x,y) getcwd(x,y)
+#else
+#define GETCWD(x,y) getcwd_(x,y)
+#endif
 #endif 
 #endif 
 
@@ -29,23 +34,26 @@ extern char	   *getwd();
  * Changes scilab current directory 
  *******************************/
 
-int C2F(scichdir)(path,err)
-     char *path;
-     int *err;
+int C2F(scichdir)(char *path,int *err)
 {
   *err=0;
   if (path == (char*) 0) {
     *cur_dir = '\0';
     return (0);
   }
+#ifndef __ABSC__
   if (chdir(path) == -1) {
+#else
+  if (chdir_(path,strlen(path)) != 0) {
+#endif
     sciprint("Can't go to directory %s \r\n", path); 
     /** XXX : a remettre , sys_errlist[errno]); **/
     *err=1;
   } 
   /** a rajouter en XWindow ? pour transmettre l'info au menu 
-    if (get_directory(cur_dir)==0) 
+    if (get_directory()==0) 
     *err=1; **/
+  /* scilab_status_show(path); XXXX en attente */ 
   return 0;
 }
 
@@ -53,12 +61,13 @@ int C2F(scichdir)(path,err)
  * Get scilab current directory 
  *******************************/
 
-int C2F(scigetcwd)(path,lpath,err)
-     char **path;
-     int *lpath;
-     int *err;
+int C2F(scigetcwd)(char **path,int *lpath,int *err)
 {
+#ifndef __ABSC__
     if (GETCWD(cur_dir, 1024) == (char*) 0)
+#else
+    if (GETCWD(cur_dir, 1024) != 0)
+#endif
       {	/* get current working dir */
 	sciprint("Can't get current directory\r\n");
 	*cur_dir = '\0';
@@ -67,8 +76,13 @@ int C2F(scigetcwd)(path,lpath,err)
       }
     else 
       {
+#ifndef __ABSC__
 	*path= cur_dir;
 	*lpath=strlen(cur_dir);
+#else
+	*path=strtok(cur_dir,"  ");
+	*lpath=strlen(*path);	
+#endif
 	*err=0;
       }
     return 0;
