@@ -20,7 +20,7 @@ c
          return
       endif
       lx=sadr(il+hsize)
-      call dcopy(nx,stk(lx),1,x,1)
+      call unsfdcopy(nx,stk(lx),1,x,1)
       top=top-1
       return
    10 if(istk(il).ne.2) then
