@@ -49,25 +49,29 @@ c     traitement du coeff (l,k)
 c     .        non zero real part
                typ=1
                if(mode.eq.1) call fmt(abs(ar),maxc,typ,n1,n2)
-               if (ar.lt.0.0d0) then
-                  cw(l1:l1)='-'
-                  l1=l1+1
-               endif
+
                if(typ.eq.1) then
                   fl=maxc
-                  write(cw(l1:l1+fl-1),form(1)) abs(ar)
+                  write(cw(l1:l1+fl-1),form(1)) ar
                elseif(typ.eq.-1) then
-                  fl=3
-                  cw(l1:l1+fl-1)='Inf'
+                  if(ar.gt.0) then
+                     fl=3
+                     cw(l1:l1+fl-1)='Inf'
+                  else
+                     fl=4
+                     cw(l1:l1+fl-1)='-Inf'
+                  endif
+                  n2=1
                elseif(typ.eq.-2) then
                   fl=3
                   cw(l1:l1+fl-1)='Nan'
+                  n2=1
                else
                   fl=n1
+                  if(ar.lt.0.0d0) fl=fl+1
                   write(form(2),120) fl,n2
-                  write(cw(l1:l1+fl-1),form(2)) abs(ar)
+                  write(cw(l1:l1+fl-1),form(2)) ar
                endif
-
                if (cw(l1:l1).eq.' ') then
                   cw(l1:l1+fl-2)=cw(l1+1:l1+fl-1)
                   cw(l1+fl-1:l1+fl-1)=' '
@@ -90,9 +94,11 @@ c     .           non zero imaginary part
                   elseif(typ.eq.-1) then
                      fl=3
                      cw(l1:l1+fl-1)='Inf'
+                     n2=1
                   elseif(typ.eq.-2) then
                      fl=3
                      cw(l1:l1+fl-1)='Nan'
+                     n2=1
                   else
                      fl=n1
                      write(form(2),120) fl,n2
@@ -134,9 +140,11 @@ c     .        imaginary case
                   elseif(typ.eq.-1) then
                      fl=3
                      cw(l1:l1+fl-1)='Inf'
+                     n2=1
                   elseif(typ.eq.-2) then
                      fl=3
                      cw(l1:l1+fl-1)='Nan'
+                     n2=1
                   else
                      fl=n1
                      write(form(2),120) fl,n2
