@@ -7,21 +7,21 @@
 
 
 void LAB_get()
-
-
 {
-
-
-  Matrix *MHandle;
+  Matrix *MHandle, *Mfield, *Mvalue;
   int Handle;
 
-  Matrix *Mfield;
-  char *field;
+  if (Interf.NbParamIn < 2)
+    {
+      InterfError("Wrong number of input arguments");
+      return;
+    }
 
-  Matrix *Mvalue;
-  char *value;
-
- 
+  if (Interf.NbParamOut > 1 )
+    {
+      InterfError("Wrong number of output arguments");
+      return;
+    }
   
   MHandle = (Matrix *)Interf.Param[0];
   if (!MatrixIsReal(MHandle) )
@@ -37,8 +37,6 @@ void LAB_get()
       InterfError("Field parameter must be a string");
       return;
     }
-
-  
   
   if (TK_UiGet(Handle, Mfield, &Mvalue)==-1)
     {
