@@ -9,8 +9,13 @@
 #ifdef _MSC_VER
 #define IS_MSVC
 #endif
+#if defined (__MINGW32__) 
+#define IS_MSVC
+#endif
 #endif 
 
+
+
 #ifndef IS_MSVC
 #ifdef SYSV
 #include <string.h>
@@ -40,8 +45,11 @@ extern int TK_Wait;
 extern int TK_NbEv;
 extern int TK_Started;
 
-extern void flushTKEvents();
-extern void nocase ();
+extern void flushTKEvents(void);
+extern int  tcl_check_one_event(void);
+extern void nocase (char*s);
+extern void inittk(void);
+
 #endif
 
 
