@@ -10,7 +10,7 @@
 #ifndef STRICT
 #define STRICT
 #endif
-#include <windows.h>
+/*#include <windows.h>*/
 #include <setjmp.h>
 #include <string.h>
 #include <stdlib.h>
@@ -22,7 +22,7 @@
 
 #include <time.h>		/* kludge to provide sleep() */
 
-#include "wgnuplib.h"
+/*#include "wgnuplib.h"*/
 #include "wcommon.h"
 #include "plot.h"
 
@@ -62,7 +62,7 @@ rlgets (char *s, int n, char *prompt)
   /* If it's not an EOF */
   if (line)
     {
-      if (*line)
+      if (*line>=0)
 	add_history_win (line);
       strncpy (s, line, n);
       return s;
@@ -88,7 +88,7 @@ rlgets_nw (char *s, int n, char *prompt)
   if (line)
     {
       /* -1 is added for eos ( end of input when using pipes ) */
-      if (*line && *line != -1)
+      if (*line>=0)
 	add_history_nw (line);
       strncpy (s, line, n);
       return s;
@@ -124,6 +124,10 @@ read_line (char *prompt)
   input_line[start] = ilen > 126 ? 126 : ilen;
   input_line[start + 2] = 0;
   (void) (*rlgets_def) (&(input_line[start + 2]), ilen, prompt);
+  if (input_line[start + 2] == -2) /* dynamic menu canceled read SS */
+    {
+      return (-1);
+    }
   if ((p = strchr (&(input_line[start + 2]), '\r')) != NULL)
     *p = 0;
   if ((p = strchr (&(input_line[start + 2]), '\n')) != NULL)
