@@ -19,7 +19,7 @@
  */
 
 #include "gvwin.h"
-#include "wgnuplib.h"
+/*#include "wgnuplib.h"*/
 #include "wresource.h"
 #include "wcommon.h"
 
