@@ -57,6 +57,7 @@
 #include <stdio.h>
 #include <ctype.h>
 #include <signal.h>
+#include <conio.h>
 
 #ifdef __CYGWIN32__
 #include <unistd.h>		/* for isatty */
@@ -154,14 +155,14 @@ static char ansi_getc ();
 #ifndef STRICT
 #define STRICT
 #endif
-#include <windows.h>
+/*#include <windows.h>*/
+/*#include "wgnuplib.h"*/
+#include "wcommon.h"
 #ifdef USE_CONSOLE
 #include "wtextc.h"
 #else
 #include "wtext.h"
 #endif
-#include "wgnuplib.h"
-#include "wcommon.h"
 
 extern TW textwin;
 #define TEXTUSER 0xf1
@@ -228,7 +229,9 @@ static void clear_eoline ();
 static void copy_line ();
 static void set_termio ();
 static void reset_termio ();
-
+#include "../machine.h"
+extern int C2F(ismenu) ();
+static int sendprompt=1;
 /* user_putc and user_puts should be used in the place of
  * fputc(ch,stdout) and fputs(str,stdout) for all output
  * of user typed characters.  This allows MS-Windows to 
@@ -318,7 +321,7 @@ NotTTyRead (char *prompt, char *buffer, int buf_size, int *eof)
     }
   if (!tty)
     {
-/** We are reading a file ==> no prompts : XXXXX to test **/
+      /** We are reading a file ==> no prompts : XXXXX to test **/
       fputs ("-->", stdout);
       /* read a line into the buffer, but not too* big */
       *eof = (fgets (buffer, buf_size, stdin) == NULL);
@@ -363,7 +366,9 @@ readline_win (char *prompt)
   set_termio ();
 
   /* print the prompt */
-  fputs (prompt, stdout);
+  if (sendprompt) fputs (prompt, stdout);
+  sendprompt=1;
+
   cur_line[0] = '\0';
   cur_pos = 0;
   max_pos = 0;
@@ -373,6 +378,15 @@ readline_win (char *prompt)
   for (;;)
     {
       cur_char = special_getc ();
+      if (C2F(ismenu) () == 1) {/* abort current line aquisition SS */
+	sendprompt=0;
+	new_line = (char *) alloc ((unsigned long) 2,
+					 "history");
+	new_line[0] = -2;
+	new_line[1] = '\0';
+	reset_termio ();
+	return (new_line);
+      }
 #ifdef OS2
       /* for emx: remap scan codes for cursor keys */
       if (cur_char == 0)
