@@ -1,7 +1,7 @@
 
 
 
-/* Copyright (C) 1998 Chancelier Jean-Philippe */
+/* Copyright (C) 1998-2002 Chancelier Jean-Philippe */
 
 /*
    Simple program to start Scilab with its console window hidden.
@@ -20,14 +20,9 @@
 #include <stdio.h>
 #include <windows.h>
 #include <string.h>
-
-#ifdef __STDC__
 #include <stdlib.h>
-#else
-#include <malloc.h>
-#endif
 
-#ifdef __MSC__
+#if defined (__MSC__) || defined(__MINGW32__)
 #define putenv(x) _putenv(x)
 #endif
 
@@ -109,11 +104,9 @@ WinMain (HINSTANCE hSelf, HINSTANCE hPrev, LPSTR cmdline, int nShow)
   *p = 0;
 
   SciEnv ();
-#ifdef __ABSC__
+
   new_cmdline = malloc (MAX_PATH + strlen (cmdline) + 1);
-#else
-  new_cmdline = alloca (MAX_PATH + strlen (cmdline) + 1);
-#endif
+
   strcpy (new_cmdline, modname + 1);
   strcat (new_cmdline, "\\scilex.exe ");
 
