@@ -1,4 +1,4 @@
-/* Copyright (C) 1998 Chancelier Jean-Philippe */
+/* Copyright (C) 1998-2002 Chancelier Jean-Philippe */
 /* Scilab wgmenu.c 
 
  *  Menus for graphic window ( from wmenu.c ) 
@@ -9,15 +9,14 @@
 #ifndef STRICT
 #define STRICT
 #endif
-#include <windows.h>
-#include <windowsx.h>
-#include <commdlg.h>
+/*#include <windows.h>
+  #include <windowsx.h>*/
 #include <string.h>		/* only use  items */
 
 #ifdef __CYGWIN32__
 #include <unistd.h>		/* for getpid */
 #endif
-#ifdef __MSC__
+#if (defined __MSC__) || (defined __MINGW32__)
 #include <process.h>		/* for getpid */
 #endif
 
@@ -31,9 +30,10 @@
 int system ();
 #endif
 
-#include "wgnuplib.h"
+/*#include "wgnuplib.h"*/
 #include "wresource.h"
 #include "wcommon.h"
+#include <commdlg.h>
 #include "../graphics/Graphics.h"
 #include "../sun/men_Sutils.h"
 extern TW textwin;
@@ -237,7 +237,7 @@ void ScilabMenuAction (char *buf)
       if (buf[1] == '0')
 	{
 	  /* Interpreted mode : we store the action on a queue */
-	  StoreCommand1 (buf + 2, 1);
+	  StoreCommand1 (buf + 2, 2);
 	}
       else
 	{
@@ -807,10 +807,19 @@ void AddMenu (integer * win_num, char *button_name, char **entries,
 				  + lstrlen (fname) + 1)) != (BYTE *) NULL)
 	{
 	  if (*win_num < 0)
-	    sprintf ((char *) macroptr, "@%dexecstr(%s(%d))", *typ, fname, 1);
-	  else
-	    sprintf ((char *) macroptr, "@%dexecstr(%s_%d(%d))", *typ,
-		     fname, *win_num, 1);
+	    if (*typ==0) 
+	      sprintf ((char *) macroptr, "@%dexecstr(%s(%d))", *typ, fname, 1);
+	    else if (*typ==2) 
+	      sprintf ((char *) macroptr, "@0%s(%d,%d)",fname, 1,*win_num);
+	    else
+	      sprintf ((char *) macroptr, "@%dexecstr(%s(%d))", *typ,fname, 1);
+	  else 
+	    if (*typ==0) 
+	      sprintf ((char *) macroptr, "@0execstr(%s_%d(%d))",fname, *win_num, 1);
+	    else if (*typ==2) 
+	      sprintf ((char *) macroptr, "@0%s(%d,%d)",fname, 1,*win_num);
+	    else
+	      sprintf ((char *) macroptr, "@%dexecstr(%s_%d(%d))", *typ,fname, *win_num, 1);
 	}
       else
 	{
@@ -838,10 +847,19 @@ void AddMenu (integer * win_num, char *button_name, char **entries,
 				   + lstrlen (fname) + 1)) != (BYTE *) NULL)
 	    {
 	      if (*win_num < 0)
-		sprintf ((char *) macroptr, "@%dexecstr(%s(%d))", *typ, fname, i + 1);
+		if (*typ==0) 
+		  sprintf ((char *) macroptr, "@%dexecstr(%s(%d))", *typ, fname, i + 1);
+		else if (*typ==2) 
+		  sprintf ((char *) macroptr, "@0%s(%d,%d)",fname, i + 1,*win_num);
+		else
+		  sprintf ((char *) macroptr, "@%dexecstr(%s(%d))", *typ,fname, i + 1);
 	      else
-		sprintf ((char *) macroptr, "@%dexecstr(%s_%d(%d))", *typ,
-			 fname, *win_num, i + 1);
+		if (*typ==0) 
+		  sprintf ((char *) macroptr, "@0execstr(%s_%d(%d))",fname, *win_num, i + 1);
+		else if (*typ==2) 
+		  sprintf ((char *) macroptr, "@0%s(%d,%d)",fname, i + 1,*win_num);
+		else
+		  sprintf ((char *) macroptr, "@%dexecstr(%s_%d(%d))", *typ,fname, *win_num, i + 1);
 	    }
 	  else
 	    {
@@ -912,6 +930,7 @@ static char *Print_Formats[] =
   "Postscript-Latex",
   "Xfig",
   "GIF",
+  "PPM",
 };
 
 /****************************************************
@@ -1060,6 +1079,12 @@ static void SavePs (struct BCG *ScilabGC)
       wininfo ("end of GIF file generation");
       SetCursor (LoadCursor (NULL, IDC_CROSS));
       break;
+    case 5:
+      SetCursor (LoadCursor (NULL, IDC_WAIT));
+      scig_tops (ScilabGC->CurWindow, ls.colored, filename, "PPM");
+      wininfo ("end of PPM file generation");
+      SetCursor (LoadCursor (NULL, IDC_CROSS));
+      break;
     }
 }
 
