@@ -30,27 +30,23 @@
 #endif
 #include <windows.h>
 #include <windowsx.h>
-
-#ifndef __GNUC__
 #include <commdlg.h>
 #include <shellapi.h>
-#endif
 
 #include <string.h>
 #include <stdlib.h>
 #include <ctype.h>
 #include <stdarg.h>
 
-#include "wgnuplib.h"
 #include "wresource.h"
 #include "wcommon.h"
 #include "../graphics/scigraphic.h"
 #include "../graphics/Graphics.h"
-
+#include "wgraph.h"
 extern void SetGHdc __PARAMS ((HDC lhdc, int width, int height));
 static void scig_replay_hdc (char c, integer win_num, HDC hdc, int width, int height,
 			     int scale);
-
+extern int check_pointer_win __PARAMS ((int *x1,int *y1,int *win));
 extern TW textwin;
 
 EXPORT LRESULT CALLBACK WndGraphProc (HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam);
@@ -65,12 +61,23 @@ static int scig_buzy = 0;
 
 /* add handlers for delete action */
 
-void scig_deletegwin_handler_none (win)
-     int win;
+void scig_deletegwin_handler_none (int win)
 {
 };
+void scig_deletegwin_handler_sci (int win)
 
-static Scig_deletegwin_handler scig_deletegwin_handler = scig_deletegwin_handler_none;
+{
+  static char buf[256];
+  struct BCG *SciGc;
+
+  SciGc = GetWindowXgcNumber(win);
+  if (strlen(SciGc->EventHandler)!=0) {
+    sprintf(buf,"%s(%d,0,0,-1000)",SciGc->EventHandler,win);
+    StoreCommand1(buf,2);
+    }
+};
+static Scig_deletegwin_handler scig_deletegwin_handler = scig_deletegwin_handler_sci;
+/*static Scig_deletegwin_handler scig_deletegwin_handler = scig_deletegwin_handler_none;*/
 
 Scig_deletegwin_handler set_scig_deletegwin_handler (f)
      Scig_deletegwin_handler f;
@@ -82,16 +89,22 @@ Scig_deletegwin_handler set_scig_deletegwin_handler (f)
 
 void reset_scig_deletegwin_handler ()
 {
-  scig_deletegwin_handler = scig_deletegwin_handler_none;
+  scig_deletegwin_handler = scig_deletegwin_handler_sci;
 }
 
+static int sci_graphic_protect = 0;
+
+void   set_delete_win_mode() {  sci_graphic_protect = 0 ;}
+extern void   set_no_delete_win_mode()  {  sci_graphic_protect = 1 ;}
+
 int C2F (deletewin) (integer * number)
 {
   /* destroying recorded graphic commands */
   scig_erase (*number);
   /* delete the windows and resources */
-  DeleteSGWin (*number);
+  if (version_flag()==0) DeleteObjs(*number);
   scig_deletegwin_handler (*number);
+  DeleteSGWin (*number);
   return (0);
 }
 
@@ -481,6 +494,18 @@ extern void DebugGW (char *fmt,...)
 #endif
 }
 
+extern void DebugGW1 (char *fmt,...)
+{
+  int i, count;
+  char buf[MAXPRINTF];
+  va_list args;
+  va_start (args, fmt);
+  count = vsprintf (buf, fmt, args);
+  MessageBox (textwin.hWndParent, (LPSTR) buf,
+	      textwin.Title, MB_ICONEXCLAMATION);
+  va_end (args);
+}
+
 /**SciViewportMove
  *@description: used to move the panner and the viewport interactively 
  *              through scilab command.
@@ -599,23 +624,43 @@ void GPopupResize (ScilabXgc, width, height)
  * events while we are in GraphicWindowProc 
  ***********************************************/
 
-typedef struct but
-{
-  int win, x, y, ibutton, motion, release;
-}
-But;
-
 #define MaxCB 50
 static But ClickBuf[MaxCB];
 static int lastc = 0;
 
-int scig_click_handler_none (win, x, y, ibut, motion, release)
-     int win, x, y, ibut, motion, release;
+/* used by xclick_any and xclick */ 
+
+static int wait_for_click=0;
+But SciClickInfo; /* for xclick and xclick_any */
+
+void set_wait_click(val) {  
+  wait_for_click=val;
+  if ( val == 1 ) 
+    SciClickInfo.win=-1; 
+}
+
+int scig_click_handler_none (int win,int x,int y,int ibut,int motion,int release)
 {
   return 0;
 };
 
-static Scig_click_handler scig_click_handler = scig_click_handler_none;
+int scig_click_handler_sci (int win,int x,int y,int ibut,int motion,int release)
+
+{
+  static char buf[256];
+  struct BCG *SciGc;
+
+  SciGc = GetWindowXgcNumber(win);
+  if (strlen(SciGc->EventHandler)!=0) {
+    sprintf(buf,"%s(%d,%d,%d,%d)",SciGc->EventHandler,win,x,y,ibut);
+    StoreCommand1(buf,2);
+    return 1;}
+  else
+    return 0;
+};
+
+static Scig_click_handler scig_click_handler = scig_click_handler_sci;
+/*static Scig_click_handler scig_click_handler = scig_click_handler_none;*/
 
 Scig_click_handler set_scig_click_handler (f)
      Scig_click_handler f;
@@ -627,14 +672,29 @@ Scig_click_handler set_scig_click_handler (f)
 
 void reset_scig_click_handler ()
 {
-  scig_click_handler = scig_click_handler_none;
+  scig_click_handler = scig_click_handler_sci;
 }
 
-int PushClickQueue (win, x, y, ibut, motion, release)
-     int win, x, y, ibut, motion, release;
+int PushClickQueue (int win,int x,int y,int ibut,int motion,int release)
 {
-  if (scig_click_handler (win, x, y, ibut, motion, release) == 1)
-    return 0;
+  /* If we are in xclick_any or xclick then send info */
+  if ( wait_for_click==1)
+    {
+
+      SciClickInfo.win= win;
+      SciClickInfo.x= x;
+      SciClickInfo.y= y;
+      SciClickInfo.ibutton= ibut;
+      SciClickInfo.motion= motion;
+      SciClickInfo.release= release;
+      return 0;
+    }
+     
+  /* first let a click_handler do the job  */
+  if ( scig_click_handler(win,x,y,ibut,motion,release)== 1) return 0;
+  /* do not record motion events and release button 
+   * this is left for a futur release 
+   */
   if (motion == 1 || release == 1)
     return 0;
   if (lastc == MaxCB)
@@ -664,8 +724,7 @@ int PushClickQueue (win, x, y, ibut, motion, release)
   return (0);
 }
 
-int CheckClickQueue (win, x, y, ibut)
-     integer *win, *x, *y, *ibut;
+int CheckClickQueue (integer *win,integer *x, integer *y, integer *ibut)
 {
   int i;
   for (i = 0; i < lastc; i++)
@@ -693,8 +752,7 @@ int CheckClickQueue (win, x, y, ibut)
   return (0);
 }
 
-int ClearClickQueue (win)
-     int win;
+int ClearClickQueue (int win)
 {
   int i;
   if (win == -1)
@@ -772,21 +830,19 @@ static void ScilabPaint (HWND hwnd, struct BCG *ScilabGC)
   PAINTSTRUCT ps;
   RECT rect;
   /* paint++; */
-/** wininfo("Painting %d",paint); **/
-/** if we are in pixmap mode ? **/
+  /** wininfo("Painting %d",paint); **/
+  /** if we are in pixmap mode ? **/
   if (scig_buzy == 1)
     return;
   scig_buzy = 1;
 
-  //hdc = BeginPaint(hwnd, &ps);
-  // suprime par Mat
-  hdc = BeginPaint (ScilabGC->CWindow, &ps);
+  hdc = BeginPaint(hwnd, &ps);
   if (ScilabGC->Inside_init != 1)
     {
       SetMapMode (hdc, MM_TEXT);
       SetBkMode (hdc, TRANSPARENT);
       GetClientRect (hwnd, &rect);
-      //SetViewportExtEx(hdc, rect.right, rect.bottom,NULL);
+      /*SetViewportExtEx(hdc, rect.right, rect.bottom,NULL);*/
       SetViewportExtEx (hdc, ScilabGC->CWindowWidth, ScilabGC->CWindowHeight, NULL);
       DebugGW ("==> paint rect %d %d \n", rect.right, rect.bottom);
       if (sciGetPixmapStatus () == 1)
@@ -807,9 +863,7 @@ static void ScilabPaint (HWND hwnd, struct BCG *ScilabGC)
 			   ScilabGC->CWindowHeight, 1);
 	}
     }
-  //EndPaint(hwnd, &ps);
-  // supprime par Mat
-  EndPaint (ScilabGC->CWindow, &ps);
+  EndPaint(hwnd, &ps);
 
   scig_buzy = 0;
 }
@@ -844,13 +898,13 @@ static void ScilabGResize (HWND hwnd, struct BCG *ScilabGC, WPARAM wParam)
  ****************************************************/
 
 EXPORT LRESULT CALLBACK
-  WndGraphProc (HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
+  WndGraphProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 {
-  static paint = 0;
   RECT rect;
   struct BCG *ScilabGC;
   int deltax = 0;
   int deltay = 0;
+  int x,y,iwin;
 
   SCROLLINFO vertsi;
   SCROLLINFO horzsi;
@@ -905,8 +959,11 @@ EXPORT LRESULT CALLBACK
 	    return 0;
 	  }
       return 0;
+    case WM_KEYDOWN:
+      return (0);
     case WM_CHAR:
-      //sciSendMessage(hwnd, WM_CHAR, wParam, lParam);
+      check_pointer_win(&x,&y,&iwin);
+      PushClickQueue (ScilabGC->CurWindow, x,y,wParam,0,0);
       return (0);
     case WM_MOUSEMOVE:
       PushClickQueue (ScilabGC->CurWindow, ((int) LOWORD (lParam)) + ScilabGC->horzsi.nPos,
@@ -915,32 +972,32 @@ EXPORT LRESULT CALLBACK
     case WM_LBUTTONDOWN:
       PushClickQueue (ScilabGC->CurWindow, ((int) LOWORD (lParam)) + ScilabGC->horzsi.nPos,
 		      HIWORD (lParam) + ScilabGC->vertsi.nPos, 0, 0, 0);
-      //sciSendMessage(hwnd, WM_CHAR, wParam, lParam);
+      /*sciSendMessage(hwnd, WM_CHAR, wParam, lParam);*/
       return (0);
     case WM_MBUTTONDOWN:
       PushClickQueue (ScilabGC->CurWindow, ((int) LOWORD (lParam)) + ScilabGC->horzsi.nPos,
 		      HIWORD (lParam) + ScilabGC->vertsi.nPos, 1, 0, 0);
-      //sciSendMessage(hwnd, WM_CHAR, wParam, lParam);
+      /*sciSendMessage(hwnd, WM_CHAR, wParam, lParam);*/
       return (0);
     case WM_RBUTTONDOWN:
       PushClickQueue (ScilabGC->CurWindow, ((int) LOWORD (lParam)) + ScilabGC->horzsi.nPos,
 		      HIWORD (lParam) + ScilabGC->vertsi.nPos, 2, 0, 0);
-      //sciSendMessage(hwnd, WM_CHAR, wParam, lParam);
+      /*sciSendMessage(hwnd, WM_CHAR, wParam, lParam);*/
       return (0);
     case WM_LBUTTONUP:
       PushClickQueue (ScilabGC->CurWindow, ((int) LOWORD (lParam)) + ScilabGC->horzsi.nPos
 		      ,HIWORD (lParam) + ScilabGC->vertsi.nPos, -5, 0, 1);
-      //sciSendMessage(hwnd, WM_CHAR, wParam, lParam);
+      /*sciSendMessage(hwnd, WM_CHAR, wParam, lParam);*/
       return (0);
     case WM_MBUTTONUP:
       PushClickQueue (ScilabGC->CurWindow, ((int) LOWORD (lParam)) + ScilabGC->horzsi.nPos,
 		      HIWORD (lParam) + ScilabGC->vertsi.nPos, -4, 0, 1);
-      //sciSendMessage(hwnd, WM_CHAR, wParam, lParam);
+      /*sciSendMessage(hwnd, WM_CHAR, wParam, lParam);*/
       return (0);
     case WM_RBUTTONUP:
       PushClickQueue (ScilabGC->CurWindow, ((int) LOWORD (lParam)) + ScilabGC->horzsi.nPos,
 		      HIWORD (lParam) + ScilabGC->vertsi.nPos, -3, 0, 1);
-      //sciSendMessage(hwnd, WM_CHAR, wParam, lParam);
+      /*sciSendMessage(hwnd, WM_CHAR, wParam, lParam);*/
       return (0);
     case WM_CREATE:
       ScilabGC = ((CREATESTRUCT *) lParam)->lpCreateParams;
@@ -1003,7 +1060,7 @@ EXPORT LRESULT CALLBACK
 	sciGetScrollInfo (ScilabGC, SB_HORZ, &horzsi);
 	switch (LOWORD (wParam))
 	  {
-	    deltax = 0;
+	    /* deltax = 0;*/
 	  case SB_PAGEUP:
 	    deltax = horzsi.nPos;
 	    horzsi.nPos = max (horzsi.nMin, horzsi.nPos - 50);
@@ -1011,7 +1068,7 @@ EXPORT LRESULT CALLBACK
 	    break;
 	  case SB_PAGEDOWN:
 	    deltax = horzsi.nPos;
-	    horzsi.nPos = min (horzsi.nMax - horzsi.nPage, horzsi.nPos + 50);
+	    horzsi.nPos = min (horzsi.nMax - (int)horzsi.nPage, horzsi.nPos + 50);
 	    deltax = deltax - horzsi.nPos;
 	    break;
 	  case SB_LINEUP:
@@ -1021,7 +1078,7 @@ EXPORT LRESULT CALLBACK
 	    break;
 	  case SB_LINEDOWN:
 	    deltax = horzsi.nPos;
-	    horzsi.nPos = min (horzsi.nMax - horzsi.nPage, horzsi.nPos + 5);
+	    horzsi.nPos = min (horzsi.nMax - (int) horzsi.nPage, horzsi.nPos + 5);
 	    deltax = deltax - horzsi.nPos;
 	    break;
 	  case SB_THUMBTRACK:
@@ -1030,6 +1087,7 @@ EXPORT LRESULT CALLBACK
 	    deltax = deltax - horzsi.nPos;
 	    break;
 	  default:
+	    deltax=0;
 	    break;
 	  }
 	sciSetScrollInfo (ScilabGC, SB_HORZ, &horzsi, TRUE);
@@ -1043,7 +1101,7 @@ EXPORT LRESULT CALLBACK
 	sciGetScrollInfo (ScilabGC, SB_VERT, &vertsi);
 	switch (LOWORD (wParam))
 	  {
-	    deltay = 0;
+	    /* deltay = 0; */
 	  case SB_PAGEUP:
 	    deltay = vertsi.nPos;
 	    vertsi.nPos = max (vertsi.nMin, vertsi.nPos - 50);
@@ -1051,7 +1109,7 @@ EXPORT LRESULT CALLBACK
 	    break;
 	  case SB_PAGEDOWN:
 	    deltay = vertsi.nPos;
-	    vertsi.nPos = min (vertsi.nMax - vertsi.nPage, vertsi.nPos + 50);
+	    vertsi.nPos = min (vertsi.nMax - (int) vertsi.nPage, vertsi.nPos + 50);
 	    deltay = deltay - vertsi.nPos;
 	    break;
 	  case SB_LINEUP:
@@ -1061,7 +1119,7 @@ EXPORT LRESULT CALLBACK
 	    break;
 	  case SB_LINEDOWN:
 	    deltay = vertsi.nPos;
-	    vertsi.nPos = min (vertsi.nMax - vertsi.nPage, vertsi.nPos + 5);
+	    vertsi.nPos = min (vertsi.nMax - (int) vertsi.nPage, vertsi.nPos + 5);
 	    deltay = deltay - vertsi.nPos;
 	    break;
 	  case SB_THUMBTRACK:
@@ -1089,8 +1147,8 @@ EXPORT LRESULT CALLBACK
       return 0;
     case WM_CLOSE:
       DebugGW ("Je fais un close \n");
-      //TranslateMessage(&message);
-      //DispatchMessage(&message);
+      /*TranslateMessage(&message);*/
+      /*DispatchMessage(&message);*/
       PostQuitMessage (0);
       C2F (deletewin) (&(ScilabGC->CurWindow));
       SetWindowLong (hwnd, 0, (LONG) 0L);
@@ -1129,7 +1187,12 @@ static void scig_replay_hdc (char c, integer win_num, HDC hdc, int width, int he
   ResetScilabXgc ();
 /** xclear will properly upgrade background if necessary **/
   C2F (dr) ("xclear", "v", PI0, PI0, PI0, PI0, PI0, PI0, PD0, PD0, PD0, PD0, 0L, 0L);
-  C2F (dr) ("xreplay", "v", &win_num, PI0, PI0, PI0, PI0, PI0, PD0, PD0, PD0, PD0, 0L, 0L);
+  if (version_flag() == 0)
+    {
+      sciRedrawF(&win_num); /* NG */
+    }
+  else
+    C2F (dr) ("xreplay", "v", &win_num, PI0, PI0, PI0, PI0, PI0, PD0, PD0, PD0, PD0, 0L, 0L);
   C2F (dr1) ("xset", "alufunction", &alu, PI0, PI0, PI0, PI0, PI0, PD0, PD0, PD0, PD0, 0L, 0L);
   C2F (dr) ("xset", "window", &cur, PI0, PI0, PI0, PI0, PI0, PD0, PD0, PD0, PD0, 0L, 0L);
   C2F (SetDriver) (name, PI0, PI0, PI0, PI0, PI0, PI0, PD0, PD0, PD0, PD0);
@@ -1171,8 +1234,8 @@ EXPORT LRESULT CALLBACK
       SendMessage (textwin.hWndText, message, wParam, lParam);
       return (0);
     case WM_SETFOCUS:
-/** when focus is set in the graphic window we set it to scilab window **/
-    /*************** Matthieu PHILIPPE
+      /** when focus is set in the graphic window we set it to scilab window **/
+      /*************** Matthieu PHILIPPE
 	je retire cette fonction pour pouvoir recuperer
 	les evevenements clavier et les traiter !!
 	SendMessage(textwin.hWndText, message, wParam, lParam); 
@@ -1180,13 +1243,13 @@ EXPORT LRESULT CALLBACK
       SetFocus (ScilabGC->CWindow);
       return (0);
     case WM_KEYDOWN:
-      /*SendMessage(textwin.hWndText, message, wParam, lParam); */
+      SendMessage (ScilabGC->CWindow, message, wParam, lParam);
       return (0);
     case WM_CHAR:
       SendMessage (ScilabGC->CWindow, message, wParam, lParam);
       return (0);
     case WM_GETMINMAXINFO:
-/*** Eventuellement a changer XXXXXXX  **/
+      /*** Eventuellement a changer XXXXXXX  **/
       hdc = GetDC (hwnd);
       SelectFont (hdc, GetStockFont (OEM_FIXED_FONT));
       GetTextMetrics (hdc, (LPTEXTMETRIC) & tm);
@@ -1199,7 +1262,7 @@ EXPORT LRESULT CALLBACK
 	+ GetSystemMetrics (SM_CYCAPTION);
       return (0);
     case WM_SIZE:
-/** sciprint("Resising Parent"); **/
+      /** sciprint("Resising Parent"); **/
       GetWindowRect (ScilabGC->Statusbar, &rect);
       SetWindowPos (ScilabGC->Statusbar, (HWND) NULL, 0,
 		    HIWORD (lParam) - (rect.bottom - rect.top),
@@ -1221,7 +1284,7 @@ EXPORT LRESULT CALLBACK
 	}
       return (0);
     case WM_COMMAND:
-/** pass on menu commands */
+      /** pass on menu commands */
       if (IsWindow (ScilabGC->CWindow))
 	SetFocus (ScilabGC->CWindow);
       SendMessage (ScilabGC->CWindow, message, wParam, lParam);
@@ -1263,9 +1326,24 @@ EXPORT LRESULT CALLBACK
       DragAcceptFiles (hwnd, FALSE);
       break;
     case WM_CLOSE:
-/** The Graphic window will do the job **/
+      /** The Graphic window will do the job **/
       SendMessage (ScilabGC->CWindow, WM_CLOSE, 0, 0);
       return 0;
     }
   return DefWindowProc (hwnd, message, wParam, lParam);
 }
+
+
+
+void C2F(seteventhandler)(int *win_num,char *name,int *ierr)
+
+{  
+  struct BCG *SciGc;
+
+  /*ButtonPressMask|PointerMotionMask|ButtonReleaseMask|KeyPressMask */
+  *ierr = 0;
+  SciGc = GetWindowXgcNumber(*win_num);
+  if ( SciGc ==  NULL ) {*ierr=1;return;}
+  strncpy(SciGc->EventHandler,name,24);
+}
+
