@@ -1,4 +1,3 @@
-
 /*******************************************
  * Original source : GNUPLOT - winmain.c
  * modified for Scilab 
@@ -22,27 +21,28 @@
  * 
  *   Maurice Castro
  *   Russell Lang
- * Modified for Scilab (1997) : Jean-Philippe Chancelier 
+ *   Modified for Scilab (1997) : Jean-Philippe Chancelier 
  * 
  */
 
 #ifndef STRICT
 #define STRICT
 #endif
-#include <windows.h>
-#include <windowsx.h>
-
-#ifndef __GNUC__
-#include <commctrl.h>
-#endif
-
-#ifdef __STDC__
+#include <stdio.h>
 #include <stdlib.h>
-#else
-#include <malloc.h>
-#endif
+#include <string.h>
+#include <stdarg.h>
 
-#ifdef __MSC__
+/*#include <windows.h>
+#include <windowsx.h>
+#include <commctrl.h>*/
+
+#include "wcommon.h"
+#include "plot.h"
+/* #include "wgnuplib.h"
+#include "wtext.h"*/
+
+#if (defined __MSC__ ) || (defined __MINGW32__) 
 #define putenv(x) _putenv(x)
 #endif
 
@@ -50,16 +50,6 @@
 #define putenv(x) abs_putenv(x)
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <stdarg.h>
-
-#include "plot.h"
-#include "wgnuplib.h"
-#include "wtext.h"
-#include "wcommon.h"
-
 extern void C2F (tmpdirc) ();
 
 /* limits */
@@ -78,7 +68,6 @@ LPSTR szGraphMenuName;
 
 int SciPlatformId;
 
-
 #define MENUNAME "wscilab.mnu"
 #define GRAPHMENUNAME "wgscilab.mnu"
 
@@ -86,14 +75,22 @@ void WinExit (void);
 
 extern void C2F (getwins) (integer *, integer *, integer *);
 extern void C2F (diary) (char *, int *, int);
+extern void set_sci_env(char *p, char *wsci) ;
 
 static void AllGraphWinDelete ();
-static int startupf = 0;
-/** 0 if we execute startup else 1 **/
+static int startupf = 0; /** 0 if we execute startup else 1 **/
 static int nointeractive = 0;
+static int show_logo = 1;
 
-static void 
-CheckMemory (LPSTR str)
+#define MIN_STACKSIZE 180000
+
+static int  memory = MIN_STACKSIZE;
+
+/*---------------------------------------------------
+ * utilities 
+ *---------------------------------------------------*/
+
+static void CheckMemory (LPSTR str)
 {
   if (str == (LPSTR) NULL)
     {
@@ -102,28 +99,26 @@ CheckMemory (LPSTR str)
     }
 }
 
-int 
-Pause (LPSTR str)
+int Pause (LPSTR str)
 {
   pausewin.Message = str;
   return (PauseBox (&pausewin) == IDOK);
 }
 
-/**************************
+/*---------------------------------------------------
  * atexit procedure for scilab and scilab -nw 
- *************************/
+ *---------------------------------------------------*/
 
-void 
-WinExit (void)
+void WinExit (void)
 {
   int i;
-/** TMPDIR is not created with scilab -ns **/
-  if (startupf == 0)
-    C2F (tmpdirc) ();
+  /** clear tmpdir */
+  /** fprintf(stderr,"I Quit Scilab through sciquit\n"); **/
+  C2F (tmpdirc) ();
   C2F (xscion) (&i);
   if (i != 0)
     {
-/** delete all graph windows **/
+      /** delete all graph windows **/
       AllGraphWinDelete ();
       TextMessage ();		/* process messages */
       TextClose (&textwin);
@@ -132,16 +127,7 @@ WinExit (void)
   return;
 }
 
-/**************************
- * procedure called in sciquit 
- * but WinExit do the proper job at exit
- *************************/
-
-int C2F (clearexit) (integer * n)
-{
-  return (0);
-}
-
+/* utility function for WinExit */
 
 static void 
 AllGraphWinDelete ()
@@ -162,8 +148,7 @@ AllGraphWinDelete ()
 
 /* call back function from Text Window WM_CLOSE */
 
-EXPORT int CALLBACK 
-ShutDown (void)
+EXPORT int CALLBACK  ShutDown (void)
 {
   exit (0);
   return 0;
@@ -174,12 +159,10 @@ ShutDown (void)
  * necessary 
  ********************************/
 
-static void 
-SciEnv ()
+static void SciEnv ()
 {
-  char *p, *p1;
   char modname[MAX_PATH + 1];
-  char env[MAX_PATH + 1 + 10];
+  char *p;
   if (!GetModuleFileName (NULL, modname + 1, MAX_PATH))
     return;
   if ((p = strrchr (modname + 1, '\\')) == NULL)
@@ -210,86 +193,115 @@ SciEnv ()
 #else
       p = modname + 1;
 #endif
-      if ((p1 = getenv ("SCI")) == (char *) 0)
+      set_sci_env(p,(char *) 0);
+    }
+}
+
+/*----------------------------------------------------
+ * set env variables (used when calling scilab from 
+ * other programs)
+ *----------------------------------------------------*/
+
+void set_sci_env(char *p, char *wsci) 
+{
+  char *p1;
+  char env[MAX_PATH + 1 + 10];
+  if ((p1 = getenv ("SCI")) == (char *) 0)
+    {
+      sprintf (env, "SCI=%s",p);
+      putenv (env);
+    }
+  if ((p1 = getenv ("HOME")) == (char *) 0)
+    {
+      sprintf (env, "HOME=%s", p);
+      putenv (env);
+    }
+  if ((p1 = getenv ("PWD")) == (char *) 0)
+    {
+      sprintf (env, "PWD=%s", p);
+      putenv (env);
+    }
+  /** for PVM **/
+  for (p1 = p; *p1; p1++)
+    {
+      if (*p1 == '/')
+	*p1 = '\\';
+    }
+  if ((p1 = getenv ("PVM_ROOT")) == (char *) 0)
+    {
+      sprintf (env, "PVM_ROOT=%s\\pvm3", p);
+      putenv (env);
+    }
+  if ((p1 = getenv ("PVM_ARCH")) == (char *) 0)
+    {
+      sprintf (env, "PVM_ARCH=WIN32");
+      putenv (env);
+    }
+  if ((p1 = getenv ("PVM_TMP")) == (char *) 0)
+    {
+      if ((p1 = getenv ("TEMP")) == (char *) 0)
 	{
-	  sprintf (env, "SCI=%s", p);
+	  sprintf (env, "PVM_TMP=c:\\tmp");
 	  putenv (env);
 	}
-      if ((p1 = getenv ("HOME")) == (char *) 0)
+      else
 	{
-	  sprintf (env, "HOME=%s", p);
-	  putenv (env);
-	}
-      if ((p1 = getenv ("PWD")) == (char *) 0)
-	{
-	  sprintf (env, "PWD=%s", p);
-	  putenv (env);
-	}
-      if ((p1 = getenv ("MANCHAPTERS")) == (char *) 0)
-	{
-	  sprintf (env, "MANCHAPTERS=%s/man/Chapters", p);
-	  putenv (env);
-	}
-/** for PVM **/
-      for (p1 = p; *p1; p1++)
-	{
-	  if (*p1 == '/')
-	    *p1 = '\\';
-	}
-      if ((p1 = getenv ("PVM_ROOT")) == (char *) 0)
-	{
-	  sprintf (env, "PVM_ROOT=%s\\pvm3", p);
-	  putenv (env);
-	}
-      if ((p1 = getenv ("PVM_TMP")) == (char *) 0)
-	{
-	  if ((p1 = getenv ("TEMP")) == (char *) 0)
-	    {
-	      sprintf (env, "PVM_TMP=c:\\tmp");
-	      putenv (env);
-	    }
-	  else
-	    {
-	      sprintf (env, "PVM_TMP=%s", p1);
-	      putenv (env);
-	    }
-	}
-      if ((p1 = getenv ("WSCI")) == (char *) 0)
-	{
-	  sprintf (env, "WSCI=%s", p);
+	  sprintf (env, "PVM_TMP=%s", p1);
 	  putenv (env);
 	}
+    }
+  if ((p1 = getenv ("WSCI")) == (char *) 0)
+    {
+      if ( wsci != NULL) 
+	sprintf (env, "WSCI=%s", wsci);
+      else 
+	sprintf (env, "WSCI=%s", p);
+      putenv (env);
+    }
 #ifdef __MSC__
       putenv ("COMPILER=VC++");
 #endif
-#ifdef __CYGWIN32__
+#if (defined __CYGWIN32__ ) || (defined __MINGW32__) 
       putenv ("COMPILER=gcc");
 #endif
 #ifdef __ABSC__
       putenv ("COMPILER=ABSOFT");
 #endif
       putenv ("WIN32=OK");
-    }
 }
 
-/*************
+
+
+/*---------------------------------------------------
  * platform flag 
  *	The return value is one of:
  *	    VER_PLATFORM_WIN32s		Win32s on Windows 3.1. 
  *	    VER_PLATFORM_WIN32_WINDOWS	Win32 on Windows 95.
  *	    VER_PLATFORM_WIN32_NT	Win32 on Windows NT
- ****************/
+ *---------------------------------------------------*/
 
-int 
-SciWinGetPlatformId ()
+int SciWinGetPlatformId ()
 {
   return SciPlatformId;
 }
 
-
-/***************************************
+/*---------------------------------------------------
  * The WinMain function 
- ***************************************/
+ *---------------------------------------------------*/
+
+int MyWinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance,
+	 LPSTR szCmdLine, int iCmdShow)
+{
+  WinMain (hInstance,hPrevInstance, szCmdLine,iCmdShow);
+  return 0;
+}
+
+#define MAXCMDTOKENS 128
+static int my_argc = -1;
+static LPSTR my_argv[MAXCMDTOKENS];
+
+/* global var */
+int  sci_show_banner=1;
 
 #ifndef __ABSC__
 int WINAPI 
@@ -301,32 +313,35 @@ WinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance,
 	 LPSTR szCmdLine, int iCmdShow)
 #endif
 {
+#ifdef TEST 
+  char test[50];
+  int i;
+#endif
   LPSTR tail;
-  int nowin = 0, argcount = 0, lpath = 0;
+  int nowin = 0, argcount = 0, lpath = 0, pathtype=0;
   char *path = NULL;
   OSVERSIONINFO os;
-#if (defined __GNUC__) || (defined __ABSC__)	/* arguments are in szCmdline */
-#define MAXCMDTOKENS 128
-  int _argc = -1;
-  LPSTR _argv[MAXCMDTOKENS];
-  _argv[++_argc] = strtok (szCmdLine, " ");
-//  fprintf(stderr,"argv[%d] = %s\n",_argc,_argv[_argc]);
-  while (_argv[_argc] != NULL)
+  my_argc = -1;
+  my_argv[++my_argc] = strtok (szCmdLine, " ");
+  while (my_argv[my_argc] != NULL)
     {
-      _argv[++_argc] = strtok (NULL, " ");
-      //   fprintf(stderr,"argv[%d] = %s\n",_argc,_argv[_argc]);
+      my_argv[++my_argc] = strtok (NULL, " ");
     }
-#else
-/** VC++  doesn't give us _argc and _argv[] so ...   */
-#define MAXCMDTOKENS 128
-  int _argc = 0;
-  LPSTR _argv[MAXCMDTOKENS];
-  _argv[_argc] = "scilex.exe";
-  _argv[++_argc] = strtok (szCmdLine, " ");
-  while (_argv[_argc] != NULL)
-    _argv[++_argc] = strtok (NULL, " ");
-#endif
-/** __GNUC__ **/
+
+#ifdef TEST 
+  if ( szCmdLine )
+    MessageBox (NULL, szCmdLine, "pipo", MB_ICONSTOP | MB_OK);
+  else
+    MessageBox (NULL, "vide", "pipo", MB_ICONSTOP | MB_OK);
+
+  sprintf(test,"%d",my_argc);
+  MessageBox (NULL, test, "pipo", MB_ICONSTOP | MB_OK);
+
+  for (i=0; i < my_argc ; i++) {
+      sprintf(test,"%s",my_argv[i]);
+      MessageBox (NULL, test, "pipo", MB_ICONSTOP | MB_OK);
+  }
+#endif 
 
   os.dwOSVersionInfoSize = sizeof (os);
   GetVersionEx (&os);
@@ -401,24 +416,33 @@ WinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance,
   graphwin.lptw = &textwin;
   graphwin.IniFile = textwin.IniFile;
   graphwin.IniSection = textwin.IniSection;
-  argcount = _argc;
+  argcount = my_argc;
   while (argcount > 0)
     {
       argcount--;
-      if (strcmp (_argv[argcount], "-nw") == 0)
+      if (strcmp (my_argv[argcount], "-nw") == 0)
 	nowin = 1;
-      else if (strcmp (_argv[argcount], "-ns") == 0)
+      else if (strcmp (my_argv[argcount], "-ns") == 0)
 	startupf = 1;
-      else if (strcmp (_argv[argcount], "-nwni") == 0)
+      else if ( strcmp(my_argv[argcount],"-nb") == 0) { sci_show_banner = 0; }
+      else if (strcmp (my_argv[argcount], "-nwni") == 0)
 	{
 	  nowin = 1;
 	  nointeractive = 1;
 	}
-      else if (strcmp (_argv[argcount], "-f") == 0 && argcount + 1 < _argc)
+      else if (strcmp (my_argv[argcount], "-f") == 0 && argcount + 1 < my_argc)
 	{
-	  path = _argv[argcount + 1];
-	  lpath = strlen (_argv[argcount + 1]);
+	  path = my_argv[argcount + 1];
+	  lpath = strlen (my_argv[argcount + 1]);
 	}
+      else if (strcmp (my_argv[argcount], "-e") == 0 && argcount + 1 < my_argc)
+	{
+	  path = my_argv[argcount + 1];
+	  lpath = strlen (my_argv[argcount + 1]);
+	  pathtype=1;
+	}
+      else if ( strcmp(my_argv[argcount],"-mem") == 0 && argcount + 1 < my_argc)
+	{ memory = Max(atoi( my_argv[argcount + 1]),MIN_STACKSIZE );} 
     }
 #ifndef __DLL__
   /** when we don't use a dll version of the graphic library 
@@ -429,8 +453,8 @@ WinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance,
   SciEnv ();
   if (nowin == 1)
     {
-/** XXXX AllocConsole(); **/
-      sci_windows_main (nowin, &startupf, path, &lpath);
+      /** XXXX AllocConsole(); **/
+      sci_windows_main (nowin, &startupf,path,pathtype, &lpath,memory);
     }
   else
     {
@@ -439,12 +463,13 @@ WinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance,
       textwin.hIcon = LoadIcon (hInstance, "texticon");
       SetClassLong (textwin.hWndParent, GCL_HICON, (DWORD) textwin.hIcon);
       SetXsciOn ();
-/** XXX **/
+      /** XXX **/
       ShowWindow (textwin.hWndParent, SW_SHOWNORMAL);
-      sci_windows_main (nowin, &startupf, path, &lpath);
+      sci_windows_main (nowin, &startupf, path,pathtype, &lpath,memory);
     }
   return 0;
 }
+
 #define __MSC_NOC__
 #ifdef __MSC_NOC__
 /* 
@@ -466,12 +491,50 @@ MAIN__ ()
   HMODULE x = GetModuleHandle (0);
   WinMain (x, 0, GetCommandLine (), 1);
 #endif
-
   return (0);
 }
 #endif
 
 
+/* to simulate argv */
+
+void add_sci_argv(char *p)
+{
+  my_argv[++my_argc]=p;
+}
+
+/* Fortran iargc and fgetarg implemented here */
+
+int sci_iargc() {
+#ifdef TEST  
+ char test[50];
+ sprintf(test,"%d",my_argc);
+  MessageBox (NULL, test, "pipo", MB_ICONSTOP | MB_OK);
+#endif 
+  return my_argc -1 ;
+}
+
+int sci_getarg(int *n,char *s,long int ls)
+{
+  register char *t;
+  register int i;
+#ifdef TEST 
+  char test[50];
+  sprintf(test,"%d %d",my_argc,ls);
+  MessageBox (NULL, test, "pipo", MB_ICONSTOP | MB_OK);
+#endif 
+  if(*n>=0 && *n <= my_argc)
+    t = my_argv[*n];
+  else
+    t = "";
+  for(i = 0; i < ls && *t!='\0' ; ++i)
+    *s++ = *t++;
+  for( ; i<ls ; ++i)
+    *s++ = ' ';
+  return 0;
+}
+
+
 /* replacement stdio routines that use Text Window for stdin/stdout */
 /* WARNING: Do not write to stdout/stderr with functions not listed 
    in win/wtext.h */
@@ -511,6 +574,14 @@ InteractiveMode ()
   return nointeractive;
 }
 
+int 
+C2F(showlogo) ()
+{
+  return show_logo;
+}
+
+
+
 int
 MyPutCh (int ch)
 {
@@ -654,8 +725,7 @@ MyPrintF (char *fmt,...)
 
 /** Synonym for Scilab of MyPrintf **/
 
-void 
-sciprint (char *fmt,...)
+void sciprint (char *fmt,...)
 {
   int i, count, lstr;
   char buf[MAXPRINTF];
@@ -665,7 +735,46 @@ sciprint (char *fmt,...)
   /* next three lines added for diary SS */
   count = vsprintf (buf, fmt, args);
   lstr = strlen (buf);
+
+  C2F (xscion) (&i);
+  if (i == 0)
+    {
+      /*count = vfprintf(stdout, fmt, args ); */
+      printf ("%s", buf);
+
+    }
+  else
+    {
+      /*count = vsprintf(buf,fmt,args); SS */
+      TextPutS (&textwin, buf);
+    }
+  /* \r\n -> \n for diary */ 
+  if ( lstr >= 2 && buf[lstr-1]== '\n' && buf[lstr-2]== '\r') 
+    {
+      buf[lstr-2]= '\n';
+      buf[lstr-1]= '\0';
+      lstr--;
+    }
+
   C2F (diary) (buf, &lstr, 0L);
+  va_end (args);
+  /** return count; **/
+}
+
+/*---------------------------------------------------
+ * the same but no diary record 
+ *---------------------------------------------------*/
+
+void sciprint_nd (char *fmt,...)
+{
+  int i, count, lstr;
+  char buf[MAXPRINTF];
+  va_list args;
+  va_start (args, fmt);
+
+  /* next three lines added for diary SS */
+  count = vsprintf (buf, fmt, args);
+  lstr = strlen (buf);
 
   C2F (xscion) (&i);
   if (i == 0)
@@ -680,22 +789,24 @@ sciprint (char *fmt,...)
       TextPutS (&textwin, buf);
     }
   va_end (args);
-/** return count; **/
+  /** return count; **/
 }
 
-/* 
-   as sciprint but with an added first argument 
-   which is ignored (used in do_printf) 
- */
+/*---------------------------------------------------
+ * as sciprint but with an added first argument 
+ * which is ignored (used in do_printf) 
+ *---------------------------------------------------*/
 
-int 
-sciprint2 (int iv, char *fmt,...)
+int sciprint2 (int iv, char *fmt,...)
 {
-  int i, count;
-  integer lstr;
+  int i, count,lstr;
   va_list ap;
   char s_buf[1024];
   va_start (ap, fmt);
+  /* next three lines added for diary SS */
+  count = vsprintf (s_buf, fmt, ap);
+  lstr = strlen (s_buf);
+
   C2F (xscion) (&i);
   if (i == 0)
     {
@@ -703,9 +814,19 @@ sciprint2 (int iv, char *fmt,...)
     }
   else
     {
-      count = vsprintf (s_buf, fmt, ap);
+      /* count = vsprintf (s_buf, fmt, ap); SS */
       TextPutS (&textwin, s_buf);
     }
+
+  /* \r\n -> \n for diary */ 
+  if ( lstr >= 2 && s_buf[lstr-1]== '\n' && s_buf[lstr-2]== '\r') 
+    {
+      s_buf[lstr-2]= '\n';
+      s_buf[lstr-1]= '\0';
+      lstr--;
+    }
+  C2F (diary) (s_buf, &lstr, 0L);
+
   va_end (ap);
   return count;
 }
@@ -858,13 +979,8 @@ ReadKey (void)
       if (irBuffer.EventType == KEY_EVENT &&
 	  irBuffer.Event.KeyEvent.bKeyDown)
 	{
-#ifdef __GNUC__
-	  if (irBuffer.Event.KeyEvent.AsciiChar != '\0')
-	    {
-#else
 	  if (irBuffer.Event.KeyEvent.uChar.AsciiChar != '\0')
 	    {
-#endif
 	      ReadConsole (hIn, &ch, 1, &n, NULL);
 	      return ch & 0xff;
 	    }
