@@ -29,10 +29,10 @@
 #ifndef STRICT
 #define STRICT
 #endif
-#include <windows.h>
-#include <windowsx.h>
+/*#include <windows.h>
+  #include <windowsx.h>*/
 #include <string.h>
-#include "wgnuplib.h"
+/*#include "wgnuplib.h"*/
 #include "wresource.h"
 #include "wcommon.h"
 
