@@ -28,20 +28,18 @@
 #ifndef STRICT
 #define STRICT
 #endif
-#include <windows.h>
-#include <windowsx.h>
+/* #include <windows.h>
+   #include <windowsx.h>*/
 
-#ifndef __GNUC__
-#include <commdlg.h>
-#endif
 
 #ifndef __ABSC__
 #include <memory.h>
 #endif
 
-#include "wgnuplib.h"
+/*#include "wgnuplib.h"*/
 #include "wresource.h"
 #include "wcommon.h"
+#include <commdlg.h>
 
 LPPRINT prlist = NULL;
 /** list of selected printers **/
