@@ -27,18 +27,16 @@
 #ifndef STRICT
 #define STRICT
 #endif
-#include <windows.h>
+/*#include <windows.h>
 #include <windowsx.h>
 #include <commdlg.h>
-#ifndef __GNUC__
-#include <shellapi.h>
-#endif
+#include <shellapi.h>*/
 
 #include <string.h>		/* use only far items */
 #include <stdlib.h>
 #include <ctype.h>
 
-#include "wgnuplib.h"
+/*#include "wgnuplib.h"*/
 #include "wresource.h"
 #include "wcommon.h"
 
@@ -88,8 +86,6 @@ static COLORREF TextColorTable[16] =
  * message Loop 
  *********************************************/
 
-extern HWND HelpModeless;	/* the modeless Help Window */
-
 EXPORT void WINAPI
 TextMessage (void)
 {
@@ -1440,8 +1436,13 @@ WndTextProc (HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 		  cbuf = (BYTE *) GlobalLock (hGMem);
 		  while (*cbuf)
 		    {
-		      if (*cbuf != '\n')
-			SendMessage (lptw->hWndText, WM_CHAR, *cbuf, 1L);
+		      /* 
+			 if (*cbuf != '\n') {
+			SendMessage (lptw->hWndText, WM_CHAR, *cbuf , 1L);
+		      }
+		      cbuf++;
+		      */
+		      SendMessage (lptw->hWndText, WM_CHAR,*cbuf , 1L);
 		      cbuf++;
 		    }
 		  GlobalUnlock (hGMem);
@@ -1616,24 +1617,28 @@ TextGetCh (LPTW lptw)
 		   - lptw->CaretHeight - lptw->ScrollPos.y);
       ShowCaret (lptw->hWndText);
     }
+
   /** 
-    jpc 1998 : Here we must wait for an event so TextMessage 
-    cannot be called directly in order not to use 
+    Here we must wait for caracters while 
+    taking into account events. 
+    TextMessage cannot be called directly in order not to use 
     99% of the cpu time doing nothing. 
     we can use TextMessage with a Sleep or TextMessage2 
-    XXXX : must check if tck/tk works with both ?
-    **/
-  /** 
+    without a sleep but the second option does not work 
+    properly. 
+  **/
+
   do {
     Sleep(1);
     TextMessage();
   } while (!TextKBHit(lptw));
-  **/
 
+  /* 
   while (!TextKBHit (lptw))
     {
       TextMessage2 ();
     }
+  */
 
   ch = *lptw->KeyBufOut++;
   if (ch == '\r')
