@@ -1,5 +1,4 @@
-
-/* Copyright (C) 1998 Chancelier Jean-Philippe */
+/* Copyright (C) 1998-2002 Chancelier Jean-Philippe */
 /************************************
  * reading functions for scilab 
  * Scilab 1997
@@ -12,8 +11,8 @@
 #ifndef STRICT
 #define STRICT
 #endif
-#include <windows.h>
-#include "wgnuplib.h"
+/*#include <windows.h>
+  #include "wgnuplib.h"*/
 #include "wresource.h"
 #include "wcommon.h"
 #include "plot.h"
@@ -41,8 +40,15 @@ void C2F (zzledt1) (buffer, buf_size, len_line, eof, dummy1)
      long int dummy1;		/* added by FORTRAN to give buffer length */
 #endif
 {
+  int i;
   set_is_reading (TRUE);
-  read_line (save_prompt);
+  i=read_line (save_prompt);
+  if (i==-1) { /* dynamic menu canceled read SS */
+    *len_line = 0;
+    *eof = -1;
+    set_is_reading (FALSE);
+    return;
+  }
   strncpy (buffer, input_line, *buf_size);
   *len_line = strlen (buffer);
 /** fprintf(stderr,"[%s,%d]\n",buffer,*len_line); **/
@@ -66,9 +72,15 @@ void C2F (zzledt) (buffer, buf_size, len_line, eof, dummy1)
   int i;
   set_is_reading (TRUE);
   i = read_line (save_prompt);
+  if (i==-1) { /* dynamic menu canceled read SS*/
+    *len_line = 0;
+    *eof = -1;
+    set_is_reading (FALSE);
+    return;
+  }
   strncpy (buffer, input_line, *buf_size);
   *len_line = strlen (buffer);
-/** fprintf(stderr,"[%s,%d]\n",buffer,*len_line); **/
+  /** fprintf(stderr,"[%s,%d]\n",buffer,*len_line); **/
   *eof = (i == 1) ? TRUE : FALSE;
   set_is_reading (FALSE);
   return;
@@ -82,5 +94,5 @@ void C2F (setprlev) (pause)
   else if (*pause > 0)
     sprintf (save_prompt, "-%d->", *pause);
   else
-    sprintf (save_prompt, ">>", *pause);
+    sprintf (save_prompt, ">>");
 }
