@@ -43,6 +43,7 @@ extern void C2F (xscistring) __PARAMS((char *str, int *n, long int dummy));
 extern void C2F (xscimore) __PARAMS((int *n));  
 extern void Scisncr  __PARAMS((char *str));  
 extern void sciprint __PARAMS((char *fmt, ...));
+extern void sciprint_nd __PARAMS((char *fmt, ...));
 extern int sciprint2 __PARAMS((int i,char *fmt, ...));
 extern void Scistring __PARAMS((char *str));
 extern void Xputchar  __PARAMS((unsigned char c));  
@@ -54,7 +55,7 @@ extern void unparseseq  __PARAMS((register ANSI *ap, int fd));
 extern void unparseputn  __PARAMS((unsigned int n, int fd));  
 extern void unparseputc  __PARAMS((char c, int fd));  
 extern void unparsefputs  __PARAMS((register char *s, int fd));  
-extern void VTRun  __PARAMS((int nostartup));  
+extern void VTRun  __PARAMS((char *,int lstartup,int memory));  
 extern void VTInit1  __PARAMS((Widget parent));  
 extern void ShowCursor  __PARAMS((void));  
 extern void HideCursor  __PARAMS((void));  
@@ -104,9 +105,9 @@ extern int C2F(winsci) __PARAMS((char *pname, int *nos, int *idisp, char *displa
 extern void getcolordef  __PARAMS((integer *c));  
 extern void setcolordef  __PARAMS((int screenc));  
 extern Widget initColors  __PARAMS((Widget));  
-extern void main_sci  __PARAMS((int argc, char **argv));  
+extern void main_sci  __PARAMS((int argc, char **argv, char *, int,int ));  
 extern int clear_ieee_warnings  __PARAMS((void));  
-extern void ClearExit  __PARAMS((integer n));  
+extern void sci_clear_and_exit  __PARAMS((integer n));  
 extern int C2F(clearexit)  __PARAMS((int *n));  
 extern int GetBytesAvailable  __PARAMS((int fd));  
 extern int kill_process_group  __PARAMS((int pid, int sig)); 
