@@ -27,6 +27,7 @@ extern void C2F (xscistring) __PARAMS((char *str, int *n, long int dummy));
 extern void C2F (xscimore) __PARAMS((int *n));  
 extern void Scisncr  __PARAMS((char *str));  
 extern void sciprint __PARAMS((char *fmt, ...));
+extern void sciprint_nd __PARAMS((char *fmt, ...));
 extern int sciprint2 __PARAMS((int i,char *fmt, ...));
 extern void Scistring __PARAMS((char *str));
 extern void Xputchar  __PARAMS((unsigned char c));  
@@ -59,7 +60,7 @@ extern void setcolordef  __PARAMS((int screenc));
 /* extern void initColors  __PARAMS((void));   */
 extern void main_sci  __PARAMS((int argc, char **argv));  
 extern int clear_ieee_warnings  __PARAMS((void));  
-extern void ClearExit  __PARAMS((integer n));  
+extern void sci_clear_and_exit  __PARAMS((integer n));  
 extern int C2F(clearexit)  __PARAMS((int *n));  
 extern int GetBytesAvailable  __PARAMS((int fd));  
 extern int kill_process_group  __PARAMS((int pid, int sig)); 
