@@ -238,6 +238,48 @@
 "Xscilab*TransientShell.hpaned.paned.cform.Command.right:			chainLeft",
 "Xscilab*TransientShell.hpaned.paned.cform.Command.top: 			chainBottom",
 "Xscilab*TransientShell.hpaned.paned.cform.Command.bottom: 			chainBottom",
+"Xscilab*Paned*font:*-fixed-medium-r-*-*-13-*-*-*-*-*-iso8859-*",
+"Xscilab*Paned.x:						147",
+"Xscilab*Paned.y:						20",
+"Xscilab*Paned.allowShellResize:				True",
+"Xscilab*Paned.hpaned.orientation:				horizontal",
+"Xscilab*Paned.hpaned.paned.showGrip:				False",
+"Xscilab*Paned.hpaned.paned.showGrip:				False",
+"Xscilab*Paned.hpaned.paned.max:				800",
+"Xscilab*Paned.hpaned.paned.min:				100",
+"Xscilab*Paned.hpaned.paned.orientation:			vertical",
+"Xscilab*Paned.hpaned.paned.*showGrip:				False",
+"Xscilab*Paned.hpaned.paned.internalBorderWidth:		1",
+"Xscilab*Paned.hpaned.paned.Viewport.allowVert:			True",
+"Xscilab*Paned.hpaned.paned.Viewport.allowHoriz:		True",
+"Xscilab*Paned.hpaned.paned.Viewport.forceBars:			False",
+"Xscilab*Paned.hpaned.paned.Viewport.vertical.width:		10",
+"Xscilab*Paned.hpaned.paned.Viewport.horizontal.height:		10",
+"Xscilab*Paned.hpaned.paned.Viewport.borderWidth:		10",
+"Xscilab*Paned.hpaned.paned.Viewport.Label.borderWidth:		0",
+"Xscilab*Paned.hpaned.paned.Viewport.Label.internalWidth: 	10",
+"Xscilab*Paned.hpaned.paned.Viewport.Label.internalHeight:	10",
+"Xscilab*Paned.hpaned.paned.Viewport.List.internalWidth:	15",
+"Xscilab*Paned.hpaned.paned.Viewport.List.internalHeight:	10",
+"Xscilab*Paned.hpaned.paned.Viewport.List.verticalList:		True",
+"Xscilab*Paned.hpaned.paned.Viewport.List.defaultColumns:	1",
+"Xscilab*Paned.hpaned.paned.Viewport.List.forceColumns:		True",
+"Xscilab*Paned.hpaned.paned.Viewport.List.maxSelectable: 	1",
+"Xscilab*Paned.hpaned.paned.Viewport.List.rowSpacing: 		2",
+"Xscilab*Paned.hpaned.paned*Text.bottomMargin:			7",
+"Xscilab*Paned.hpaned.paned*Text.leftMargin:			7",
+"Xscilab*Paned.hpaned.paned*Text*Scrollbar.thickness: 		7",
+"Xscilab*Paned.hpaned.paned*Text.resizable: 				True",
+"Xscilab*Paned.hpaned.paned*Text*editType: 				edit",
+"Xscilab*Paned.hpaned.paned*Text.scrollVertical: 			whenNeeded",
+"Xscilab*Paned.hpaned.paned*Text.scrollHorizontal: 			whenNeeded",
+"Xscilab*Paned.hpaned.paned*Text.borderWidth: 				1",
+"Xscilab*Paned.hpaned.paned.cform.min:					30",
+"Xscilab*Paned.hpaned.paned.cform.skipAdjust:				True",
+"Xscilab*Paned.hpaned.paned.cform.Command.left:			chainLeft",
+"Xscilab*Paned.hpaned.paned.cform.Command.right:			chainLeft",
+"Xscilab*Paned.hpaned.paned.cform.Command.top: 			chainBottom",
+"Xscilab*Paned.hpaned.paned.cform.Command.bottom: 			chainBottom",
 "Xscilab*messageShell.title:					Scilab Message Panel",
 "Xscilab*messageShell.hpaned.paned.labelviewport.max:			500",
 "Xscilab*messageShell.hpaned.paned.cform.fromVert:				labelviewport",
@@ -343,7 +385,7 @@
 "Xscilab*scigForm.scigmForm.File.fromVert:scigraphicinfo",
 "Xscilab*scigForm.scigmForm.File.fromHoriz:Panner",
 "Xscilab*scigForm.scigmForm.File.Label:File",
-"Xscilab*scigForm.scigmForm.Zoom.label:2D Zoom",
+"Xscilab*scigForm.scigmForm.Zoom.label:Zoom",
 "Xscilab*scigForm.scigmForm.Zoom.fromHoriz:File",
 "Xscilab*scigForm.scigmForm.Zoom.fromVert:scigraphicinfo",
 "Xscilab*scigForm.scigmForm.UnZoom.label:UnZoom",
