@@ -1,4 +1,9 @@
-/* Copyright (C) 1998 Chancelier Jean-Philippe */
+/*------------------------------------------------------------------------
+ *    X11 interface 
+ *    Copyright (C) 1998-2001 Enpc/Jean-Philippe Chancelier
+ *    jpc@cermics.enpc.fr 
+ --------------------------------------------------------------------------*/
+
 #include <stdio.h>			/* For the Syntax message */
 #include <signal.h>
 
@@ -20,16 +25,17 @@
 #include <X11/Xaw/Viewport.h>
 #include <X11/Xaw/Panner.h>	
 #include <X11/IntrinsicP.h>
-#include <X11/Xaw/ViewportP.h>
+#include <X11/Xaw3d/ViewportP.h>
+
 
 #include <string.h>
-#include <malloc.h>
 /** getpid **/
 #ifdef __STDC__
 #include <stdlib.h>
 #include <sys/types.h>
 #include <unistd.h>
 #else 
+#include <malloc.h>
 extern char * getenv();
 extern int getpid();
 #endif
@@ -39,13 +45,14 @@ extern int getpid();
 #include "../menusX/men_scilab.h"
 #include "All-extern.h"
 #include "All-extern-x1.h"
-#include "../graphics/periX11-bcg.h"
+#include "../graphics/bcg.h"
 
 extern Widget initColors  __PARAMS((Widget));  
 extern Window GetBGWindowNumber __PARAMS((int));
 extern void DisplayInit __PARAMS((char *string,Display **dpy,Widget *toplevel));
 extern void ChangeBandF __PARAMS((int win_num,Pixel fg, Pixel bg));
 extern integer F2C(fbutn) __PARAMS((char *,integer*,integer*));
+extern void __PARAMS(DeleteObjs(int win_num)); /* NG */
 struct BCG *GetWindowXgcNumber __PARAMS((int));
 int demo_menu_activate=0; /* add a demo menu in the graphic Window */
 
@@ -576,8 +583,8 @@ void GViewportResize(ScilabXgc,width,height)
        * the drawbox can be bigger than the popup if 
        * we are comming back from a ScilabXgc->CurResizeStatus==0 state 
        */
-      clwidth = Width  + Max(0,clwidth-cwidth);
-      clheight= Height + Max(0,clheight-cheight);
+      clwidth = Width  + Max(0,(int)clwidth - (int)cwidth);
+      clheight= Height + Max(0,(int)clheight - (int)cheight);
       iargs = 0;
       XtSetArg (args[iargs], XtNwidth, clwidth ); iargs++;
       XtSetArg (args[iargs], XtNheight,clheight); iargs++;
@@ -632,6 +639,12 @@ EventProc(widget, number, event)
      XEvent *event;
 {
   XEvent event2;
+
+  char buf[100];
+  int cent=100;
+  KeySym keysym;
+  XComposeStatus compose_status = {NULL, 0};
+
   /* sciprint("Je suis ds EventProc\n"); */
   switch (event->type) 
     {
@@ -657,6 +670,20 @@ EventProc(widget, number, event)
 		     event->xbutton.y,
 		     event->xbutton.button-1,0,0);
       break;
+    case  KeyPress :
+      XLookupString((XKeyEvent *)&(event->xkey), buf, 
+		    cent, &keysym,&compose_status);
+      PushClickQueue((int) number,event->xkey.x,
+		     event->xkey.y,(int)keysym,0,0);
+
+      break;
+      /*    case  KeyRelease :
+      XLookupString((XKeyEvent *)&(event->xkey), buf, 
+		    cent, &keysym,&compose_status);
+      PushClickQueue((int) number,event->xkey.x,
+		     event->xkey.y,-(int)keysym,0,0);
+
+		     break;*/
     default:
       /* printf("XXXJe suis ds EventProc defaut, fenetre %d\r\n",(integer) number);*/
       return(0);
@@ -674,10 +701,26 @@ EventProc(widget, number, event)
  * he want the queue to be used 
  *********************************************/
 
-int scig_click_handler_none (win,x,y,ibut,motion,release)int win,x,y,ibut,motion,release;
+int scig_click_handler_none (int win,int x,int y,int ibut,int motion,int release)
 {return 0;};
 
-static Scig_click_handler scig_click_handler = scig_click_handler_none;
+int scig_click_handler_sci (int win,int x,int y,int ibut,int motion,int release)
+
+{
+  static char buf[256];
+  struct BCG *SciGc;
+
+  SciGc = GetWindowXgcNumber(win);
+  if (strlen(SciGc->EventHandler)!=0) {
+    sprintf(buf,"%s(%d,%d,%d,%d)",SciGc->EventHandler,win,x,y,ibut);
+    StoreCommand(buf);
+    return 1;}
+  else
+    return 0;
+};
+
+static Scig_click_handler scig_click_handler = scig_click_handler_sci;
+/*static Scig_click_handler scig_click_handler = scig_click_handler_none;*/
 
 Scig_click_handler set_scig_click_handler(f) 
      Scig_click_handler f;
@@ -689,7 +732,8 @@ Scig_click_handler set_scig_click_handler(f)
 
 void reset_scig_click_handler() 
 {
-  scig_click_handler = scig_click_handler_none;
+  /*  scig_click_handler = scig_click_handler_none;*/
+  scig_click_handler = scig_click_handler_sci;
 }
 
 
@@ -827,7 +871,10 @@ EventProc1(widget, number, event)
       if ( event1->count == 0) 
 	{
 	  FDEBUG((stderr,"Expose--> scig_replay or wshow \r\n")); 
-	  scig_expose(win_num);
+	  if (version_flag() == 0) /* NG */
+	    sciRedrawF(&win_num); /* NG */
+	  else /* NG */
+	    scig_expose(win_num);
 	  ignore_expose(widget,&event2);
 	}
       break;
@@ -837,7 +884,10 @@ EventProc1(widget, number, event)
       break;
     case ConfigureNotify :
       FDEBUG((stderr,"XXX Configure\n"));
-      scig_replay(win_num);
+      if (version_flag() == 0) /* NG */
+       sciRedrawF(&win_num); /* NG */
+      else /* NG */
+	scig_replay(win_num);
       /** I ignore the following expose events **/
       ignore_expose(widget,&event2);
       break; 
@@ -898,8 +948,7 @@ Select(w, number, client_data)
  * deleted a graphic window ( used in xclick_any)
  */
 
-void SendSGDeleteMessage(win_num)
-     int win_num;
+static void SendSGDeleteMessage(int win_num)
 {
   Window Win;
   Widget toplevel;
@@ -921,7 +970,20 @@ void SendSGDeleteMessage(win_num)
 
 void scig_deletegwin_handler_none (win)int win; {};
 
-static Scig_deletegwin_handler scig_deletegwin_handler = scig_deletegwin_handler_none;
+void scig_deletegwin_handler_sci (int win)
+
+{
+  static char buf[256];
+  struct BCG *SciGc;
+
+  SciGc = GetWindowXgcNumber(win);
+  if (strlen(SciGc->EventHandler)!=0) {
+    sprintf(buf,"%s(%d,0,0,-1000)",SciGc->EventHandler,win);
+    StoreCommand(buf);
+    }
+};
+static Scig_deletegwin_handler scig_deletegwin_handler = scig_deletegwin_handler_sci;
+/*static Scig_deletegwin_handler scig_deletegwin_handler = scig_deletegwin_handler_none;*/
 
 Scig_deletegwin_handler set_scig_deletegwin_handler(f) 
      Scig_deletegwin_handler f;
@@ -933,14 +995,24 @@ Scig_deletegwin_handler set_scig_deletegwin_handler(f)
 
 void reset_scig_deletegwin_handler() 
 {
-  scig_deletegwin_handler = scig_deletegwin_handler_none;
+/*  scig_deletegwin_handler = scig_deletegwin_handler_none;*/
+  scig_deletegwin_handler = scig_deletegwin_handler_sci;
 }
 
 
-/*
+/*------------------------------------------------------------------
  * Delete Window 
- */
+ *------------------------------------------------------------------*/
 
+/* this is used to prevent the user from destroying a graphic window 
+ * when acquiring for example a zoom rectangle (see Plo2dEch 
+ */
+static int sci_graphic_protect = 0;
+void   set_delete_win_mode(void) {  sci_graphic_protect = 0 ;}
+extern void   set_no_delete_win_mode(void)  {  sci_graphic_protect = 1 ;}
+
+extern int  get_xclick_client_message_flag(void);
+ 
 static void
 Delete(w, number, client_data)
      Widget w;
@@ -948,12 +1020,25 @@ Delete(w, number, client_data)
      XtPointer client_data;
 {
   integer win_num = (integer) number ;
-  /** Warning : this is not valid here dpy = XtDisplay(w); **/
-  SendSGDeleteMessage(win_num);
+  if (  sci_graphic_protect == 1 )
+    {
+      wininfo("Cannot destroy window while acquiring zoom rectangle ");
+      return;
+    }
+  if ( get_xclick_client_message_flag() == 1 ) 
+    {
+      /* the client message is only used while waiting for 
+       * a mouse click 
+       */
+      SendSGDeleteMessage(win_num);
+    }
   /** Delete the graphic window **/
   Efface((Widget) 0,(XtPointer) number, (XtPointer) 0);
-  DeleteSGWin(win_num);
+  if (version_flag() == 0) DeleteObjs(win_num); 
   scig_deletegwin_handler(win_num);
+  DeleteSGWin(win_num);
+
+
 }
 
 /* for Fortran call */
@@ -1039,6 +1124,11 @@ SavePs(w, number, client_data)
 	  /** Gif file **/
 	  scig_tops(win_num,colored,file,"GIF");
 	}
+      else if (strcmp(printer,"PPM")==0)
+	{
+	  /** PPM file **/
+	  scig_tops(win_num,colored,file,"PPM");
+	}
       if ( strcmp(printer,"Postscript No Preamble") != 0)
 	{
 	  sprintf(bufname,"$SCI/bin/scilab -%s %s %s",
@@ -1171,14 +1261,14 @@ Rot3D(w, number, client_data)
   XtSetArg(args[iargs], XtNsensitive, False); iargs++;
   XtSetValues(w, args, iargs);
   SetUnsetMenu(&win_num,"UnZoom",&ne,False);
-  SetUnsetMenu(&win_num,"2D Zoom",&ne,False);
+  SetUnsetMenu(&win_num,"Zoom",&ne,False);
   SetUnsetMenu(&win_num,"File",&ne,False);
   scig_3drot(win_num);
   iargs = 0;
   XtSetArg(args[iargs], XtNsensitive,True); iargs++;
   XtSetValues(w, args, iargs);
   SetUnsetMenu(&win_num,"UnZoom",&ne,True);
-  SetUnsetMenu(&win_num,"2D Zoom",&ne,True);
+  SetUnsetMenu(&win_num,"Zoom",&ne,True);
   SetUnsetMenu(&win_num,"File",&ne,True);
 }
 
@@ -1355,7 +1445,6 @@ KillButton(w, client_data, call_data)
     FREE(datas->fname);
   FREE(datas);
 }
-
 /****************************************************
  * callBack associated to a user defined menu 
  ****************************************************/
@@ -1381,7 +1470,20 @@ SelMenu(w, client_data, call_data)
 	}
       StoreCommand(buf);
     }
-  else 
+  else if (datas->type == 2) 
+    { 
+      /* Interpreted mode : we store the action on a queue */
+      if ( datas->win_num < 0 ) 
+	{
+	  sprintf(buf,"%s(%d)",datas->fname,datas->entry+1);
+	}
+      else 
+	{
+	  sprintf(buf,"%s(%d,%d)",datas->fname,datas->entry+1,datas->win_num);
+	}
+      StoreCommand(buf);
+    }
+  else
     { 
       /* hard coded mode */
       int rep ;
@@ -1391,6 +1493,7 @@ SelMenu(w, client_data, call_data)
     }
 }
 
+
 /****************************************************
  *Delete the button named button_name in window 
  * number win_num
@@ -1734,3 +1837,20 @@ static int GetChilds(win_num,nc,wL,outer,name,name_pos)
   return TRUE;
 }
 
+
+
+void C2F(seteventhandler)(win_num,name,ierr)
+     int *win_num;
+     int *ierr;
+     char *name;
+{  
+  struct BCG *SciGc;
+
+  /*ButtonPressMask|PointerMotionMask|ButtonReleaseMask|KeyPressMask */
+  *ierr = 0;
+  SciGc = GetWindowXgcNumber(*win_num);
+  if ( SciGc ==  NULL ) {*ierr=1;return;}
+  strncpy(SciGc->EventHandler,name,24);
+}
+
+
