@@ -39,7 +39,6 @@
 #endif
 
 #include "jpc_global.h"
-#include "../sun/h_help.h" 
 #include "../sun/Sun.h" 
 #include "All-extern-x1.h" 
 #include "../graphics/Graphics.h" 
@@ -62,7 +61,6 @@ static char	savedCommand[LINESIZ] = "";
 static void DoIt  __PARAMS((Widget w, XtPointer command, XtPointer ));  
 static void Do_Kill  __PARAMS((Widget w, XtPointer command, XtPointer ));  
 static void Do_Stop  __PARAMS((Widget w, XtPointer command, XtPointer ));  
-static void Do_Help  __PARAMS((Widget w, XtPointer command, XtPointer ));  
 static void info_handler  __PARAMS((Widget w, caddr_t , XEvent *));  
 static void AddInfoHandler  __PARAMS((Widget , char *));  
 static void CreateButtons  __PARAMS((Widget parent));  
@@ -99,7 +97,7 @@ static void Do_Kill (w, command, call_data)
     XtPointer command;
     XtPointer call_data;
 {
-  ClearExit(1);
+ sci_clear_and_exit(1);
 }
 
 static void Do_Stop (w, command, call_data)
@@ -112,22 +110,6 @@ static void Do_Stop (w, command, call_data)
   if (get_is_reading()) write_scilab("\n");
 }
 
-extern void   popupHelpPanel();
-
-static void Do_Help (w, command, call_data)
-    Widget w;
-    XtPointer command;
-    XtPointer call_data;
-{
-  static int status=0;
-  if ( status == 0) 
-    {
-      initHelpActions(app_con); status=1;
-    };
-  popupHelpPanel();
-  /* status=system("$SCI/bin/scilab -xhelp"); */
-}
-
 
 /* for all file operations */
 void FileG1(w, closure, call_data)
@@ -252,9 +234,6 @@ static void CreateButtons (parent)
   AddInfoHandler(menuentry,"Exec demos");
 
   CreateFormWithButtons(parent);
-
-  menuentry = AddButton (parent, "Help", Do_Help," ");
-  AddInfoHandler(menuentry,"Open Help Window");
 }
 
 
