@@ -8,9 +8,9 @@
  *	Digital Equipment Corporation
  *	treese@crl.dec.com
  *
- *	$Source: /trx/u2/treese/Src/Xdir.rel/RCS/xdir.c,v $
+ *	$Source: /usr/local/cvsroot/scilab2.7/routines/xsci/wf_w_dir.c,v $
  *
- *	COPYRIGHT 1990  DIGITAL EQUIPMENT CORPORATION, MAYNARD, MASSACHUSETTS
+ *	COPYRIGHT 1990  DIGITAL EQUIPMENT CORPORATION, MAlYNARD, MASSACHUSETTS
  *	  ALL RIGHTS RESERVED.
  *
  * THE INFORMATION IN THIS SOFTWARE IS SUBJECT TO CHANGE WITHOUT NOTICE AND
@@ -55,7 +55,9 @@
 #include <sys/dir.h>
 #endif
 
-#if !defined(freebsd)
+#ifdef __STDC__ 
+#include <stdlib.h>
+#else 
 #include <malloc.h>
 #endif
 
