@@ -24,7 +24,11 @@ char     cur_filename[FSIZE];
 #include "wf_w_util.h"
 #include "wf_w_setup.h"
 
+#ifdef __STDC__ 
+#include <stdlib.h> 
+#else 
 #include <malloc.h>
+#endif 
 
 #include "../machine.h"
 #include "All-extern.h"
@@ -182,10 +186,10 @@ void ok_prep(filemask,dirname,title,flag,err)
 {
   char newdir[PATH_MAX];
   if (file_popup) {
-/*    FirstArg(XtNtitle, title);
-    SetValues(file_popup);	*/
-      FirstArg(XtNlabel, title);
-      SetValues(labelW);
+    /*    FirstArg(XtNtitle, title);
+	  SetValues(file_popup);	*/
+    FirstArg(XtNlabel, title);
+    SetValues(labelW);
   }
 
   /* Change Accelerators to ok */
