@@ -27,8 +27,8 @@
  */
 
 /* charproc.c */
-#ifdef sgi
-#define __STDC__
+#if defined  sgi && ! defined  __STDC__
+#define __STDC__ 1  
 #endif
 
 #include "../machine.h"
@@ -59,7 +59,12 @@
 #endif
 
 #include <string.h> /* in case of dmalloc */ 
-#include <malloc.h>  /* in case of dmalloc */ 
+#ifdef __STDC__
+#include <stdlib.h>
+#else
+#include <malloc.h>
+#endif
+
 
 #ifdef WITH_TK
 #include "../tksci/tksci.h"
@@ -605,11 +610,10 @@ void Scistring(str)
 #include <varargs.h>
 #endif 
 
-/* 
-  Fonction de type print(format,args,....) 
-  qui imprime dans la fenetre Scilab
-*/
-
+/*---------------------------------------------------
+ * functions similar to print(format,arg1,...,argn) 
+ * but with output redirected to scilab window 
+ *-------------------------------------------------*/
 
 #ifdef __STDC__ 
 void  sciprint(char *fmt,...) 
@@ -633,7 +637,6 @@ void sciprint(va_alist) va_dcl
   /* next three lines added for diary SS*/
   (void ) vsprintf(s_buf, fmt, ap );
   lstr=strlen(s_buf);
-  C2F(diary)(s_buf,&lstr,0L);
 
   C2F(xscion)(&i);
   if (i == 0) 
@@ -642,10 +645,53 @@ void sciprint(va_alist) va_dcl
     }
   else 
     {
-      /*(void ) vsprintf(s_buf, fmt, ap );  SS
-	lstr=strlen(s_buf);*/
       C2F(xscisncr)(s_buf,&lstr,0L);
+    }
+  /* \r\n -> \n for diary */ 
+  if ( lstr >= 2 && s_buf[lstr-1]== '\n' && s_buf[lstr-2]== '\r') 
+    {
+      s_buf[lstr-2]= '\n';
+      s_buf[lstr-1]= '\0';
+      lstr--;
+    }
+  C2F(diary)(s_buf,&lstr,0L);
 
+  va_end(ap);
+}
+
+/* almost the same but no diary record */ 
+/* usefull for automatic tests */ 
+
+#ifdef __STDC__ 
+void  sciprint_nd(char *fmt,...) 
+#else 
+/*VARARGS0*/
+void sciprint_nd(va_alist) va_dcl
+#endif 
+{
+  int i;
+  integer lstr;
+  va_list ap;
+  char s_buf[1024];
+#ifdef __STDC__
+  va_start(ap,fmt);
+#else
+  char *fmt;
+  va_start(ap);
+  fmt = va_arg(ap, char *);
+#endif
+
+  (void ) vsprintf(s_buf, fmt, ap );
+  lstr=strlen(s_buf);
+
+  C2F(xscion)(&i);
+  if (i == 0) 
+    {
+      printf("%s",s_buf); 
+    }
+  else 
+    {
+      C2F(xscisncr)(s_buf,&lstr,0L);
     }
   va_end(ap);
 }
@@ -675,6 +721,10 @@ int sciprint2(va_alist) va_dcl
   iv = va_arg(ap,int);
   fmt = va_arg(ap, char *);
 #endif
+  /* next three lines added for diary SS*/
+  (void ) vsprintf(s_buf, fmt, ap );
+  lstr=strlen(s_buf);
+
   C2F(xscion)(&i);
   if (i == 0) 
     {
@@ -682,10 +732,18 @@ int sciprint2(va_alist) va_dcl
     }
   else 
     {
-      retval= vsprintf(s_buf, fmt, ap );
-      lstr=strlen(s_buf);
+      /* Next two lines suppressed:see above SS
+	 retval= vsprintf(s_buf, fmt, ap );*/
       C2F(xscisncr)(s_buf,&lstr,0L);
     }
+  /* \r\n -> \n for diary */ 
+  if ( lstr >= 2 && s_buf[lstr-1]== '\n' && s_buf[lstr-2]== '\r') 
+    {
+      s_buf[lstr-2]= '\n';
+      s_buf[lstr-1]= '\0';
+      lstr--;
+    }
+  C2F(diary)(s_buf,&lstr,0L);
   va_end(ap);
   return retval;
 }
@@ -1992,7 +2050,7 @@ void unparseputc(c, fd)
   int fd;
 {
   char buf[2];
-  register i = 1;
+  register int i = 1;
   extern XtermWidget term;
 
   if ((buf[0] = c) == '\r' && (term->flags & LINEFEED))
@@ -2088,9 +2146,9 @@ void SwitchBufPtrs(screen)
 
 #define PROMPT "==>"
 
-void VTRun(nostartup)
-     int nostartup;
+void VTRun(char *startup, int lstartup,int memory)
 {
+  static int ini=-1, ierr =0 ;
   register TScreen *screen = &term->screen;
   if (!screen->Vshow) set_vt_visibility(TRUE);
   if (screen->allbuf == NULL)  VTallocbuf();
@@ -2100,10 +2158,11 @@ void VTRun(nostartup)
 
   bcnt = 0;
   bptr = buffer;
-  {
-    /** An interaction Loop */
-    F2C(scilab)(&nostartup);
-  }
+
+  C2F(inisci)(&ini, &memory, &ierr);
+  if (ierr > 0) sci_exit(1) ;
+  /** An interaction Loop for scilab interpreter */
+  C2F(scirun)(startup,strlen(startup));
   HideCursor();
   screen->cursor_set = OFF;
 }
@@ -2358,7 +2417,7 @@ static void VTRealize(w, valuemask, values)
   {
     fprintf(stderr, "%s:  unable to locate a suitable font\n",
 	    xterm_name);
-    ClearExit(1);
+   sci_clear_and_exit(1);
   }
   /* making cursor */
   if (!screen->pointer_cursor)
