@@ -33,32 +33,32 @@ Arg menuArgs[2] = {{ XtNleftBitmap, (XtArgVal) 0 },
 		   { XtNsensitive, (XtArgVal) 0 }};
 
 
-static int domenu  _PARAMS((Widget w, XEvent *, String *, Cardinal *));  
-static Widget create_menu  _PARAMS((XtermWidget xtw, Widget toplevelw, 
+static int domenu  __PARAMS((Widget w, XEvent *, String *, Cardinal *));  
+static Widget create_menu  __PARAMS((XtermWidget xtw, Widget toplevelw, 
 				    char *, struct _MenuEntry *, Cardinal));  
-static void handle_send_signal  _PARAMS((Widget gw, int sig));  
-static void do_visualbell  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_redraw  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_quit  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_scrollbar  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_jumpscroll  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_reversevideo  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_autowrap  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_reversewrap  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_autolinefeed  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_appcursor  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_appkeypad  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_scrollkey  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_scrollttyoutput  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_allow132  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_cursesemul  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_marginbell  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_altscreen  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_softreset  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_hardreset  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_clearsavedlines  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void do_vtfont  _PARAMS((Widget gw, caddr_t , caddr_t));  
-static void handle_toggle _PARAMS(( void(*proc)(),int , String *, 
+static void handle_send_signal  __PARAMS((Widget gw, int sig));  
+static void do_visualbell  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_redraw  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_quit  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_scrollbar  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_jumpscroll  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_reversevideo  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_autowrap  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_reversewrap  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_autolinefeed  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_appcursor  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_appkeypad  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_scrollkey  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_scrollttyoutput  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_allow132  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_cursesemul  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_marginbell  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_altscreen  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_softreset  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_hardreset  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_clearsavedlines  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void do_vtfont  __PARAMS((Widget gw, caddr_t , caddr_t));  
+static void handle_toggle __PARAMS(( void(*proc)(),int , String *, 
 				   Cardinal , Widget w, caddr_t , caddr_t));  
 
 
