@@ -509,10 +509,10 @@ void Panic(s, a)
 
 /* #include "wf_fig.h" */ /** for sys_errlist **/
 #ifndef linux 
-#if !defined(__bsdi__) && !defined(__NetBSD__)
+#if !defined(__bsdi__) && !defined(__NetBSD__) && !defined(__APPLE__)
 extern int	errno;
 extern int	sys_nerr;
-#if (! (defined(BSD) && (BSD >= 199306))) && !defined(freebsd)
+#if (! (defined(BSD) && (BSD >= 199306))) && !defined(freebsd)  && !defined(__APPLE__)
 extern char    *sys_errlist[];
 #endif
 #endif
@@ -523,7 +523,6 @@ static char UE[]="unknown error";
 char *SysErrorMsg(n)
   int n;
 {
-  extern int sys_nerr;
   return ((n >= 0 && n < sys_nerr) ? sys_errlist[n] : UE );
 }
 
@@ -563,7 +562,7 @@ void Cleanup(code)
   {
     (void) kill_process_group((int) screen->pid, SIGHUP);
   }
-  ClearExit(code);
+ sci_clear_and_exit(code);
 }
 
 
@@ -594,7 +593,7 @@ void xerror(d, ev)
 {
   fprintf(stderr, "%s:  warning, error event receieved:\n", xterm_name);
   (void) XmuPrintDefaultErrorMessage(d, ev, stderr);
-  ClearExit(ERROR_XERROR);
+ sci_clear_and_exit(ERROR_XERROR);
 }
 
 /*ARGSUSED*/
@@ -606,7 +605,7 @@ void xioerror(dpy)
 	    "%s:  fatal IO error %d (%s) or KillClient on X server \"%s\"\r\n",
 	    xterm_name, errno, SysErrorMsg(errno),
 	    DisplayString(dpy));
-  ClearExit(ERROR_XIOERROR);
+ sci_clear_and_exit(ERROR_XIOERROR);
 }
 
 /**
