@@ -29,18 +29,24 @@
 
 #include <stdio.h>
 #include <ctype.h>
+#ifdef __STDC__
+#include <stdlib.h>
+#else 
 #include <malloc.h>
-#include <X11/Xatom.h>
+#endif
 
+#include <X11/Xatom.h>
 #include <X11/StringDefs.h>
 #include <X11/Shell.h>
-
 #include <X11/Xaw/Scrollbar.h>
 
 #include "x_data.h"
 #include "x_error.h"
 #include "x_menu.h"
 
+#include "../machine.h"
+#include "All-extern-x.h"
+
 /* Event handlers */
 
 static void ScrollTextTo();
@@ -202,7 +208,7 @@ static void RealizeScrollBar (sbw, screen)
 }
 
 
-ScrollBarReverseVideo(scrollWidget)
+void ScrollBarReverseVideo(scrollWidget)
 	register Widget scrollWidget;
 {
 	Arg args[4];
@@ -228,7 +234,7 @@ ScrollBarReverseVideo(scrollWidget)
 
 
 
-ScrollBarDrawThumb(scrollWidget)
+void ScrollBarDrawThumb(scrollWidget)
 	register Widget scrollWidget;
 {
 	register TScreen *screen = &term->screen;
@@ -244,7 +250,7 @@ ScrollBarDrawThumb(scrollWidget)
 	
 }
 
-ResizeScrollBar(scrollWidget, x, y, height)
+void ResizeScrollBar(scrollWidget, x, y, height)
 	register Widget scrollWidget;
 	int x, y;
 	unsigned height;
@@ -254,7 +260,7 @@ ResizeScrollBar(scrollWidget, x, y, height)
 	ScrollBarDrawThumb(scrollWidget);
 }
 
-WindowScroll(screen, top)
+void WindowScroll(screen, top)
 	register TScreen *screen;
 	int top;
 {
@@ -302,7 +308,7 @@ WindowScroll(screen, top)
 }
 
 
-ScrollBarOn (xw, init, doalloc)
+void ScrollBarOn (xw, init, doalloc)
     XtermWidget xw;
     int init, doalloc;
 {
@@ -367,7 +373,7 @@ ScrollBarOn (xw, init, doalloc)
 	}
 }
 
-ScrollBarOff(screen)
+void ScrollBarOff(screen)
 	register TScreen *screen;
 {
 	if(!screen->scrollbar)
@@ -458,7 +464,7 @@ static int params_to_pixels (screen, params, n)
     String *params;
     int n;
 {
-    register mult = 1;
+    register int mult = 1;
     register char *s;
 
     switch (n > 2 ? 2 : n) {
