@@ -27,11 +27,14 @@
 
 /* util.c */
 
-#include "x_ptyx.h"
+#include "x_ptyxP.h"
 #include "x_data.h"
 #include "x_error.h"
 #include "x_menu.h"
 
+#include "../machine.h"
+#include "All-extern-x.h"
+
 #include <stdio.h>
 
 static void horizontal_copy_area();
@@ -40,7 +43,8 @@ static void vertical_copy_area();
 /*
  * These routines are used for the jump scroll feature
  */
-FlushScroll(screen)
+
+void FlushScroll(screen)
 register TScreen *screen;
 {
 	register int i;
@@ -121,7 +125,8 @@ register TScreen *screen;
 	}
 }
 
-AddToRefresh(screen)
+
+int AddToRefresh(screen)
 register TScreen *screen;
 {
 	register int amount = screen->refresh_amt;
@@ -155,7 +160,7 @@ register TScreen *screen;
  * All done within the scrolling region, of course. 
  * requires: amount > 0
  */
-Scroll(screen, amount)
+void Scroll(screen, amount)
 register TScreen *screen;
 register int amount;
 {
@@ -258,7 +263,7 @@ register int amount;
  * All done within the scrolling region, of course.
  * Requires: amount > 0
  */
-RevScroll(screen, amount)
+void RevScroll(screen, amount)
 register TScreen *screen;
 register int amount;
 {
@@ -326,7 +331,7 @@ register int amount;
  * inserts n blank lines at the cursor's position.  Lines above the
  * bottom margin are lost.
  */
-InsertLine (screen, n)
+void InsertLine (screen, n)
 register TScreen *screen;
 register int n;
 {
@@ -387,7 +392,8 @@ register int n;
  * If cursor not in scrolling region, returns.  Else, deletes n lines
  * at the cursor's position, lines added at bottom margin are blank.
  */
-DeleteLine(screen, n)
+
+void DeleteLine(screen, n)
 register TScreen *screen;
 register int n;
 {
@@ -467,7 +473,8 @@ register int n;
 /*
  * Insert n blanks at the cursor's position, no wraparound
  */
-InsertChar (screen, n)
+
+void InsertChar (screen, n)
     register TScreen *screen;
     register int n;
 {
@@ -510,7 +517,7 @@ InsertChar (screen, n)
 /*
  * Deletes n chars at the cursor's position, no wraparound.
  */
-DeleteChar (screen, n)
+void DeleteChar (screen, n)
     register TScreen *screen;
     register int	n;
 {
@@ -536,8 +543,8 @@ DeleteChar (screen, n)
 		     screen->reverseGC,
 		     screen->border + screen->scrollbar
 		       + Width(screen) - n*FontWidth(screen),
-		     CursorY (screen, screen->cur_row), n * FontWidth(screen),
-		     FontHeight(screen));
+		     CursorY (screen, screen->cur_row),(unsigned) n * FontWidth(screen),
+		     (unsigned) FontHeight(screen));
 	    }
 	}
 	/* adjust screen->buf */
@@ -549,12 +556,13 @@ DeleteChar (screen, n)
 /*
  * Clear from cursor position to beginning of display, inclusive.
  */
-ClearAbove (screen)
-register TScreen *screen;
-{
-	register top, height;
 
-	if(screen->cursor_state)
+void ClearAbove (screen)
+     register TScreen *screen;
+{
+  register int top, height;
+
+  if(screen->cursor_state)
 		HideCursor();
 	if((top = -screen->topline) <= screen->max_row) {
 		if(screen->scroll_amt)
@@ -565,7 +573,7 @@ register TScreen *screen;
 			XClearArea(screen->display, TextWindow(screen),
 			 screen->border + screen->scrollbar, top *
 			 FontHeight(screen) + screen->border,
-			 Width(screen), height * FontHeight(screen), FALSE);
+			 (unsigned)Width(screen), (unsigned)height * FontHeight(screen), FALSE);
 
 		if(screen->cur_row - screen->topline <= screen->max_row)
 			ClearLeft(screen);
@@ -576,10 +584,11 @@ register TScreen *screen;
 /*
  * Clear from cursor position to end of display, inclusive.
  */
-ClearBelow (screen)
+
+void ClearBelow (screen)
 register TScreen *screen;
 {
-	register top;
+  register int top;
 
 	ClearRight(screen);
 	if((top = screen->cur_row - screen->topline) <= screen->max_row) {
@@ -589,7 +598,7 @@ register TScreen *screen;
 			XClearArea(screen->display, TextWindow(screen),
 			 screen->border + screen->scrollbar, top *
 			 FontHeight(screen) + screen->border,
-			 Width(screen), (screen->max_row - top + 1) *
+			 (unsigned) Width(screen),(unsigned) (screen->max_row - top + 1) *
 			 FontHeight(screen), FALSE);
 	}
 	ClearBufRows(screen, screen->cur_row + 1, screen->max_row);
@@ -598,7 +607,8 @@ register TScreen *screen;
 /* 
  * Clear last part of cursor's line, inclusive.
  */
-ClearRight (screen)
+
+void ClearRight (screen)
 register TScreen *screen;
 {
 	if(screen->cursor_state)
@@ -612,13 +622,13 @@ register TScreen *screen;
 		  screen->reverseGC,
 		 CursorX(screen, screen->cur_col),
 		 CursorY(screen, screen->cur_row),
-		 Width(screen) - screen->cur_col * FontWidth(screen),
-		 FontHeight(screen));
+		 (unsigned) Width(screen) - screen->cur_col * FontWidth(screen),
+		 (unsigned)FontHeight(screen));
 	    }
 	}
-	bzero(screen->buf [2 * screen->cur_row] + screen->cur_col,
+	bzero((char*) ( screen->buf [2 * screen->cur_row] + screen->cur_col),
 	       (screen->max_col - screen->cur_col + 1));
-	bzero(screen->buf [2 * screen->cur_row + 1] + screen->cur_col,
+	bzero((char *) (screen->buf [2 * screen->cur_row + 1] + screen->cur_col),
 	       (screen->max_col - screen->cur_col + 1));
 	/* with the right part cleared, we can't be wrapping */
 	screen->buf [2 * screen->cur_row + 1] [0] &= ~LINEWRAPPED;
@@ -627,7 +637,8 @@ register TScreen *screen;
 /*
  * Clear first part of cursor's line, inclusive.
  */
-ClearLeft (screen)
+
+void ClearLeft (screen)
     register TScreen *screen;
 {
         int i;
@@ -644,8 +655,8 @@ ClearLeft (screen)
 		     screen->reverseGC,
 		     screen->border + screen->scrollbar,
 		      CursorY (screen, screen->cur_row),
-		     (screen->cur_col + 1) * FontWidth(screen),
-		     FontHeight(screen));
+		     (unsigned)(screen->cur_col + 1) * FontWidth(screen),
+		     (unsigned)FontHeight(screen));
 	    }
 	}
 	
@@ -662,7 +673,8 @@ ClearLeft (screen)
 /* 
  * Erase the cursor's line.
  */
-ClearLine(screen)
+
+void ClearLine(screen)
 register TScreen *screen;
 {
 	if(screen->cursor_state)
@@ -676,15 +688,15 @@ register TScreen *screen;
 		     screen->reverseGC,
 		     screen->border + screen->scrollbar,
 		      CursorY (screen, screen->cur_row),
-		     Width(screen), FontHeight(screen));
+		     (unsigned) Width(screen), (unsigned) FontHeight(screen));
 	    }
 	}
-	bzero (screen->buf [2 * screen->cur_row], (screen->max_col + 1));
-	bzero (screen->buf [2 * screen->cur_row + 1], (screen->max_col + 1));
+	bzero ((char *) (screen->buf [2 * screen->cur_row]), (screen->max_col + 1));
+	bzero ((char *) (screen->buf [2 * screen->cur_row + 1]), (screen->max_col + 1));
 }
 
-ClearScreen(screen)
-register TScreen *screen;
+void ClearScreen(screen)
+     register TScreen *screen;
 {
 	register int top;
 
@@ -700,13 +712,13 @@ register TScreen *screen;
 			XClearArea(screen->display, TextWindow(screen),
 			 screen->border + screen->scrollbar, 
 			 top * FontHeight(screen) + screen->border,	
-		 	 Width(screen), (screen->max_row - top + 1) *
+		 	 (unsigned) Width(screen), (unsigned)(screen->max_row - top + 1) *
 			 FontHeight(screen), FALSE);
 	}
 	ClearBufRows (screen, 0, screen->max_row);
 }
 
-CopyWait(screen)
+void CopyWait(screen)
 register TScreen *screen;
 {
 	XEvent reply;
@@ -788,7 +800,7 @@ horizontal_copy_area(screen, firstchar, nchars, amount)
     int src_y = CursorY(screen, screen->cur_row);
 
     copy_area(screen, src_x, src_y,
-	      (unsigned)nchars*FontWidth(screen), FontHeight(screen),
+	      (unsigned)nchars*FontWidth(screen),(unsigned) FontHeight(screen),
 	      src_x + amount*FontWidth(screen), src_y);
 }
 
@@ -807,7 +819,7 @@ vertical_copy_area(screen, firstline, nlines, amount)
 	int src_y = firstline * FontHeight(screen) + screen->border;
 
 	copy_area(screen, src_x, src_y,
-		  (unsigned)Width(screen), nlines*FontHeight(screen),
+		  (unsigned)Width(screen),(unsigned) nlines*FontHeight(screen),
 		  src_x, src_y - amount*FontHeight(screen));
     }
 }
@@ -815,7 +827,8 @@ vertical_copy_area(screen, firstline, nlines, amount)
 /*
  * use when scrolling the entire screen
  */
-scrolling_copy_area(screen, firstline, nlines, amount)
+
+void scrolling_copy_area(screen, firstline, nlines, amount)
     TScreen *screen;
     int firstline;		/* line on screen to start copying at */
     int nlines;
@@ -831,7 +844,8 @@ scrolling_copy_area(screen, firstline, nlines, amount)
  * Handler for Expose events on the VT widget.
  * Returns 1 iff the area where the cursor was got refreshed.
  */
-HandleExposure (screen, event)
+
+int HandleExposure (screen, event)
     register TScreen *screen;
     register XEvent *event;
 {
@@ -876,13 +890,12 @@ HandleExposure (screen, event)
  * have been translated to allow for any CopyArea in progress.
  * The rectangle passed in is pixel coordinates.
  */
-handle_translated_exposure (screen, rect_x, rect_y, rect_width, rect_height)
+int handle_translated_exposure (screen, rect_x, rect_y, rect_width, rect_height)
     register TScreen *screen;
     register int rect_x, rect_y;
-    register unsigned int rect_width, rect_height;
+    register int rect_width, rect_height;
 {
-	register int toprow, leftcol, nrows, ncols;
-	extern Bool waiting_for_initial_map;
+  register int toprow, leftcol, nrows, ncols;
 
 	toprow = (rect_y - screen->border) / FontHeight(screen);
 	if(toprow < 0)
@@ -918,7 +931,7 @@ handle_translated_exposure (screen, rect_x, rect_y, rect_width, rect_height)
 	return (0);
 }
 
-ReverseVideo (termw)
+void ReverseVideo (termw)
 	XtermWidget termw;
 {
 	register TScreen *screen = &termw->screen;
@@ -962,7 +975,7 @@ ReverseVideo (termw)
 }
 
 
-recolor_cursor (cursor, fg, bg)
+void recolor_cursor (cursor, fg, bg)
     Cursor cursor;			/* X cursor ID to set */
     unsigned long fg, bg;		/* pixel indexes to look up */
 {
