@@ -1,8 +1,17 @@
 /***********************************************************************
  * zzledt.c - last line editing routine
  *
- * $Id: zzledt.c,v 10.2 1993/03/08 16:11:01 a Exp $
- * $Log: zzledt.c,v $
+ * $Id: x_zzledt.c,v 1.3 2002/08/08 14:59:47 steer Exp $
+ * $Log: x_zzledt.c,v $
+ * Revision 1.3  2002/08/08 14:59:47  steer
+ * ajout de dclaration de ismenu et sciprint
+ *
+ * Revision 1.2  2002/08/08 14:49:46  steer
+ *  pour que les menus dynamiques ne provoque pas l'impression de l'instruction
+ *
+ * Revision 1.1.1.1  2001/04/26 07:48:34  scilab
+ * Imported sources
+ *
  *
  * Revision 10.1  1993/02/11  14:34:03  mga
  * Initial Version
@@ -104,7 +113,10 @@ static int  translate();
 static int  search_line_backward(),search_line_forward();
 void  set_echo_mode(),set_is_reading();
 int   get_echo_mode();
+extern int C2F(ismenu) ();
+extern void sciprint __PARAMS((char *fmt,...));
 
+static int sendprompt=1;
 extern char Sci_Prompt[10];
 
 #include "x_VTparse.h" 
@@ -132,8 +144,9 @@ long int dummy1;                /* added by FORTRAN to give buffer length */
    int character_count;
    char wk_buf[WK_BUF_SIZE + 1];
 
-   sciprint(Sci_Prompt);
+   if(sendprompt) sciprint(Sci_Prompt);
                             /* empty work buffer */
+   sendprompt=1;
    set_is_reading(TRUE);
 
    wk_buf[0] = NUL;
@@ -142,6 +155,13 @@ long int dummy1;                /* added by FORTRAN to give buffer length */
    while(1) {
                             /* get next keystroke (no echo) */
      keystroke = gchar_no_echo();
+     if (C2F(ismenu) () == 1) {/* abort current line aquisition*/
+       sendprompt=0;
+       backspace(cursor);
+       cursor = 0;
+       *eof=-1;
+       return;
+     }
      if ( keystroke ==  CTRL_C )
        {
 	 int j = SIGINT;
